@@ -1398,11 +1398,95 @@ void wxVTKRenderWindowInteractor::WorldToDisplay(double worldPos[4], double disp
 
 }
 
+void wxVTKRenderWindowInteractor::GetCamVectors(double camPos[4], double camDir[4], double camUp[4]) {
+	bool available = false;
+
+	if (m_pPicker != NULL && m_pImageViewer != NULL) {
+		int x = Size[0] >> 1;
+		int y = Size[1] >> 1;
+		vtkRenderer* ren = FindPokedRenderer(x, y);
+
+		if (ren != NULL) {
+			vtkCamera* cam = ren->GetActiveCamera();
+			cam->GetPosition(camPos);
+			cam->GetDirectionOfProjection(camDir);
+			cam->GetViewUp(camUp);
+			camPos[3] = camDir[3] = camUp[3] = 1.0;
+			available = true;
+		}
+	}
+	if (!available) {
+		for (int i = 0; i < 4; i++) {
+			camPos[i] = camDir[i] = camUp[i] = std::numeric_limits<double>::quiet_NaN();
+		}
+	}
+}
+
+void wxVTKRenderWindowInteractor::RayPick(double displayPos[2], double worldPos[4]) {
+
+	bool error = true;
+
+	if (m_pPicker != NULL && m_pImageViewer != NULL) {
+		int x = (int)(displayPos[0]);
+		int y = Size[1] - (int)(displayPos[1]) - 1;
+		vtkRenderer* ren = FindPokedRenderer(x, y);
+
+		if (ren != NULL) {
+			vtkCamera* cam = ren->GetActiveCamera();
+			double pt[3]  = { x, y, 0.0f };
+			double world[4] = {0.0f, 0.0f, 0.0f, 0.0f};
+			m_pPicker->Pick(pt, ren);
+			m_pPicker->GetPickPosition(world);
+
+			double cpos[3];
+			double cdir[3];
+			cam->GetPosition(cpos);
+			cam->GetDirectionOfProjection(cdir);
+			if (cam->GetParallelProjection()) {
+				this->m_pImageViewer->IntersectarRayo(world, cdir, worldPos);
+				worldPos[3] = 1.0;
+				error = false;
+			}
+		}
+	}
+	if (error) {
+		worldPos[0] = worldPos[1] = worldPos[2] = worldPos[3] = std::numeric_limits<double>::quiet_NaN();
+	}
+
+}
+
+void wxVTKRenderWindowInteractor::RayPick(double worldPos[4]) {
+
+	bool error = true;
+
+	if (m_pPicker != NULL && m_pImageViewer != NULL) {
+		int x = Size[0] >> 1;
+		int y = Size[1] >> 1;
+		vtkRenderer* ren = FindPokedRenderer(x, y);
+
+		if (ren != NULL) {
+			vtkCamera* cam = ren->GetActiveCamera();
+			double cpos[3];
+			double cdir[3];
+			cam->GetPosition(cpos);
+			cam->GetDirectionOfProjection(cdir);
+			this->m_pImageViewer->IntersectarRayo(cpos, cdir, worldPos);
+			worldPos[3] = 1.0;
+			error = false;
+		}
+	}
+	if (error) {
+		worldPos[0] = worldPos[1] = worldPos[2] = worldPos[3] = std::numeric_limits<double>::quiet_NaN();
+	}
+
+}
+
 //endregion
 
 //----------------------------------------------------------------------------------------------------
 //region "Helpers de contexto de dibujado"
 
+
 void wxVTKRenderWindowInteractor::TransformarEvento(wxMouseEvent &event)
 {
 	if (m_pPicker != NULL && m_pImageViewer != NULL) {
