@@ -94,12 +94,13 @@ public:
 	}
 
 	IModeloImagen(IModeloDicom* pModeloPadre, IModeloSerie* pSeriePadre,
-		const std::string& UID, const std::string& pathImagen = "")
+		const std::string& UID, const std::string& instanceNumber, const std::string& pathImagen = "")
 	{
 		m_pSeriePadre = pSeriePadre;
 		m_pModeloPadre = pModeloPadre;
 		m_UID = UID;
 		m_pathImagen = pathImagen;
+		m_instanceNumber = instanceNumber;
 	}
 
 	IModeloImagen( const IModeloImagen& o) {
@@ -107,6 +108,7 @@ public:
 		m_pModeloPadre = o.m_pModeloPadre;
 		m_UID = o.m_UID;
 		m_pathImagen = o.m_pathImagen;
+		m_instanceNumber = o.m_instanceNumber;
 	}
 
 	IModeloImagen& operator = (const IModeloImagen& o) {
@@ -114,6 +116,7 @@ public:
 		m_pModeloPadre = o.m_pModeloPadre;
 		m_UID = o.m_UID;
 		m_pathImagen = o.m_pathImagen;
+		m_instanceNumber = o.m_instanceNumber;
 		return *this;
 	}
 
@@ -130,12 +133,17 @@ public:
 	{
 		return m_pathImagen;
 	}
-
+	
+	const std::string& GetInstanceNumber() const
+	{
+		return m_instanceNumber;
+	}
 protected:
 	IModeloSerie* m_pSeriePadre;
 	IModeloDicom* m_pModeloPadre;
 	std::string   m_UID;
 	std::string	  m_pathImagen;
+	std::string	  m_instanceNumber;
 
 	friend class IModeloDicom;
 
@@ -716,7 +724,7 @@ public:
 
 	}
 
-	const IModeloImagen& InsertarImagen(const std::string& UIDSerie, const std::string& UID, const std::string& pathImagen = "")
+	const IModeloImagen& InsertarImagen(const std::string& UIDSerie, const std::string& UID, const std::string& instanceNumber, const std::string& pathImagen = "")
 	{
 
 		IModeloImagen* imagen = NULL;
@@ -731,7 +739,7 @@ public:
 
 			if (serie != NULL) {
 
-				serie->Imagenes.push_back(IModeloImagen( this, serie, UID, pathImagen));
+				serie->Imagenes.push_back(IModeloImagen( this, serie, UID, instanceNumber, pathImagen));
 				imagen = & (serie->Imagenes.back());
 				ListaPunterosImagenes.push_back(imagen);
 			}
