@@ -49,7 +49,7 @@ bool GNC::GCS::IException::IsFatal()  const {
 
 GNC::GCS::IException::operator std::string() const
 {
-	return _Std("Exception in component ") + GetComponent() + std::string(" : ")  + GetCause();
+	return _Std("Exception in component") + std::string(" ") + GetComponent() + std::string(" :\n")  + GetCause();
 }
 
 //=========================
