@@ -14,6 +14,7 @@
 #ifndef IHISTORYTOOL_H
 #define IHISTORYTOOL_H
 #include <string>
+#include <list>
 
 #include <api/api.h>
 #include <wx/bitmap.h>
@@ -52,9 +53,10 @@ namespace GNC {
 			virtual void AppendToolIn(wxEvtHandler* pParent, wxMenu* pMenu);
 
 			virtual void Execute() = 0;
+			virtual void Execute(const std::list<long>& seriesPk);
 
 			virtual bool Enabled() { return true;}
-
+			virtual bool AreSeriesFullyDownloaded(const std::list<long>& seriesPk);
 
 			UID ID;
 			TToolFamily Family;
@@ -66,4 +68,4 @@ namespace GNC {
 		};
 	}
 }
-#endif
\ No newline at end of file
+#endif
