@@ -49,11 +49,13 @@
 #include <wx/wfstream.h>
 #include <wx/wxsqlite3/wxsqlite3.h>
 #include <wx/socket.h>
+#include <wx/dcclient.h>
 
 #include <main/controllers/configurationcontroller.h>
 #include <main/tools/coretools.h>
 #include "singleinstance.h"
 #include "initwx.h"
+#include <curl/curl.h>
 
 #if defined(__DEPRECATED)
 #undef __DEPRECATED
@@ -84,12 +86,11 @@
 #include <api/toolsystem/itoolsregistry.h>
 #include <api/controllers/imodulecontroller.h>
 #include <api/controllers/icontroladorlog.h>
-#include <api/controllers/icommandscontroller.h>
+#include <main/controllers/commandcontroller.h>
 #include <api/controllers/ieventscontroller.h>
 #include <api/dicom/idicomconformance.h>
 #include <eventos/hidesplashwindow.h>
 
-
 #include "main/entorno.h"
 
 #include <main/controllers/controladorextensiones.h>
@@ -261,6 +262,16 @@ bool Ginkgo::OnInit()
 	wxLog *logger = new wxLogStderr();
 	wxLog::SetActiveTarget(logger);
 	wxSQLite3Database::InitializeSQLite();
+	//initialize WSA on windows
+#if defined(_WINDOWS)
+		WSADATA wsaData;
+		if (WSAStartup(MAKEWORD( 2, 2 ), &wsaData) != 0) {
+			LOG_ERROR("INIT", "Error initializing network");
+		}
+#endif
+	//initialize curl...
+	/* Must initialize libcurl before any threads are started */
+	curl_global_init(CURL_GLOBAL_ALL);
 
 	WriteHeaderLog();
 
@@ -303,34 +314,45 @@ bool Ginkgo::OnInit()
 			name, inst_name);
 		if (connection)
 		{
-			wxFileName fileName;
+			
 			if (argc == 2) {
-				fileName = wxFileName(argv[1]);
-				if (fileName.IsRelative()) {
-					#if defined(__WXGTK__)
-					char* invocation_dir = getenv("INVOCATION_DIR");					
-					if (invocation_dir != NULL) {
-						wxString invocationDir = wxString::FromUTF8(invocation_dir);
-						if (!invocationDir.IsEmpty()) {
-							fileName = invocationDir + wxFileName::GetPathSeparator() + fileName.GetFullPath();
-						}
-					}					
-					#else
-					fileName.MakeAbsolute();
-					#endif
-				}			
-				if (fileName.IsOk() && ((fileName.FileExists() && fileName.IsFileReadable()) || (wxDirExists(fileName.GetFullPath()) && fileName.IsDirReadable()))) {
-					LOG_INFO("Core", "The client sends following file: " << fileName.GetFullPath().ToUTF8());
+				wxString str = wxString(argv[1]);
+				if (str.Lower().StartsWith(wxT("ginkgocadx://"))) {
+					LOG_INFO("Core", "The client sends following URL: " << str.ToUTF8());
 					// Ask the other instance to open a file or raise itself
-					connection->Execute(fileName.GetFullPath());
+					connection->Execute(str);
 					connection->Disconnect();
 					delete connection;
 				}
 				else {
-					wxString err = wxString::Format(wxT("Error: The file %s does not exists or is not readable"), argv[1]);
-					LOG_ERROR("Core", TOPATH(err));
-					wxMessageBox(err, wxT("Ginkgo CADx"), wxICON_INFORMATION|wxOK);
-				}			
+
+					wxFileName fileName = wxFileName(argv[1]);
+					if (fileName.IsRelative()) {
+						#if defined(__WXGTK__)
+						char* invocation_dir = getenv("INVOCATION_DIR");					
+						if (invocation_dir != NULL) {
+							wxString invocationDir = wxString::FromUTF8(invocation_dir);
+							if (!invocationDir.IsEmpty()) {
+								fileName = invocationDir + wxFileName::GetPathSeparator() + fileName.GetFullPath();
+							}
+						}					
+						#else
+						fileName.MakeAbsolute();
+						#endif
+					}			
+					if (fileName.IsOk() && ((fileName.FileExists() && fileName.IsFileReadable()) || (wxDirExists(fileName.GetFullPath()) && fileName.IsDirReadable()))) {
+						LOG_INFO("Core", "The client sends following file: " << fileName.GetFullPath().ToUTF8());
+						// Ask the other instance to open a file or raise itself
+						connection->Execute(fileName.GetFullPath());
+						connection->Disconnect();
+						delete connection;
+					}
+					else {
+						wxString err = wxString::Format(wxT("Error: The file %s does not exists or is not readable"), argv[1]);
+						LOG_ERROR("Core", TOPATH(err));
+						wxMessageBox(err, wxT("Ginkgo CADx"), wxICON_INFORMATION|wxOK);
+					}
+				}
 			} else {
 				// Ask the other instance to open a file or raise itself
 				connection->Execute(wxT(""));
@@ -359,6 +381,7 @@ bool Ginkgo::OnInit()
 		GNC::GCS::ControladorInternacionalizacion::Instance()->AddCatalog("cadxcore");
 	}
 	//permisos del core
+	GNC::GCS::IControladorPermisos::Instance()->AddDefinicionPermiso("core.restrictions", _Std("Ginkgo CADx restrictions"), "reutilize_study", _Std("Open only one tab for each study"), false, "", true);
 	GNC::GCS::IControladorPermisos::Instance()->AddDefinicionPermiso("core.restrictions", _Std("Ginkgo CADx restrictions"), "anonymous_history", _Std("Anonymous mode (history is cleaned)"), false, "", false);
 	GNC::GCS::IControladorPermisos::Instance()->AddDefinicionPermiso("core.restrictions", _Std("Ginkgo CADx restrictions"), "max_tabs", _Std("Max number of tabs opened"), false, "2", false);
 	GNC::GCS::IControladorPermisos::Instance()->AddDefinicionPermiso("core.restrictions", _Std("Ginkgo CADx restrictions"), "inactivity_time", _Std("Max seconds of Ginkgo CADx application inactivity"), false, "600", false);
@@ -409,6 +432,9 @@ bool Ginkgo::OnInit()
 
 	GNC::GCS::IControladorPermisos::Instance()->AddDefinicionPermiso("core.opengl", _Std("OpenGL"), "enable_shaders", _Std("Enable shaders"), false, "", true);
 
+	//ginkgocloud
+	GNC::GCS::IControladorPermisos::Instance()->AddDefinicionPermiso("ginkgocloud",_Std("Ginkgo Cloud"), "download",_Std("Download from Ginkgo Cloud"),false, "", true);
+
 	//
 
 	/*
@@ -550,11 +576,11 @@ bool Ginkgo::OnInit()
 
 		DoProgress(wxString(_("Interpreting parameters ...")));
 
+
 	}
 	//parseo
 	wxCommandEvent ce(wxEVT_COMMAND_MENU_SELECTED, ID_Inicio_Aplicacion);
-	m_pVentanaPrincipal->AddPendingEvent(ce);
-
+	m_pVentanaPrincipal->GetEventHandler()->AddPendingEvent(ce);
 
 #if defined (__WXMAC__)
 	m_Inicializado = true;
@@ -606,7 +632,7 @@ int Ginkgo::OnExit()
 	GNC::GCS::ControladorAcciones::FreeInstance();
 	GNC::GCS::InactivityController::FreeInstance();
 	GIL::DICOM::PACSController::FreeInstance();
-	GNC::GCS::IControladorComandos::FreeInstance();
+	GNC::GCS::ICommandController::FreeInstance();
 	GNC::ControladorExtensiones::FreeInstance();
 	GNC::GCS::ControladorCarga::FreeInstance();
 	GNC::HistoryToolsController::FreeInstance();
@@ -633,6 +659,11 @@ int Ginkgo::OnExit()
 
 	GNC::GCS::IControladorLog::FreeInstance();
 
+#if defined(_WINDOWS)
+		WSACleanup();
+#endif
+	curl_global_cleanup();
+
 	#if defined(_WINDOWS) && defined(_DEBUG)
 	cairo_debug_reset_static_data();
 	#endif
