@@ -109,7 +109,7 @@ GNC::GCS::Ptr<GNC::GCS::IReferredStudyContext> GNC::GCS::IStudyContext::NewRef(c
 
 	reference->EstudioPadre          = parent;
 	
-	reference->hangingProtocol = parent->hangingProtocol;
+	reference->hangingLayout = parent->hangingLayout;
 
 	return reference;
 }
@@ -133,7 +133,7 @@ GNC::GCS::IStudyContext& GNC::GCS::IStudyContext::operator = (const GNC::GCS::IS
 	for (std::vector<long>::const_iterator it = o.OpenedSeries.begin(); it != o.OpenedSeries.end(); ++it) {
 		OpenedSeries.push_back((*it));
 	}
-	hangingProtocol = o.hangingProtocol;
+	hangingLayout = o.hangingLayout;
 
 	return *this;
 }
@@ -158,22 +158,34 @@ void GNC::GCS::IStudyContext::SetViewer(const vtkSmartPointer<vtkGinkgoImageView
 
 void GNC::GCS::IStudyContext::SetActiveIndex(int indice)
 {
-	TStudyFile& fichero = *Files[indice];
+	int newIdx = indice;
 
-	ActiveFileIndex = indice;
-	Loader->SetInput(fichero.PathOfFile);
-	Loader->UpdateInformation();
-	double spacing[3] = {1.0f, 1.0f, 1.0f};
-	GetSpacingActive(spacing[0], spacing[1], spacing[2]);
-	Loader->SetOutputSpacing(spacing);
-	double origin[3] = {0.0f, 0.0f, 0.0f};
-	GetOriginActive(origin[0], origin[1], origin[2]);
-	Loader->SetOutputOrigin(origin);
-	if(Viewer != NULL) {
-		// FIXME: Comprobar si el pipeline esta conectado.
-		Viewer->SetupPipeline();
-	} else {
-		//std::cerr << "No se ha inicializado el contexto correctamente (Viewer NULL) tal vez sea un estudio referido" << std::endl;
+	if (indice >= 0 && !Files.empty()) { // Propagate last to each other, so there is no more slices to layout them
+		size_t numFiles = Files.size();
+		if (indice >= numFiles) {
+			newIdx = numFiles - 1;
+		}
+		TStudyFile& fichero = *Files[newIdx];
+
+		ActiveFileIndex = newIdx;
+	
+		Loader->SetInput(fichero.PathOfFile);
+		Loader->UpdateInformation();
+		double spacing[3] = {1.0f, 1.0f, 1.0f};
+		GetSpacingActive(spacing[0], spacing[1], spacing[2]);
+		Loader->SetOutputSpacing(spacing);
+		double origin[3] = {0.0f, 0.0f, 0.0f};
+		GetOriginActive(origin[0], origin[1], origin[2]);
+		Loader->SetOutputOrigin(origin);
+		if(Viewer != NULL) {
+			// FIXME: Comprobar si el pipeline esta conectado.
+			Viewer->SetupPipeline();
+		} else {
+			//std::cerr << "No se ha inicializado el contexto correctamente (Viewer NULL) tal vez sea un estudio referido" << std::endl;
+		}
+	}
+	else {
+		LOG_ERROR("StudyContext", "Layout distribution error");
 	}
 }
 
