@@ -337,6 +337,51 @@ namespace GNC {
 			//-- Acotaciones
 			//----------------------------------------------
 
+			/** Return signs ( -1.0 if < -epsilon, 1.0 if > epsilon 0.0 otherwise) */
+			inline Vector3D Sign() const {
+				Vector3D signs;
+				const TComp lower = -EpsilonDeComponentes();
+				const TComp upper = EpsilonDeComponentes();
+				for (int i = 0; i < 3; i++) {
+					const TComp& val = v[i];
+					TComp& sign = signs.v[i];
+					if (val < lower) {
+						sign = -1.0;
+					}
+					else if (val > upper) {
+						sign = 1.0;
+					}
+					else {
+						sign = 0.0;
+					}
+				}
+				return signs;
+			}
+
+			/** Stabilize at 0.0 (ignore if desv from zero > eps) */
+			inline Vector3D& Stabilize() {
+				TComp trunc = EpsilonDeComponentes();
+				for (int i = 0; i < 3; i++) {
+					TComp& val = v[i];
+					if (val > 0.0) {
+						if (val < trunc) {
+							val = 0.0;
+						}
+					}
+					else if (val < 0.0) {
+						if (std::abs(val) < trunc) {
+							val = 0.0;
+						}
+					}
+				}
+				return *this;
+			}
+
+			/** Return a new vector stabilized at 0.0 (ignore if desv from zero > eps) */
+			inline Vector3D Stabilized() const {
+				return Vector3D(*this).Stabilize();
+			}
+
 			inline Vector3D ValorAbsoluto() {
 				return Vector3D(std::abs(x), std::abs(y), std::abs(z));
 			}
