@@ -28,7 +28,7 @@
 #include <api/globals.h>
 #include <api/integration/dict.h>
 #include <api/controllers/ieventscontroller.h>
-#include <api/controllers/icommandscontroller.h>
+#include <main/controllers/commandcontroller.h>
 #include <api/controllers/ipacscontroller.h>
 #include <api/internationalization/internationalization.h>
 
@@ -63,29 +63,35 @@ namespace GADAPI {
 	DicomizeCommandParams::DicomizeCommandParams(const GNC::GCS::Ptr<GNC::GUI::ImportationData>& pDatosPersistentes, const std::string& dirTemporal)
 	{
 		m_pSemaforoEsperarComando = new wxSemaphore();
-		m_pImportData = pDatosPersistentes;
+		if (pDatosPersistentes.IsValid()) {
+			m_pImportData = pDatosPersistentes;
+		} else {
+			m_pImportData = new GNC::GUI::ImportationData();
+		}
 		
 		//se copia todo el directorio temporal a uno nuevo
 		wxString wxNuevoDirTemp = FROMPATH(GNC::Entorno::Instance()->CrearDirectorioTemporal());
 
 		wxDir dir;
-		if (dir.Open(FROMPATH(dirTemporal))) {
-			wxString fileName;
-			wxString destino;
-			bool cont = dir.GetFirst(&fileName);
+		if (!dirTemporal.empty()) {
+			if (dir.Open(FROMPATH(dirTemporal))) {
+				wxString fileName;
+				wxString destino;
+				bool cont = dir.GetFirst(&fileName);
 
-			while (cont) {
-				destino = wxNuevoDirTemp + wxFileName::GetPathSeparator(wxPATH_NATIVE) + fileName;
-				fileName=dir.GetName()+ wxFileName::GetPathSeparator(wxPATH_NATIVE) +fileName;
-				wxRenameFile(fileName,destino);
-				for(GNC::GUI::ImportationData::TListOfFiles::iterator it = m_pImportData->m_SourceFiles.begin(); it!= m_pImportData->m_SourceFiles.end(); ++it){
-					if ( FROMPATH((*it)) == fileName )
-					{
-						(*it) = TOPATH(destino);
-						break;
+				while (cont) {
+					destino = wxNuevoDirTemp + wxFileName::GetPathSeparator(wxPATH_NATIVE) + fileName;
+					fileName=dir.GetName()+ wxFileName::GetPathSeparator(wxPATH_NATIVE) +fileName;
+					wxRenameFile(fileName,destino);
+					for(GNC::GUI::ImportationData::TListOfFiles::iterator it = m_pImportData->m_SourceFiles.begin(); it!= m_pImportData->m_SourceFiles.end(); ++it){
+						if ( FROMPATH((*it)) == fileName )
+						{
+							(*it) = TOPATH(destino);
+							break;
+						}
 					}
+					cont = dir.GetNext(&fileName);
 				}
-				cont = dir.GetNext(&fileName);
 			}
 		}
 		m_dirTemporal = TOPATH(wxNuevoDirTemp);
@@ -93,6 +99,7 @@ namespace GADAPI {
 		m_mensajeError = "";
 		m_copiadoCorrecto = false;
 		m_importacionCorrecta = false;
+		m_openAfterDicomize = true;
 		m_pComandoEspera = NULL;
 		m_pParamsEspera = NULL;
 		//
@@ -107,20 +114,24 @@ namespace GADAPI {
 	DicomizeCommandParams& DicomizeCommandParams::operator = (const DicomizeCommandParams& o) {
 		this->m_pImportData = o.m_pImportData;
 		this->m_dirTemporal = o.m_dirTemporal;
+		this->m_openAfterDicomize = o.m_openAfterDicomize;
 
 		this->m_mensajeError = "";
 		this->m_copiadoCorrecto = o.m_copiadoCorrecto;
 		this->m_importacionCorrecta = o.m_importacionCorrecta;
 		this->m_listOfFiles = o.m_listOfFiles;
 
+		m_pSemaforoEsperarComando = new wxSemaphore();
 		m_pComandoEspera = NULL;
 		m_pParamsEspera = NULL;
 		return *this;
 	}
 
 	DicomizeCommandParams::~DicomizeCommandParams() {
-		delete m_pSemaforoEsperarComando;
-		m_pSemaforoEsperarComando = NULL;
+		if (m_pSemaforoEsperarComando != NULL) {
+			delete m_pSemaforoEsperarComando;
+			m_pSemaforoEsperarComando = NULL;
+		}
 	}
 
 	DicomizeCommand::DicomizeCommand(DicomizeCommandParams* pParams) : IComando(pParams)
@@ -172,7 +183,7 @@ namespace GADAPI {
 			if(answer == wxYES) {
 				DicomizeCommandParams* pParams = new DicomizeCommandParams(*m_pIntegracionParams);
 				DicomizeCommand* pCmd = new DicomizeCommand(pParams);
-				GNC::Entorno::Instance()->GetControladorComandos()->ProcessAsync(_Std("Importing..."),pCmd,NULL);
+				GNC::Entorno::Instance()->GetCommandController()->ProcessAsync(_Std("Importing..."),pCmd,NULL);
 			} else {
 				BorrarArchivosTemporales(FROMPATH(m_pIntegracionParams->m_dirTemporal));
 				GNC::GCS::InactivityController::Instance()->KillNow();
@@ -391,7 +402,7 @@ namespace GADAPI {
 		}
 
 		if(correcto) {
-			GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorialParams* pParams = new GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorialParams(m_pIntegracionParams->m_listOfFiles, false, GNC::GCS::HistoryController::TAA_COPY);
+			GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorialParams* pParams = new GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorialParams(m_pIntegracionParams->m_listOfFiles, m_pIntegracionParams->m_openAfterDicomize, GNC::GCS::HistoryController::TAA_MOVE);
 			pParams->m_informar = false;
 			GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorial* pCmd = new GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorial(pParams);
 			
@@ -413,7 +424,7 @@ namespace GADAPI {
 			//el pacs sera el primero d la configuracion si no lanzar excepcion
 			std::string pacsStore = m_pIntegracionParams->m_pImportData->m_pIntegrationModel->GlobalVariables.GetValue(GKDI_GLOBAL_PACS_STORE_SID);
 			::GADAPI::SendPACSCommand* pCmd = new ::GADAPI::SendPACSCommand(pacsStore, hl7Message, m_pIntegracionParams->m_InsertedSeries);
-			GNC::Entorno::Instance()->GetControladorComandos()->ProcessAsync("Processing...",pCmd,NULL);
+			GNC::Entorno::Instance()->GetCommandController()->ProcessAsync("Processing...",pCmd,NULL);
 		}
 		catch (GIL::HL7::HL7Exception& ex) {
 			std::ostringstream ostr;
@@ -455,7 +466,7 @@ namespace GADAPI {
 		LOG_TRACE("DicomizeCommand", "Esperando a " << pCmd);
 		m_pIntegracionParams->m_pComandoEspera = pCmd;
 		m_pIntegracionParams->m_pParamsEspera = pCmdParams;
-		GNC::Entorno::Instance()->GetControladorComandos()->ProcessAsync("Processing...",pCmd,NULL);
+		GNC::Entorno::Instance()->GetCommandController()->ProcessAsync("Processing...",pCmd,NULL);
 		m_pIntegracionParams->m_pSemaforoEsperarComando->Wait();
 		LOG_TRACE("DicomizeCommand", "Espera de " << pCmd << " finalizada");
 	}
