@@ -16,11 +16,9 @@
 #define ginkgoEVT_Core_ModificacionImagen  3
 #define ginkgoEVT_Core_ModificacionWidget  4
 #define ginkgoEVT_Core_Render              5
-#define ginkgoEVT_Core_Herramientas        6
+#define ginkgoEVT_Core_SCGenerated         6
 #define ginkgoEVT_Core_MensajesUsuario     7
-#define ginkgoEVT_Core_Estilo              8
 #define ginkgoEVT_Core_ProgresoComando     9
-#define ginkgoEVT_Core_HandleDICOM         10
 #define ginkgoEVT_Core_UpdateAvailable     11
 #define ginkgoEVT_Core_Views               12
 #define ginkgoEVT_Core_HideSplashWindow	   18
