@@ -15,7 +15,7 @@
 #include <api/globals.h>
 #include <api/icommand.h>
 #include <api/dicom/idicommanager.h>
-#include <api/controllers/icommandscontroller.h>
+#include <main/controllers/commandcontroller.h>
 #include <api/internationalization/internationalization.h>
 #include <api/imodelointegracion.h>
 #include <main/entorno.h>
@@ -969,7 +969,7 @@ void GNC::GCS::ControladorCarga::CargaAsincrona(GNC::GCS::IVista* pVista, bool l
 	wxCriticalSectionLocker locker(*m_pCriticalSection);
 	GNC::GCS::ControladorVistas::Instance()->SolicitarActivarVista(pVista);
 	GADAPI::ComandoCarga* pCmd = new GADAPI::ComandoCarga(new GADAPI::ComandoCargaParams(pVista, loadFirst));
-	GNC::Entorno::Instance()->GetControladorComandos()->ProcessAsync(_Std("load"), pCmd, pVista);
+	GNC::Entorno::Instance()->GetCommandController()->ProcessAsync(_Std("load"), pCmd, pVista);
 }
 
 GNC::GCS::ControladorCarga * GNC::GCS::ControladorCarga::Instance()
