@@ -33,7 +33,6 @@
 
 GetAssociation::GetAssociation(const std::string& _ambitolog, IModeloDicom* pModelo) : FindAssociation(_ambitolog),
 	m_maxReceivePDULength(ASC_DEFAULTMAXPDU),
-	m_pHandler(NULL),
 	m_pModelo(pModelo),
 	m_numeroImagenes(0),
 	m_mensaje(""),
@@ -367,7 +366,6 @@ CONDITION GetAssociation::getSCU(DcmDataset *pdset) {
 		LOG_DEBUG("C-GET", str.c_str());
 	}
 
-
 	cond = MDIMSE_getUser(
 		assoc,
 		this,
@@ -379,8 +377,17 @@ CONDITION GetAssociation::getSCU(DcmDataset *pdset) {
 		&rsp, &statusDetail, &rspIds);
 
 	if (cond.bad()) {
-		LOG_DEBUG(ambitolog, "DIMSE_getUser(): " << cond.text() );
+		std::ostringstream os;
+		os << DU_cgetStatusString(cond.status());
+		if (statusDetail != NULL) {
+			OFString errorComment;
+			if (statusDetail->findAndGetOFString(DCM_ErrorComment, errorComment).good()) {
+				os << ". " << errorComment.c_str();
+			}
+		}
+		m_errorMessage = os.str();
 	}
+
 	if (statusDetail != NULL) {
 		LOG_DEBUG(ambitolog, "DIMSE_getUser(): Estado: " << std::endl << DumpDataset(statusDetail));
 		delete statusDetail;
@@ -391,12 +398,38 @@ CONDITION GetAssociation::getSCU(DcmDataset *pdset) {
 		delete rspIds;
 	}
 
-	if(m_errorMessage != "")
-	{
-		throw GIL::DICOM::PACSException(m_errorMessage, "Acquisition");
+	return cond;
+
+	/*if( rsp.DimseStatus != STATUS_Success && rsp.DimseStatus != STATUS_Pending) {
+		std::ostringstream os;
+		os << DU_cgetStatusString(rsp.DimseStatus);
+		if (statusDetail != NULL) {
+			OFString errorComment;
+			if (statusDetail->findAndGetOFString(DCM_ErrorComment, errorComment).good()) {
+				os << ". " << errorComment.c_str();
+			}
+		}
+		m_errorMessage = os.str();
 	}
 
-	return cond;
+	if (statusDetail != NULL) {
+		LOG_DEBUG(ambitolog, "DIMSE_getUser(): Estado: " << std::endl << DumpDataset(statusDetail));
+		delete statusDetail;
+	}
+
+	if (rspIds != NULL) {
+
+		delete rspIds;
+	}
+
+	if(m_errorMessage != "" || rsp.NumberOfFailedSubOperations > 0 ) {
+		if (m_errorMessage.size() == 0) {
+			m_errorMessage = "Some operations failed";
+		}
+		return makeOFCondition(OFM_dcmnet, 18, OF_error, m_errorMessage.c_str());
+	}
+
+	return cond;*/
 }
 
 void GetAssociation::getCallback(void * /*callbackData*/, T_DIMSE_C_GetRQ * /*request*/, int /*responseCount*/, T_DIMSE_C_GetRSP * /*response*/)
@@ -447,10 +480,6 @@ CONDITION GetAssociation::subOpSCP(T_ASC_Association **subAssoc) {
 
 	OFCondition cond = DIMSE_receiveCommand(*subAssoc, DIMSE_BLOCKING, 0, &presID, &msg, NULL);
 
-	if (cond.bad()) {
-
-	}
-
 	if (cond == EC_Normal) {
 		switch (msg.CommandField) {
 			case DIMSE_C_STORE_RQ:
@@ -759,20 +788,19 @@ void GetAssociation::OnFileReceived(const std::string& fileName, DcmDataset* dse
 
 			OFString OFUIDImagen;
 			std::string UIDImagen;
-			if (dset->findAndGetOFString(DCM_SOPInstanceUID, OFUIDImagen).good()) {
+			OFString OFInstanceNumber;
+			std::string InstanceNumber;
+			if (dset->findAndGetOFString(DCM_SOPInstanceUID, OFUIDImagen).good() && dset->findAndGetOFString(DCM_InstanceNumber, OFInstanceNumber).good()) {
 				UIDImagen.assign(OFUIDImagen.c_str());
-				m_pModelo->InsertarImagen(SerieUID,UIDImagen);
+				InstanceNumber.assign(OFInstanceNumber.c_str());
+				m_pModelo->InsertarImagen(SerieUID,UIDImagen, InstanceNumber, fileName);
+			} else {
+				LOG_ERROR("DCMGET", "InstanceUID or InstanceNumber not found");
 			}
 		}
 	}
-	if (m_pHandler != NULL) {
-		m_pHandler->Store(fileName, dset);
-	}
 }
 
-void GetAssociation::SetCallbackHandler(IStoreCallBack * handler) {
-	m_pHandler = handler;
-}
 
 float GetAssociation::TasaTransferencia(int bytesDescargados)
 {
