@@ -30,7 +30,6 @@ public:
 
 	CONDITION SendObject(DcmDataset *dataset);
 
-	void SetCallbackHandler(IStoreCallBack* handler);
 
 protected:
 
@@ -41,7 +40,6 @@ private:
 	CONDITION moveSCU(DcmDataset *pdset);
 
 	int m_maxReceivePDULength;
-	IStoreCallBack* m_pHandler;
 	IModeloDicom* m_pModelo;
 	std::string m_errorMessage;
 };
