@@ -189,7 +189,7 @@ PrintAssociation::~PrintAssociation() {
 	
 }
 
-CONDITION PrintAssociation::Print(DicomServer* server, const std::string& local_aet, const GIL::DICOM::DicomDataset& film, const GIL::DICOM::DicomDataset& layout, const GIL::DICOM::DicomDataset& job, const std::list<std::string>& images)
+CONDITION PrintAssociation::Print(const GNC::GCS::Ptr<DicomServer>& server, const std::string& local_aet, const GIL::DICOM::DicomDataset& film, const GIL::DICOM::DicomDataset& layout, const GIL::DICOM::DicomDataset& job, const std::list<std::string>& images)
 {
 	CONDITION status = DIMSE_NORMAL;
 	
@@ -238,6 +238,8 @@ CONDITION PrintAssociation::Print(DicomServer* server, const std::string& local_
 			attrs.clear();
 			
 			std::string tmpStd;
+
+
 			e = newDicomElement(DCM_NumberOfCopies);
 			if (job.getTag(GKDCM_NumberOfCopies, tmpStd)) {
 				e->putString(tmpStd.c_str());
@@ -246,23 +248,31 @@ CONDITION PrintAssociation::Print(DicomServer* server, const std::string& local_
 			}
 			attrs.insert(e);
 			
-			e = newDicomElement(DCM_PrintPriority);
 			if (job.getTag(GKDCM_PrintPriority, tmpStd)) {
-				e->putString(tmpStd.c_str());
+				e = newDicomElement(DCM_PrintPriority);
+				if (!tmpStd.empty()) {
+					e->putString(tmpStd.c_str());
+				}
+				attrs.insert(e);
 			}
-			attrs.insert(e);
 			
-			e = newDicomElement(DCM_MediumType);
 			if (job.getTag(GKDCM_MediumType, tmpStd)) {
-				e->putString(tmpStd.c_str());
+				e = newDicomElement(DCM_MediumType);
+				if (!tmpStd.empty()) {
+					e->putString(tmpStd.c_str());
+				}
 			}
 			attrs.insert(e);
 			
-			e = newDicomElement(DCM_FilmDestination);
+			
 			if (film.getTag(GKDCM_FilmDestination, tmpStd)) {
-				e->putString(tmpStd.c_str());
+				e = newDicomElement(DCM_FilmDestination);
+				if (!tmpStd.empty()) {
+					e->putString(tmpStd.c_str());
+				}
+				attrs.insert(e);
 			}
-			attrs.insert(e);
+			
 			
 			e = newDicomElement(DCM_FilmSessionLabel);
 			e->putString("GNK Print Session");
@@ -288,8 +298,6 @@ CONDITION PrintAssociation::Print(DicomServer* server, const std::string& local_
 			
 			if (c.good()) {
 
-				
-			
 				// 4. N-CREATE (Presentation LUT)
 				// 5. N-CREATE (Film Box)
 				
@@ -297,11 +305,14 @@ CONDITION PrintAssociation::Print(DicomServer* server, const std::string& local_
 				response = NULL;
 				attrs.clear();
 				
-				e = newDicomElement(DCM_ImageDisplayFormat);
 				if (layout.getTag(GKDCM_ImageDisplayFormat, tmpStd)) {
+					e = newDicomElement(DCM_ImageDisplayFormat);
 					e->putString(tmpStd.c_str());
+					if (!tmpStd.empty()) {
+						e->putString(tmpStd.c_str());
+					}
+					attrs.insert(e);
 				}
-				attrs.insert(e);
 				
 				{
 					seq = new DcmSequenceOfItems(DCM_ReferencedFilmSessionSequence);
@@ -321,44 +332,60 @@ CONDITION PrintAssociation::Print(DicomServer* server, const std::string& local_
 					attrs.insert(seq);
 				}
 				
-				
-				e = newDicomElement(DCM_FilmOrientation);
 				if (film.getTag(GKDCM_FilmOrientation, tmpStd)) {
+					e = newDicomElement(DCM_FilmOrientation);
 					e->putString(tmpStd.c_str());
+					if (!tmpStd.empty()) {
+						e->putString(tmpStd.c_str());
+					}
+					attrs.insert(e);
 				}
-				attrs.insert(e);
 				
 				
-				e = newDicomElement(DCM_FilmSizeID);
 				if (film.getTag(GKDCM_FilmSizeID, tmpStd)) {
+					e = newDicomElement(DCM_FilmSizeID);
 					e->putString(tmpStd.c_str());
+					if (!tmpStd.empty()) {
+						e->putString(tmpStd.c_str());
+					}
+					attrs.insert(e);
 				}
-				attrs.insert(e);
 				
-				e = newDicomElement(DCM_MagnificationType);
 				if (film.getTag(GKDCM_MagnificationType, tmpStd)) {
+					e = newDicomElement(DCM_MagnificationType);
 					e->putString(tmpStd.c_str());
+					if (!tmpStd.empty()) {
+						e->putString(tmpStd.c_str());
+					}
+					attrs.insert(e);
 				}
-				attrs.insert(e);
 
-				e = newDicomElement(DCM_Trim);
 				if (film.getTag(GKDCM_Trim, tmpStd)) {
+					e = newDicomElement(DCM_Trim);
 					e->putString(tmpStd.c_str());
+					if (!tmpStd.empty()) {
+						e->putString(tmpStd.c_str());
+					}
+					attrs.insert(e);
 				}
-				attrs.insert(e);
 				
-				e = newDicomElement(DCM_BorderDensity);
 				if (layout.getTag(GKDCM_BorderDensity, tmpStd)) {
+					e = newDicomElement(DCM_BorderDensity);
 					e->putString(tmpStd.c_str());
+					if (!tmpStd.empty()) {
+						e->putString(tmpStd.c_str());
+					}
+					attrs.insert(e);
 				}
-				attrs.insert(e);
 
-				
-				e = newDicomElement(DCM_EmptyImageDensity);
 				if (layout.getTag(GKDCM_EmptyImageDensity, tmpStd)) {
+					e = newDicomElement(DCM_EmptyImageDensity);
 					e->putString(tmpStd.c_str());
+					if (!tmpStd.empty()) {
+						e->putString(tmpStd.c_str());
+					}
+					attrs.insert(e);
 				}
-				attrs.insert(e);
 				
 				OFString filmBoxSOPInstanceUID;
 				c = createRQ(UID_BasicFilmBoxSOPClass, filmBoxSOPInstanceUID, &attrs, rstatus, response);
