@@ -854,14 +854,11 @@ namespace GIL {
 
 		DicomStoreAssociation::~DicomStoreAssociation()
 		{
-#ifdef _WIN32
-			WSACleanup();
-#endif
 			//no limpiamos no sea que los haya registrado otro que no seamos nosotros!!!
 			FreeMemory();
 		}
 
-		void DicomStoreAssociation::Store(ListaRutas listaFicheros, DicomServer* server, std::string nombreAETLocal,GNC::IProxyNotificadorProgreso* pNotificador, GIL::DICOM::TipoTransferSyntaxEnvio transferSyntax)
+		void DicomStoreAssociation::Store(ListaRutas listaFicheros, const GNC::GCS::Ptr<DicomServer>& server, std::string nombreAETLocal,GNC::IProxyNotificadorProgreso* pNotificador, GIL::DICOM::TipoTransferSyntaxEnvio transferSyntax)
 		{
 			if (listaFicheros.size() == 0)
 				return;
@@ -1082,15 +1079,6 @@ namespace GIL {
 				LOG_WARN(LOGGER, "Warning: no data dictionary loaded, check environment variable");
 			}
 
-#ifdef _WIN32
-			WORD wVersionRequested;
-			WSADATA wsaData;
-
-			wVersionRequested = MAKEWORD(1, 1);
-
-			WSAStartup(wVersionRequested, &wsaData);
-#endif
-
 			/* initialize network, i.e. create an instance of T_ASC_Network*. */
 
 			cond = ASC_initializeNetwork(NET_REQUESTOR, puerto, opt_acse_timeout, &net);
