@@ -685,7 +685,7 @@ namespace GIL
 			// try to parse group and element number
 			n = sscanf(s, "%x|%x=%s", &g, &e, val);
 			OFString toParse = s;
-			unsigned long eqPos = toParse.find('=');
+			size_t eqPos = toParse.find('=');
 			if (n < 2) // if at least no tag could be parsed
 			{
 				// if value is given, extract it (and extrect dictname)
