@@ -20,12 +20,16 @@
 #include <main/controllers/dicommanager.h>
 #include <api/dicom/dicomdataset.h>
 #include <api/dicom/dcmdictionary.h>
+#include <api/ivista.h>
+#include <main/gui/mainwindow/ventanaprincipal.h>
+#include <main/entorno.h>
 
 #include <wx/xml/xml.h>
 #include <wx/mstream.h>
 #include <wx/sstream.h>
 #include <wx/regex.h>
 #include <wx/sizer.h>
+#include <wx/display.h>
 
 #define HP_DOCUMENT_ROOT wxT("hanging-protocols")
 
@@ -40,9 +44,16 @@
 #define HP_ATT_MODE_ID wxT("mode")
 #define HP_ATT_ACTIVE wxT("active")
 
+#define LOS_ROOT wxT("layouts")
 #define LO_ROOT wxT("layout")
 #define LO_ATT_ROWS wxT("rows")
 #define LO_ATT_COLUMNS wxT("columns")
+#define LO_ATT_DETACHED wxT("detached")
+#define LO_ATT_MAXIMIZED wxT("maximized")
+#define LO_ATT_X_POS wxT("x-pos")
+#define LO_ATT_Y_POS wxT("y-pos")
+#define LO_ATT_WIDTH wxT("width")
+#define LO_ATT_HEIGHT wxT("height")
 
 #define MC_ROOT wxT("matcher")
 #define MC_ATT_CRITERIA wxT("criteria")
@@ -185,7 +196,7 @@ void GNC::GCS::Matcher::setMatchingCriteria(const std::map<std::string, std::str
 /**
 Defines a specific layout, is recursive to allow splitted cells
 */
-GNC::GCS::Layout::Layout():rows(1), columns(1)
+GNC::GCS::Layout::Layout():rows(1), columns(1),isDetached(false)
 {
 }
 
@@ -198,6 +209,25 @@ GNC::GCS::Layout::Layout(wxXmlNode* layoutRoot)
 	if (layoutRoot->GetAttribute(LO_ATT_COLUMNS, wxT("1")).ToLong(&tmp)) {
 		columns = tmp;
 	}
+	wxString foo;
+	if (layoutRoot->GetAttribute(LO_ATT_DETACHED, &foo)) {
+		this->isDetached = true;
+		isMaximized = layoutRoot->GetAttribute(LO_ATT_MAXIMIZED, &foo);
+		if (layoutRoot->GetAttribute(LO_ATT_X_POS, wxT("-1")).ToLong(&tmp)) {
+			xPos = tmp;
+		}
+		if (layoutRoot->GetAttribute(LO_ATT_Y_POS, wxT("-1")).ToLong(&tmp)) {
+			yPos = tmp;
+		}
+		if (layoutRoot->GetAttribute(LO_ATT_WIDTH, wxT("-1")).ToLong(&tmp)) {
+			width = tmp;
+		}
+		if (layoutRoot->GetAttribute(LO_ATT_HEIGHT, wxT("-1")).ToLong(&tmp)) {
+			height = tmp;
+		}
+	} else {
+		this->isDetached = false;
+	}
 
 	for (wxXmlNode* child = layoutRoot->GetChildren(); child != NULL; child = child->GetNext())
 	{
@@ -230,6 +260,12 @@ GNC::GCS::Layout::Layout(const Layout& other)
 	this->properties = other.properties;
 	this->columns = other.columns;
 	this->rows = other.rows;
+	this->isDetached = other.isDetached;
+	this->isMaximized = other.isMaximized;
+	this->xPos = other.xPos;
+	this->yPos = other.yPos;
+	this->width = other.width;
+	this->height = other.height;
 }
 
 GNC::GCS::Layout::~Layout()
@@ -266,6 +302,17 @@ wxXmlNode* GNC::GCS::Layout::serialize()
 		propertyNode->AddAttribute(PROPERTY_VALUE, wxString::FromUTF8((*it).second.c_str()));
 	}
 
+	if (isDetached) {
+		layoutNode->AddAttribute(LO_ATT_DETACHED, wxEmptyString);
+		if (isMaximized) {
+			layoutNode->AddAttribute(LO_ATT_MAXIMIZED, wxEmptyString);
+		}
+		layoutNode->AddAttribute(LO_ATT_X_POS, wxString::Format(wxT("%d"), this->xPos));
+		layoutNode->AddAttribute(LO_ATT_Y_POS, wxString::Format(wxT("%d"), this->yPos));
+		layoutNode->AddAttribute(LO_ATT_WIDTH, wxString::Format(wxT("%d"), this->width));
+		layoutNode->AddAttribute(LO_ATT_HEIGHT, wxString::Format(wxT("%d"), this->height));
+	}
+
 	return layoutNode;
 }
 
@@ -437,8 +484,100 @@ void GNC::GCS::Layout::setProperties(const std::map<std::string, std::string>& p
 	this->properties = properties;
 }
 
+GNC::GCS::HangingProtocol* GNC::GCS::Layout::getParent()
+{
+	return pParent;
+}
+
+void GNC::GCS::Layout::setParent(GNC::GCS::HangingProtocol* pH)
+{
+	pParent = pH;
+}
+
+void GNC::GCS::Layout::setDefaultPosition()
+{
+	isDetached = false;
+}
+
+void GNC::GCS::Layout::setWindowProperties(bool isMaximized, int xPos, int yPos, int width, int height)
+{
+	this->isDetached = true;
+	this->isMaximized = isMaximized;
+	this->xPos = xPos;
+	this->yPos = yPos;
+	this->width = width;
+	this->height = height;
+}
+
+void GNC::GCS::Layout::copyWindowProperties(const GNC::GCS::Layout& other)
+{
+	this->isDetached = other.isDetached;
+	this->isMaximized = other.isMaximized;
+	this->xPos = other.xPos;
+	this->yPos = other.yPos;
+	this->width = other.width;
+	this->height = other.height;
+}
+
+void GNC::GCS::Layout::applyWindowProperties(wxWindow* pWindow)
+{
+	if (isDetached) {
+		int maxX = 0, maxY = 0;
+		int deviceCount = wxDisplay::GetCount();
+		for (int i = 0; i < deviceCount; ++i) {
+			wxDisplay dsply(i);
+			maxX = std::max<int>(maxX, dsply.GetClientArea().x + dsply.GetCurrentMode().GetWidth());
+			maxY = std::max<int>(maxY, dsply.GetClientArea().y + dsply.GetCurrentMode().GetHeight());
+		}
+		wxPoint position(xPos, yPos);
+		if (position.x > -50 && position.x  < maxX 
+			&& position.y > -50 && position.y < maxY) {
+			pWindow->SetPosition(position);
+		}
+		wxSize size(width, height);
+		wxTopLevelWindow* pTopLevel = dynamic_cast<wxTopLevelWindow*>(pWindow);
+		if (pTopLevel != NULL) {
+			pTopLevel->Maximize(isMaximized);
+			if (!isMaximized) {
+				pWindow->SetSize(size);
+			}
+		} else {
+			pWindow->SetSize(size);
+		}
+		
+	}
+}
+
+void GNC::GCS::Layout::applyWindowProperties(GNC::GCS::IVista* pView)
+{
+	//detach view...
+	wxWindow* pWindow = pView->GetWindow();
+	if(pWindow != NULL) {
+		wxWindow* pParentWindow = pWindow->GetParent();
+		if(pParentWindow != NULL) {
+			wxFrame* pdlg = dynamic_cast<wxFrame*>(pParentWindow);
+			if(pdlg != NULL) {
+				//it is detached
+				if (!isDetached) {
+					//undetach
+					GNC::Entorno::Instance()->GetVentanaPrincipal()->EncajarDesencajar(pView);
+				}
+			}
+			else {
+				//it isn't detached
+				if (isDetached) {
+					//detach
+					GNC::Entorno::Instance()->GetVentanaPrincipal()->EncajarDesencajar(pView);
+					//apply properties
+					applyWindowProperties(pWindow->GetParent());
+				}
+			}
+		}
+	}
+}
+
 /////////////////////////////////////////////////////
-GNC::GCS::HangingProtocol::HangingProtocol()
+GNC::GCS::HangingProtocol::HangingProtocol():active(true)
 {
 }
 
@@ -456,9 +595,19 @@ GNC::GCS::HangingProtocol::HangingProtocol(wxXmlNode* hangingNode)
 	}
 	for (wxXmlNode* child = hangingNode->GetChildren(); child != NULL; child = child->GetNext())
 	{
-		if (child->GetName().CmpNoCase(LO_ROOT) == 0) {
-			this->layout = new Layout(child);
-		} else if (child->GetName().CmpNoCase(MC_ROOT) == 0) {
+		if (child->GetName().CmpNoCase(LOS_ROOT) == 0) {
+			//layouts...
+			for (wxXmlNode* layoutChild = child->GetChildren(); layoutChild != NULL; layoutChild = layoutChild->GetNext()) {
+				if (layoutChild->GetName().CmpNoCase(LO_ROOT) == 0) {
+					GNC::GCS::Ptr<Layout> pLayout(new Layout(layoutChild));
+					this->addLayout(pLayout);
+				}
+			}			
+		} else if (child->GetName().CmpNoCase(LO_ROOT) == 0)  {
+			//retrocompatib...
+			GNC::GCS::Ptr<Layout> pLayout(new Layout(child));
+			this->addLayout(pLayout);
+		}else if (child->GetName().CmpNoCase(MC_ROOT) == 0) {
 			this->studyMatcher = new Matcher(child);
 		} else if (child->GetName().CmpNoCase(PROPERTY_NODE) == 0) {
 			const wxString key = child->GetAttribute(PROPERTY_KEY, wxEmptyString);
@@ -481,8 +630,10 @@ GNC::GCS::HangingProtocol::HangingProtocol(const GNC::GCS::HangingProtocol& othe
 	if (other.studyMatcher.IsValid()) {
 		this->studyMatcher = new Matcher(*other.studyMatcher);
 	}
-	if (other.layout.IsValid()) {
-		this->layout = new Layout(*other.layout);
+	for (GNC::GCS::HangingProtocol::TListOfLayouts::const_iterator it = other.layouts.begin(); it != other.layouts.end(); ++it) {
+		if ((*it).IsValid()) {
+			this->layouts.push_back(new Layout(*(*it)));
+		}
 	}
 	this->properties = other.properties;
 	this->active = other.active;
@@ -501,8 +652,11 @@ wxXmlNode* GNC::GCS::HangingProtocol::serialize()
 	hangingNode->AddAttribute(HP_ATT_MODULE_SID, wxString::FromUTF8(this->moduleSid.c_str()));
 	hangingNode->AddAttribute(HP_ATT_MODE_ID, wxString::Format(wxT("%d"), this->openingMode));
 	hangingNode->AddAttribute(HP_ATT_ACTIVE, active?wxT("true"):wxT("false"));
-	if (this->layout.IsValid()) {
-		hangingNode->AddChild(this->layout->serialize());
+	wxXmlNode* layoutsNode = new wxXmlNode(hangingNode, wxXML_ELEMENT_NODE, LOS_ROOT);
+	for (GNC::GCS::HangingProtocol::TListOfLayouts::const_iterator it = layouts.begin(); it != layouts.end(); ++it) {
+		if ((*it).IsValid()) {
+			layoutsNode->AddChild((*it)->serialize());
+		}
 	} 
 	if (this->studyMatcher.IsValid()) {
 		hangingNode->AddChild(this->studyMatcher->serialize());
@@ -578,14 +732,22 @@ void GNC::GCS::HangingProtocol::setStudyMatcher(const GNC::GCS::Ptr<GNC::GCS::Ma
 	this->studyMatcher = matcher;
 }
 
-const GNC::GCS::Ptr<GNC::GCS::Layout>& GNC::GCS::HangingProtocol::getLayout()
+const GNC::GCS::HangingProtocol::TListOfLayouts& GNC::GCS::HangingProtocol::getLayouts()
 {
-	return this->layout;
+	return this->layouts;
 }
 
-void GNC::GCS::HangingProtocol::setLayout(const GNC::GCS::Ptr<GNC::GCS::Layout>& layout)
+void GNC::GCS::HangingProtocol::addLayout(const GNC::GCS::Ptr<GNC::GCS::Layout>& layout)
 {
-	this->layout = layout;
+	if (layout.IsValid()) {
+		layout->setParent(this);
+		this->layouts.push_back(layout);
+	}
+}
+
+void GNC::GCS::HangingProtocol::clearLayouts()
+{
+	this->layouts.clear();
 }
 
 std::map<std::string, std::string>& GNC::GCS::HangingProtocol::getProperties()
