@@ -177,17 +177,19 @@ namespace GNC {
 			//region "metodos propios del historial"
 			bool AddFiles(const StringList& listaPaths, TAddErrorList& errorList, std::list<long>* insertedSeries, GNC::IProxyNotificadorProgreso* pNotificador = NULL, TAddAction action = TAA_COPY);
 			bool UpdateFiles(const GNC::GCS::HistoryController::FileModelList& files);
+			bool LinkFilesToSeries(long seriesPk, GNC::GCS::HistoryController::DICOMFileModelList& files, GNC::IProxyNotificadorProgreso* pNotificador = NULL);
 		protected:
 			bool UpdateFileModel(FileModel& fileModel);
 			void FindOrInsertStudy(DICOMFileModel& model);
 			void FindOrInsertSeries(DICOMFileModel& model);
 			bool FindOrInsertFile(DICOMFileModel& model);
+			bool FindOrLink(DICOMFileModel& model);
 
 			void UpdateStudy(DICOMFileModel& model);
 			void UpdateSeries(DICOMFileModel& model);
 			void UpdateFile(DICOMFileModel& model);
 
-			void GetPathOfFile(FileModel& fileModel);
+			std::string GetPathOfFile(GNC::GCS::IHistoryController::TLocation location, long pk, const std::string& file_path);
 			std::string GetPathOfFile(long file_pk);
 			std::string GetRelativePath(const std::string& absolutePath);
 			std::string GetAbsolutePath(const std::string& relativePath);
@@ -200,6 +202,7 @@ namespace GNC {
 			void GetSeriesModelFromUID(const std::string& uids, SeriesModelList& series);
 			void GetSeriesFromStudy(long study_pk, SeriesModelList& listOfSeries);
 			StudyModel GetStudyModel(long study_pk);
+			void GetStudyModelFromUID(const std::string& uids, StudyModelList& studies);
 			/**
 			gets dicom tags from study stored in database
 			*/
@@ -214,14 +217,18 @@ namespace GNC {
 			void GetAllPatients(GNC::GCS::HistoryController::PatientModelList& patientList);
 			
 			bool ExistsSeriesWithUID(const std::string& seriesUID);
+			bool ExistsStudyWithUID(const std::string& studyUID);
 			int GetNumberOfFiles();
-			void GetSeriesSortedFileModels(long series_pk, FileModelList& fileList, bool onlyFirst = false);
+			/**this method take a lot of time, if you don't need verbose information, use LightFileModelList...**/
+			virtual void GetSeriesSortedFileModels(long series_pk, FileModelList& fileList, bool onlyFirst = false);
+			virtual void GetSeriesSortedFileModels(long series_pk, LightFileModelList& fileList, bool onlyFirst = false);
 			StringList GetSeriesSortedPathsByUID(const std::string& seriesUID);
 			StringList GetSeriesSortedPaths(const std::string& series_pk);
 			StringList GetSeriesSortedPaths(long series_pk);
 			char GetSeriesOrientation(long series_pk);
 
 			bool DeleteSeriesList(const IdList& pks);
+			bool DeleteSopInstanceUIDs(const StringList& sopInstanceUIds);
 
 			bool EmptyHistory(bool eliminarDelDisco);
 		//	//thumbnails...
@@ -243,6 +250,7 @@ namespace GNC {
 		//	//region "helpers"
 		//	//devuelve false si !copia y no esta donde deberia
 		public:
+			bool ReadFile(DICOMFileModel& modelo,const std::string& pathAbsoluto, TAddErrorList& errorList, TAddAction action);
 			bool ReadFile(DICOMFileModel& modelo,const std::string& pathAbsoluto, TAddErrorList& errorList);
 
 		protected:
