@@ -16,24 +16,29 @@
 
 #include <wx/statbmp.h>
 #include <wx/bmpbuttn.h>
+#include <wx/uri.h>
 
 #include "integrationcontroller.h"
 #include "controladorlog.h"
 #include "controladorextensiones.h"
 #include "controladoreventos.h"
-#include "controladorcomandos.h"
+#include "commandcontroller.h"
 #include "controladorhl7.h"
 #include "configurationcontroller.h"
+#include <commands/cloudcommand.h>
 #include <api/integration/dict.h>
+#include <api/dicom/dcmdictionary.h>
 #include <main/controllers/controladorpermisos.h>
 #include <main/gui/import/wxwizardimportacionginkgo.h>
 #include <main/gui/acquisition/dialogoadquisicion.h>
+#include <main/gui/acquisition/downloadagaindialog.h>
 #include <main/gui/mainwindow/ventanaprincipal.h>
 #include <main/entorno.h>
-#include <commands/comandopacs.h>
+#include <commands/pacsdownloadcommand.h>
 #include <eventos/integration.h>
 #include <main/controllers/parserxmlenglish.h>
 #include <main/controllers/parserxmlspanish.h>
+#include <main/controllers/historycontroller.h>
 #include <wx/filename.h>
 #include <wx/sstream.h>
 #include <wx/tokenzr.h>
@@ -148,7 +153,7 @@ bool GIL::IntegrationController::Process(GIL::IntegrationModelList& models)
 		}
 		else if(modelo->accion == GIL::IModeloIntegracion::TA_Obtener) 
 		{
-			GADAPI::ComandoPACSParams * pParams = NULL;
+			GADAPI::PACSDownloadCommandParams * pParams = NULL;
 			std::string tag;
 			if (!modelo->TagsDICOMOverwrite.getTag("0008|0052", tag)) {
 				//show only acquisition form
@@ -157,11 +162,25 @@ bool GIL::IntegrationController::Process(GIL::IntegrationModelList& models)
 				numProcessed++;
 			} else {
 				GIL::DICOM::DicomDataset base = modelo->TagsDICOMOverwrite;
-				pParams = new GADAPI::ComandoPACSParams(modelo->GlobalVariables.GetValue(GKDI_GLOBAL_PACS_RETRIEVE_SID), base);
-				pParams->m_informar = true;
+				std::string qrlevel, uid;
+				base.getTag(GKDCM_QueryRetrieveLevel,qrlevel);
+				if (qrlevel == "STUDY" && base.getTag(GKDCM_StudyInstanceUID, uid) && GNC::GCS::HistoryController::Instance()->ExistsStudyWithUID(uid)) {
+					GNC::GUI::DownloadAgainDialog dlg(GNC::Entorno::Instance()->GetVentanaRaiz(), uid, false);
+					int answer = dlg.ShowModal();
+					if (answer != wxID_OK) {
+						continue;
+					}
+				} else if (qrlevel == "SERIES" && base.getTag(GKDCM_SeriesInstanceUID, uid) && GNC::GCS::HistoryController::Instance()->ExistsSeriesWithUID(uid)) {
+					GNC::GUI::DownloadAgainDialog dlg(GNC::Entorno::Instance()->GetVentanaRaiz(), uid, false);
+					int answer = dlg.ShowModal();
+					if (answer != wxID_OK) {
+						continue;
+					}
+				}
+				pParams = new GADAPI::PACSDownloadCommandParams(modelo->GlobalVariables.GetValue(GKDI_GLOBAL_PACS_RETRIEVE_SID), base);
 
-				GADAPI::ComandoPACS* pComandoPACS = new GADAPI::ComandoPACS(pParams);
-				GNC::Entorno::Instance()->GetControladorComandos()->ProcessAsync("Descargando PACS...",pComandoPACS, NULL);
+				GADAPI::PACSDownloadCommand* pComandoPACS = new GADAPI::PACSDownloadCommand(pParams);
+				GNC::Entorno::Instance()->GetCommandController()->ProcessAsync("Descargando PACS...",pComandoPACS, NULL);
 				GNC::Entorno::Instance()->GetVentanaPrincipal()->MostrarVentana();
 				numProcessed++;
 			} 
@@ -544,7 +563,7 @@ std::string GIL::IntegrationController::GetIdPlantilla(const std::string& uidMod
 
 
 /* Parsea la cadena XML y construye el modelo de integracion. Los parametros no encontrados se asignan por defecto segun lo especificado en la configuracion global */
-void GIL::IntegrationController::ParsearModeloIntegracion(GIL::IntegrationModelList& modelos, const std::string& xmlString, const wxString& relativePath) const
+void GIL::IntegrationController::ParsearModeloIntegracion(GIL::IntegrationModelList& modelos, const std::string& xmlString, const wxString& configurationFilePath) const
 {
 	GTRACE("GIL::HL7::ControladorHL7::ParsearModeloIntegracion( modelo, [\n" << xmlString.c_str() << "\n] )");
 	wxXmlDocument xml;
@@ -572,14 +591,19 @@ void GIL::IntegrationController::ParsearModeloIntegracion(GIL::IntegrationModelL
 
 	if (m_mapParsers.find(parserKey) != m_mapParsers.end()) {
 		m_mapParsers.find(parserKey)->second->ParseIntegrationXML(modelos, raiz);
+		wxFileName absoluteFile(configurationFilePath.c_str());
+		if (absoluteFile.FileExists()) {
+			absoluteFile = absoluteFile.GetPath();
+		}
+
 		for (GIL::IntegrationModelList::iterator it = modelos.begin(); it != modelos.end(); ++it) {
 			GNC::GCS::Ptr<GIL::IModeloIntegracion>& modelo = (*it);
 			GIL::IModeloIntegracion::ListOfPaths absoluteFiles;
 			for (GIL::IModeloIntegracion::ListOfPaths::iterator itFile = modelo->Files.begin(); itFile != modelo->Files.end(); ++itFile) 
 			{
 				wxFileName fileName(wxString::FromUTF8((*itFile).c_str()));
-				if (fileName.IsRelative()) {
-					fileName.MakeAbsolute(relativePath);
+				if (fileName.IsRelative() && absoluteFile.IsOk()) {
+					fileName.MakeAbsolute(absoluteFile.GetFullPath());
 				}						
 				std::string pathStd(fileName.GetFullPath().ToUTF8());
 				absoluteFiles.push_back(pathStd);
@@ -594,3 +618,228 @@ void GIL::IntegrationController::ParsearModeloIntegracion(GIL::IntegrationModelL
 	}
 }
 
+std::string GIL::IntegrationController::ParsesModelFromURL(const wxString& url) const
+{
+	//parse ginkgo cloud uris
+	if (url.StartsWith(wxT("ginkgocadx://cloud:"))) {
+		GNC::GCS::CloudGetCommandParams* pParams = new GNC::GCS::CloudGetCommandParams(std::string(url.SubString(19, url.size() - 1).ToUTF8()), true);
+		GNC::GCS::CloudCommand* pCmd = new GNC::GCS::CloudCommand(pParams);
+		GNC::CommandController::Instance()->ProcessAsync("Downloading",pCmd, NULL);
+
+		return "";
+	}
+
+	//  ginkgocadx://?pacs=dicom%3A%2F%2FDCM4CHEE%40ironman%3A11112%3Fmethod%3Dget%26mode%3Dseries&action=retrieve&level=STUDY&query=0020%7C000D%3A1.3.6.1.4.1.39470.1.1.3.0.1.2.2259150805.5724.1353416100.533&aid=JIMENA
+	// ginkgocadx://?pacs=dicom%3A%2F%2FDCM4CHEE%40ironman%3A11112%3Fmethod%3Dget%26mode%3Dseries&action=dicomize&petition-id=asdf&scope=AA&patient-id=234234&episode-number=asewr&query
+	// ginkgocadx://?pacs=dicom%3A%2F%2FDCM4CHEE%40ironman%3A11112%3Fmethod%3Dget%26mode%3Dseries&action=dicomize&patient-id=234234&query=0010%7C0040%3AM&query=0010%7C0010%3ADoe%5Ejoe%20Charl
+
+		
+	// ginkgocadx://?action=retrieve&pacs=test&level=STUDY&query=0020|000D:1.2.3.4.5.6 de un pacs id
+	// ginkgocadx://?action=retrieve&level=STUDY&query=0020|000D:1.2.3.4.5.6  | del pacs por defecto
+	/*
+	<?xml version="1.0" encoding="UTF-8"?>
+	<gnkworkflows>
+        <!-- Configuracion de PACS, estos son opcionales y se pueden declarar tantos como uno quiera. -->        
+        <pacs sid="test" aet="DCM4CHEE" hostname="172.26.0.3" port="11112" tls="no" verify-credentials="no" retrieve-method="get" pdu="16384" retrieve-mode="series">
+        <!--sid: Identificador del pacs(obligatorio) -->
+        <!--aet: Application entity title (obligatorio) -->
+        <!--hostname: hostname o ip (obligatorio) -->
+        <!--port: puerto del PACS (obligatorio) -->
+        <!--tls (yes/no): usar tls. (por defecto no) -->
+        <!--verify-credentials (yes/no): Verificar credenciales del servidor PACS. (por defecto no) -->
+        <!--retrieve-method (get/move): Metodo de descargar del pacs (por defecto get) -->
+        
+        <!--retrieve-mode (series/studies): Modo de obtencion (por defecto series) -->
+		<!--pdu: Tamanio de la PDU. (por defecto=16384) -->
+        <!--pacs-user: Usuario de acceso al pacs. -->
+        <!--pacs-password: Password de acceso al PACS  -->
+		<gnkworkflow action="retrieve" pacs-retrieve-sid="test">
+        <!-- action: flujo de trabajo a ejecutar {dicomize, retrieve} -->        
+        <!-- pacs-retrieve-sid: Identificador del PACS del que se va a descargar la prueba. Puede ser uno almacenado en ginkgo cadx o alguno declarado anteriormente. Si no se especifica ninguno se utiliza el PACS por defecto. -->
+        
+				<!-- Nivel de consulta en el PACS (obligatorio) -->
+                <query-retrieve-level value="STUDY"/>
+				<!-- query-retrieve-level modos: {PATIENT, STUDY, SERIES, IMAGE} -->
+
+                <!-- Metadatos para realizar la consulta en el PACS (obligatorio) -->				
+                <metadata code="DICOM" key="0020|000D" value="1.2.3.4.5.6" />   <!-- StudyInstanceUID -->
+				<!--code: tipo de codigo, solo esta soportado DICOM (obligatorio) -->
+				<!--key: clave a buscar (obligatorio) -->
+				<!--value: valor (obligatorio) -->				
+				<!-- Ejemplo SeriesInstanceUID: <metadata code="DICOM" key="0020|000E" value="2.18.840.1.113883.5.242.33.14.3.10110519171259.709.76244" /> -->
+				<!-- Ejemplo AccessionNumber: <metadata code="DICOM" key="0008|0050" value="2011-27843782" /> -->         
+                
+				<!-- Aplicacion que genera la llamada. Se usa para mensajeria y LOG (en este caso no hay mensajeria con esta operacion) (obligatorio) -->
+                <hce aid="JIMENA" />      
+        </gnkworkflow>
+		*/
+	// ginkgocadx://?action=retrieve&level=STUDY&query=0020|000D:1.2.3.4.5.6&aid=JIMENA
+
+	wxURI uri(url);
+	wxString query = uri.GetQuery();
+	std::string xmlIntegration;
+	if (!query.IsEmpty()) 
+	{
+		std::map<std::string, std::string> parameters;
+		std::list<std::string> listOfQueries; //query is an special multivalued parameter...
+		wxStringTokenizer tknzr(query, wxT("&"));
+		while (tknzr.HasMoreTokens()){
+			wxString token = tknzr.GetNextToken();
+			if (token.StartsWith(wxT("query="))) {
+				//special multivalued parameter...
+				int pos = token.Find(wxT("="));
+				listOfQueries.push_back(std::string(wxURI::Unescape(token.SubString(pos+1, token.size() - 1)).ToUTF8()));
+			} else {
+				if (token.Contains(wxT("="))) {
+					int pos = token.Find(wxT("="));
+					parameters[std::string(token.SubString(0, pos-1).Lower().ToUTF8())] = std::string(wxURI::Unescape(token.SubString(pos+1, token.size() - 1)).ToUTF8());
+				} else {
+					parameters[std::string(token.Lower().ToUTF8())] = "";
+				}
+			}
+		}
+		wxXmlDocument doc;
+		doc.SetFileEncoding(wxT("UTF-8"));
+		doc.SetRoot(new wxXmlNode(NULL,wxXML_ELEMENT_NODE,wxT("gnkworkflows")));
+		//pacs parsing...
+		//pacs configuration from url is simple, you can configure:
+		//pacs=pacsid
+		//pacs=dicom://AET@host:port&method=<get/move>&mode=<STUDY/SERIES>
+		//pacs=dicom://DCM4CHEE@172.26.0.33:11112?method=WADO&wadourl=http://172.26.0.33:18080/wado => pacs=dicom://DCM4CHEE@172.26.0.33:11112?method=WADO&urlWado=http%3A%2F%2F172.26.0.33%3A18080%2Fwado
+		wxString pacsSid;
+		if (parameters.find("pacs") != parameters.end()) {			
+			wxString pacsParameter = wxString::FromUTF8(parameters["pacs"].c_str());
+			if (pacsParameter.StartsWith(wxT("dicom://"))) {
+				wxXmlNode* pacsNode = new wxXmlNode(doc.GetRoot(), wxXML_ELEMENT_NODE, wxT("pacs"));
+				//randomSid
+				pacsSid =  wxString::Format(wxT("temppacs%d"), rand());
+				pacsNode->AddProperty(wxT("sid"),pacsSid);
+				//parse url...
+				wxURI pacsUri(pacsParameter);
+
+				if (pacsUri.GetUserInfo().IsEmpty() || pacsUri.GetServer().IsEmpty()) {
+					throw IntegrationException("Error in pacs url format: dicom://AET@host:port", "URLPARSER");
+				}
+				pacsNode->AddProperty(wxT("aet"), pacsUri.GetUserInfo());
+				pacsNode->AddProperty(wxT("hostname"), pacsUri.GetServer());
+				if (!pacsUri.GetPort().IsEmpty()) {
+					pacsNode->AddProperty(wxT("port"), pacsUri.GetPort());
+				}
+
+				//tokenize query &
+				wxStringTokenizer dicomTknzr(pacsUri.GetQuery(), wxT("&"));
+				while (dicomTknzr.HasMoreTokens()){
+					wxString token = dicomTknzr.GetNextToken();
+					if (token.StartsWith(wxT("method="))) {
+						int pos = token.Find(wxT("="));
+						pacsNode->AddProperty(wxT("retrieve-method"),wxURI::Unescape(token.SubString(pos+1, token.size() - 1)));
+					}
+					if (token.StartsWith(wxT("mode="))) {
+						int pos = token.Find(wxT("="));
+						pacsNode->AddProperty(wxT("retrieve-mode"),wxURI::Unescape(token.SubString(pos+1, token.size() - 1)));
+					}
+					if (token.StartsWith(wxT("wadourl="))) {
+						int pos = token.Find(wxT("="));
+						pacsNode->AddProperty(wxT("wado-url"),wxURI::Unescape(token.SubString(pos+1, token.size() - 1)));
+					}
+				}				
+			} else {
+				pacsSid = pacsParameter;
+			}	
+		}
+		//action parsing...
+		if (parameters.find("action") != parameters.end()) 
+		{
+			wxXmlNode* workFlowNode = new wxXmlNode(doc.GetRoot(), wxXML_ELEMENT_NODE, wxT("gnkworkflow"));
+			if (parameters["action"]=="retrieve") 
+			{
+				//retrieve
+				//action=retrieve&aid=JIMENA&query=group|element:value
+				workFlowNode->AddProperty(wxT("action"), wxT("retrieve"));
+				if (!pacsSid.IsEmpty()) {
+					workFlowNode->AddProperty(wxT("pacs-retrieve-sid"), pacsSid);
+				}
+				//retrieve..
+				//parse level and query...
+				if (parameters.find("level") != parameters.end()) {
+					wxXmlNode* qrLevel = new wxXmlNode(workFlowNode, wxXML_ELEMENT_NODE, wxT("query-retrieve-level"));
+					qrLevel->AddProperty(wxT("value"), wxString::FromUTF8(parameters["level"].c_str()));
+				}
+				//aid
+				if (parameters.find("aid") != parameters.end()) {
+					wxXmlNode* qrLevel = new wxXmlNode(workFlowNode, wxXML_ELEMENT_NODE, wxT("hce"));
+					qrLevel->AddProperty(wxT("aid"), wxString::FromUTF8(parameters["aid"].c_str()));
+				}
+				//parse query...
+				//query=0020|000D:1.2.3.4.5.6
+				//<metadata code="DICOM" key="0020|000D" value="1.2.3.4.5.6" />
+				for (std::list<std::string>::iterator it = listOfQueries.begin(); it != listOfQueries.end(); ++it) {
+					wxString queryString = wxString::FromUTF8((*it).c_str());
+					int colonPosition = queryString.Find(wxT(":"));
+					if (colonPosition == -1) {
+						throw IntegrationException("Malformated query string: group|element:value", "URLPARSER");
+					}
+					wxXmlNode* queryNode = new wxXmlNode(workFlowNode, wxXML_ELEMENT_NODE, wxT("metadata"));
+					queryNode->AddProperty(wxT("code"), wxT("DICOM"));
+					queryNode->AddProperty(wxT("key"), queryString.SubString(0, colonPosition-1));
+					queryNode->AddProperty(wxT("value"), queryString.SubString(colonPosition+1, queryString.size() - 1));
+				}
+			} else if(parameters["action"] == "dicomize") {
+				//dicomize... 
+				//action=dicomize&petition-id=asdf&scope=AA&patient-id=234234&episode-number=asewr&query...
+				//action
+				workFlowNode->AddProperty(wxT("action"), wxT("dicomize"));
+				//pacs
+				if (!pacsSid.IsEmpty()) {
+					workFlowNode->AddProperty(wxT("pacs-store-sid"), pacsSid);
+				}
+				//petition-id
+				if (parameters.find("petition-id") != parameters.end()) {
+					workFlowNode->AddProperty(wxT("petition-id"), wxString::FromUTF8(parameters["petition-id"].c_str()));
+				}
+				//scope
+				if (parameters.find("scope") != parameters.end()) {
+					workFlowNode->AddProperty(wxT("scope"), wxString::FromUTF8(parameters["scope"].c_str()));
+				}
+				//patient...
+				if (parameters.find("patient-id") != parameters.end()) {
+					wxXmlNode* patientNode = new wxXmlNode(workFlowNode, wxXML_ELEMENT_NODE, wxT("patient"));
+					wxXmlNode* idNode = new wxXmlNode(patientNode, wxXML_ELEMENT_NODE, wxT("id"));
+					idNode->AddProperty(wxT("code"),wxT("PI"));
+					idNode->AddProperty(wxT("value"), wxString::FromUTF8(parameters["patient-id"].c_str()));
+					//episode-number
+					if (parameters.find("episode-number") != parameters.end()) {
+						wxXmlNode* episodeNumberNode = new wxXmlNode(patientNode, wxXML_ELEMENT_NODE, wxT("episode-number"));
+						new wxXmlNode(episodeNumberNode, wxXML_TEXT_NODE,wxT("content"),wxString::FromUTF8(parameters["episode-number"].c_str()));
+					}
+				} else {
+					throw IntegrationException("patient-id parameter is required in dicomization process", "URLPARSER");
+				}
+				//parse query...
+				//query=0020|000D:1.2.3.4.5.6
+				//<metadata code="DICOM" key="0020|000D" value="1.2.3.4.5.6" />
+				for (std::list<std::string>::iterator it = listOfQueries.begin(); it != listOfQueries.end(); ++it) {
+					wxString queryString = wxString::FromUTF8((*it).c_str());
+					int colonPosition = queryString.Find(wxT(":"));
+					if (colonPosition == -1) {
+						throw IntegrationException("Malformated query string: group|element:value", "URLPARSER");
+					}
+					wxXmlNode* queryNode = new wxXmlNode(workFlowNode, wxXML_ELEMENT_NODE, wxT("metadata"));
+					queryNode->AddProperty(wxT("code"), wxT("DICOM"));
+					queryNode->AddProperty(wxT("key"), queryString.SubString(0, colonPosition-1));
+					queryNode->AddProperty(wxT("value"), queryString.SubString(colonPosition+1, queryString.size() - 1));
+				}
+			} else {
+				throw IntegrationException("Unsupported action parameter", "URLPARSER");
+			}
+		}
+
+		wxStringOutputStream out;
+		doc.Save(out);
+		xmlIntegration = std::string(out.GetString().ToUTF8());
+		LOG_DEBUG("ItegrationController", "Generated XML\n"<<xmlIntegration);
+	}
+
+	return xmlIntegration;
+}
+
