@@ -67,12 +67,14 @@ void GIL::ParserXMLEnglish::ParseIntegrationXML(GIL::IntegrationModelList& model
 	MapaServers servers;
 	std::string xpp; // XML Pretty Printed for extended information info.
 	// PreCargamos la lista de PACS de la configuracion
-	for (DicomServerHolder* sl = DicomServerList::Instance()->GetList(); sl != NULL; sl = sl->next) {
+	DicomServerList::TServerList ListOfServers = DicomServerList::Instance()->GetServerList();
+	for (DicomServerList::TServerList::iterator it = ListOfServers.begin(); it != ListOfServers.end(); ++it)
+	{
 		IModeloPACSServer pacs;
-		pacs.sid = sl->server.ID;
-		pacs.AET = sl->server.AET;
-		pacs.hostname = sl->server.HostName;
-		pacs.puerto = sl->server.Port;
+		pacs.sid = (*it)->ID;
+		pacs.AET = (*it)->AET;
+		pacs.hostname = (*it)->HostName;
+		pacs.puerto = (*it)->Port;
 
 		servers[pacs.sid] = pacs;
 	}
@@ -137,6 +139,11 @@ void GIL::ParserXMLEnglish::ParseIntegrationXML(GIL::IntegrationModelList& model
 					pacsServer.password = propVal.ToUTF8();
 				}
 
+				propVal = nodo->GetPropVal(wxT("wado-url"), wxEmptyString);
+				if( !propVal.empty()) {
+					pacsServer.wadoURI = propVal.ToUTF8();
+				}
+
 				propVal = nodo->GetPropVal(wxT("verify-credentials"), wxEmptyString);
 				if( propVal.CmpNoCase(wxT("yes")) == 0 || propVal.CmpNoCase(wxT("true")) == 0 || propVal.CmpNoCase(wxT("si")) == 0 || propVal.CmpNoCase(wxT("1")) == 0 ) {
 					pacsServer.verify = true;
@@ -149,7 +156,9 @@ void GIL::ParserXMLEnglish::ParseIntegrationXML(GIL::IntegrationModelList& model
 				if( propVal.CmpNoCase(wxT("get")) == 0 ) {
 					pacsServer.metodo = GIL::IModeloPACSServer::IMPS_GET;
 				}
-				else {
+				else if (propVal.CmpNoCase(wxT("wado")) == 0) {
+					pacsServer.metodo = GIL::IModeloPACSServer::IMPS_WADO;
+				} else {
 					pacsServer.metodo = GIL::IModeloPACSServer::IMPS_MOVE;
 				}
 				
@@ -188,7 +197,7 @@ void GIL::ParserXMLEnglish::ParseIntegrationXML(GIL::IntegrationModelList& model
 
 				servers[pacsServer.sid] = pacsServer;
 				try{
-					DicomServer* server = DicomServerList::Instance()->GetServer(pacsServer.sid);
+					GNC::GCS::Ptr<DicomServer> server = DicomServerList::Instance()->GetServer(pacsServer.sid);
 					server->AET = pacsServer.AET;
 					server->HostName = pacsServer.hostname;
 					long puerto;
@@ -203,10 +212,12 @@ void GIL::ParserXMLEnglish::ParseIntegrationXML(GIL::IntegrationModelList& model
 						throw IntegrationException(_Std("Port is not a valid number"), xpp, "CONF/pacs");
 					}
 					if (pacsServer.metodo == GIL::IModeloPACSServer::IMPS_GET) {
-						server->retrieveWithMove = false;
+						server->retrieveMethod = DicomServer::GET;
 					}
-					else {
-						server->retrieveWithMove = true;
+					else if (pacsServer.metodo == GIL::IModeloPACSServer::IMPS_WADO) {
+						server->retrieveMethod = DicomServer::WADO;
+					} else {
+						server->retrieveMethod = DicomServer::MOVE;
 					}
 					server->retrieveSeries = wxString::FromUTF8(pacsServer.retrieveLevel.c_str()).CmpNoCase(wxT("SERIES")) == 0;
 					server->useTLS = pacsServer.tls;
@@ -215,6 +226,7 @@ void GIL::ParserXMLEnglish::ParseIntegrationXML(GIL::IntegrationModelList& model
 					server->privateKey  = pacsServer.key;
 					server->pacsUser = pacsServer.user;
 					server->pacsPass = pacsServer.password;
+					server->wadoURI = pacsServer.wadoURI;
 
 					DicomServerList::Instance()->SetDefaultServer(server->ID);
 
@@ -225,7 +237,13 @@ void GIL::ParserXMLEnglish::ParseIntegrationXML(GIL::IntegrationModelList& model
 						throw IntegrationException(_Std("The pdu size is not a valid number"), xpp, "CONF/pacs");
 					}
 					if(wxString::FromUTF8(pacsServer.puerto.c_str()).ToLong(&puerto)) {
-						DicomServerList::Instance()->AddServer( DicomServer(pacsServer.sid, pacsServer.AET, pacsServer.hostname, (int)puerto, 0, true, pdu, pacsServer.tls, pacsServer.user, pacsServer.password, pacsServer.metodo == GIL::IModeloPACSServer::IMPS_MOVE, wxString::FromUTF8(pacsServer.retrieveLevel.c_str()).Upper() == wxT("SERIES"), false, pacsServer.verify, pacsServer.cert, pacsServer.key, pacsServer.defaultCharset), true );
+						DicomServer::TRetrieveMethod retrieveMethod = DicomServer::MOVE;
+						if ( pacsServer.metodo == GIL::IModeloPACSServer::IMPS_GET) {
+							retrieveMethod = DicomServer::GET;
+						} else if (pacsServer.metodo == GIL::IModeloPACSServer::IMPS_WADO) {
+							retrieveMethod = DicomServer::WADO;
+						} 
+						DicomServerList::Instance()->AddServer( DicomServer(pacsServer.sid, pacsServer.AET, pacsServer.hostname, (int)puerto, 0, true, pdu, pacsServer.tls, pacsServer.user, pacsServer.password, retrieveMethod, pacsServer.wadoURI, wxString::FromUTF8(pacsServer.retrieveLevel.c_str()).Upper() == wxT("SERIES"), false, pacsServer.verify, pacsServer.cert, pacsServer.key, pacsServer.defaultCharset), true );
 					} else {
 						throw IntegrationException(_Std("The port is not a valid number"), xpp, "CONF/pacs");
 					}
@@ -438,8 +456,12 @@ GIL::IModeloIntegracion* GIL::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode* nodo
 				modelo->GlobalVariables.InsertVariable(GKDI_HCE_ID, std::string(propVal.ToUTF8()));
 			}
 			else {
-				throw IntegrationException(_Std("\"aid\" attribute expected at \"hce\" scope"), xpp, "CONF/template");
+				LOG_DEBUG("ParserXMLEnglish","application id unespecified, using \"defaultHCE\"");
+				modelo->GlobalVariables.InsertVariable(GKDI_HCE_ID, "defaultHCE");
 			}
+		} else {
+			LOG_DEBUG("ParserXMLEnglish","application id unespecified, using \"defaultHCE\"");
+			modelo->GlobalVariables.InsertVariable(GKDI_HCE_ID, "defaultHCE");
 		}
 
 		if (hijo->GetName().CmpNoCase(wxT("metadata")) == 0) {
@@ -520,16 +542,13 @@ GIL::IModeloIntegracion* GIL::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode* nodo
 			modelo->TagsDICOMOverwrite.tags["0008|0080"] = modelo->GlobalVariables.GetValue(GKDI_REFERRING_PHISICIAN_INSTITUTION_NAME);
 		}
 		if (!modelo->GlobalVariables.Contains(GKDI_HCE_PETITION_ID)) {
-			throw IntegrationException(_Std("\"petition-id\" attribute expected at \"gnkworkflow\" scope"), xpp, "CONF/template");
+			LOG_DEBUG("ParserXMLEnglish", "\"petition-id\" attribute not specified");
 		}
 	} else if (modelo->accion == GIL::IModeloIntegracion::TA_Obtener) {
 		if (modelo->TagsDICOMOverwrite.tags.empty()) {
 			throw IntegrationException(_Std("You must specify attributes you want to use in the query"), xpp, "CONF/template");
 		}
 	}
-	if(!modelo->GlobalVariables.Contains(GKDI_HCE_ID)) {
-		throw IntegrationException(_Std("id_application expected"), xpp, "CONF/template");
-	}
 	if (!modelo->GlobalVariables.Contains(GKDI_PATIENT_ID) && modelo->accion == GIL::IModeloIntegracion::TA_Dicomizar) {
 		throw IntegrationException(_Std("It has been read a \"patient\" tag without identifiers"), xpp, "CONF/template");
 	}
@@ -538,11 +557,11 @@ GIL::IModeloIntegracion* GIL::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode* nodo
 	GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/HCE","CodigoAplicacion", codigoAplicacion);
 	modelo->GlobalVariables.InsertVariable(GKDI_GLOBAL_APPLICATION_CODE, codigoAplicacion);
 	if(!servers.empty()) {
-		DicomServer* pServer = DicomServerList::Instance()->GetDefaultServer();
-		if (!modelo->GlobalVariables.Contains(GKDI_GLOBAL_PACS_STORE_SID) && pServer != NULL) {
+		GNC::GCS::Ptr<DicomServer> pServer = DicomServerList::Instance()->GetDefaultServer();
+		if (!modelo->GlobalVariables.Contains(GKDI_GLOBAL_PACS_STORE_SID) && pServer.IsValid()) {
 			modelo->GlobalVariables.InsertVariable(GKDI_GLOBAL_PACS_STORE_SID, pServer->ID);
 		}
-		if (!modelo->GlobalVariables.Contains(GKDI_GLOBAL_PACS_RETRIEVE_SID) && pServer != NULL) {
+		if (!modelo->GlobalVariables.Contains(GKDI_GLOBAL_PACS_RETRIEVE_SID) && pServer.IsValid()) {
 			modelo->GlobalVariables.InsertVariable(GKDI_GLOBAL_PACS_RETRIEVE_SID, pServer->ID);
 		}
 	}
