@@ -66,12 +66,14 @@ void GIL::ParserXMLSpanish::ParseIntegrationXML(GIL::IntegrationModelList& model
 	MapaServers servers;
 	std::string xpp; // XML Pretty Printed for extended information info.
 	// PreCargamos la lista de PACS de la configuracion
-	for (DicomServerHolder* sl = DicomServerList::Instance()->GetList(); sl != NULL; sl = sl->next) {
+	DicomServerList::TServerList ListOfServers = DicomServerList::Instance()->GetServerList();
+	for (DicomServerList::TServerList::iterator it = ListOfServers.begin(); it != ListOfServers.end(); ++it)
+	{
 		IModeloPACSServer pacs;
-		pacs.sid = sl->server.ID;
-		pacs.AET = sl->server.AET;
-		pacs.hostname = sl->server.HostName;
-		pacs.puerto = sl->server.Port;
+		pacs.sid = (*it)->ID;
+		pacs.AET = (*it)->AET;
+		pacs.hostname = (*it)->HostName;
+		pacs.puerto = (*it)->Port;
 
 		servers[pacs.sid] = pacs;
 	}
@@ -177,7 +179,7 @@ void GIL::ParserXMLSpanish::ParseIntegrationXML(GIL::IntegrationModelList& model
 
 				servers[pacsServer.sid] = pacsServer;
 				try{
-					DicomServer* server = DicomServerList::Instance()->GetServer(pacsServer.sid);
+					GNC::GCS::Ptr<DicomServer> server = DicomServerList::Instance()->GetServer(pacsServer.sid);
 					server->AET = pacsServer.AET;
 					server->HostName = pacsServer.hostname;
 					long puerto;
@@ -192,10 +194,10 @@ void GIL::ParserXMLSpanish::ParseIntegrationXML(GIL::IntegrationModelList& model
 						throw IntegrationException(_Std("Port is not a valid number"), xpp, "CONF/pacs");
 					}
 					if (pacsServer.metodo == GIL::IModeloPACSServer::IMPS_GET) {
-						server->retrieveWithMove = false;
+						server->retrieveMethod = DicomServer::GET;
 					}
 					else {
-						server->retrieveWithMove = true;
+						server->retrieveMethod = DicomServer::MOVE;
 					}
 					{
 						wxString strTmp = wxString::FromUTF8(pacsServer.retrieveLevel.c_str());
@@ -217,7 +219,11 @@ void GIL::ParserXMLSpanish::ParseIntegrationXML(GIL::IntegrationModelList& model
 						throw IntegrationException(_Std("The pdu size is not a valid number"), xpp, "CONF/pacs");
 					}
 					if(wxString::FromUTF8(pacsServer.puerto.c_str()).ToLong(&puerto)) {
-						DicomServerList::Instance()->AddServer( DicomServer(pacsServer.sid, pacsServer.AET, pacsServer.hostname, (int)puerto, 0, true, pdu, pacsServer.tls, pacsServer.user, pacsServer.password, pacsServer.metodo == GIL::IModeloPACSServer::IMPS_MOVE, wxString::FromUTF8(pacsServer.retrieveLevel.c_str()).Upper() == wxT("SERIES"), false, pacsServer.verify, pacsServer.cert, pacsServer.key, ""), true );
+						DicomServer::TRetrieveMethod retrieveMethod = DicomServer::MOVE;
+						if ( pacsServer.metodo == GIL::IModeloPACSServer::IMPS_GET) {
+							retrieveMethod = DicomServer::GET;
+						}
+						DicomServerList::Instance()->AddServer( DicomServer(pacsServer.sid, pacsServer.AET, pacsServer.hostname, (int)puerto, 0, true, pdu, pacsServer.tls, pacsServer.user, pacsServer.password, retrieveMethod, "", wxString::FromUTF8(pacsServer.retrieveLevel.c_str()).Upper() == wxT("SERIES"), false, pacsServer.verify, pacsServer.cert, pacsServer.key, pacsServer.defaultCharset), true );
 					} else {
 						throw IntegrationException(_Std("The port is not a valid number"), xpp, "CONF/pacs");
 					}
@@ -558,11 +564,11 @@ GIL::IModeloIntegracion* GIL::ParserXMLSpanish::ParsePlantilla(wxXmlNode* nodo,
 	//se pone el codigo de aplicacion y el primer PACS de la configuracion si no nos ha venido  ninguno
 	modelo->GlobalVariables.InsertVariable(GKDI_GLOBAL_APPLICATION_CODE, codigoAplicacion);
 	if(servers.size() > 0) {
-		DicomServer* pServer = DicomServerList::Instance()->GetDefaultServer();
-		if (!modelo->GlobalVariables.Contains(GKDI_GLOBAL_PACS_STORE_SID) && pServer != NULL) {
+		GNC::GCS::Ptr<DicomServer> pServer = DicomServerList::Instance()->GetDefaultServer();
+		if (!modelo->GlobalVariables.Contains(GKDI_GLOBAL_PACS_STORE_SID) && pServer.IsValid()) {
 			modelo->GlobalVariables.InsertVariable(GKDI_GLOBAL_PACS_STORE_SID, pServer->ID);
 		}
-		if (!modelo->GlobalVariables.Contains(GKDI_GLOBAL_PACS_RETRIEVE_SID) && pServer != NULL) {
+		if (!modelo->GlobalVariables.Contains(GKDI_GLOBAL_PACS_RETRIEVE_SID) && pServer.IsValid()) {
 			modelo->GlobalVariables.InsertVariable(GKDI_GLOBAL_PACS_RETRIEVE_SID, pServer->ID);
 		}
 	}
