@@ -21,7 +21,7 @@
 
 #include <api/icommand.h>
 #include <api/dicom/idicommanager.h>
-#include <api/controllers/icommandscontroller.h>
+#include <main/controllers/commandcontroller.h>
 #include <api/imodelointegracion.h>
 #include <api/internationalization/internationalization.h>
 #include <api/utils/iginkgomatrix4x4.h>
@@ -45,23 +45,19 @@
 #include <vtkImageDataStreamer.h>
 
 #include <itkImage.h>
-#include <itkOrientedImage.h>
+
 #include <itkCommand.h>
 #include <itkMetaDataObject.h>
 
 #include <itkImageFileReader.h>
 #include <itkGDCMSeriesFileNames.h>
-#include <itkVectorResampleImageFilter.h>
 #include <itk/itkImageToVTKImageFilter.h>
 #include <itkMetaDataDictionary.h>
+#include <itkMetaDataObject.h>
 #include <vtkAlgorithmOutput.h>
 #include <vtkImageChangeInformation.h>
 
-//#include <gdcmFilename.h>
-//#include <gdcmSystem.h>
-//#include <gdcmDirectory.h>
-//#include <gdcmTrace.h>
-//#include <gdcmVersion.h>
+
 //#define DEBUG_PRINT_DIR_COSINES
 
 class CargaItkProgressCallback : public itk::Command
@@ -158,7 +154,6 @@ GNC::StreamingLoader::StreamingLoader(): DirectionCosines(GNC::GCS::IGinkgoMatri
 	//gdcm::ImageHelper::SetForceRescaleInterceptSlope(true);
 	//gdcm::ImageHelper::SetForcePixelSpacing(true);
 
-	m_GantryTilt = 0.0;
 	m_SignalFile = false;
 	m_IO = ImageIO::New();
 	m_IO->SetLoadPrivateTags(false);
@@ -202,12 +197,15 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 	try {
 		m_CurrentFile = fichero;
 		m_IO->SetFileName(fichero);
+		m_IO->SetUseStreamedReading(true);
+
 
 		//correct a bug because this dictionary doesn't clear between consecutive loads
 		itk::MetaDataDictionary newDict;
 		m_IO->SetMetaDataDictionary(newDict);
 		//
 		m_IO->ReadImageInformation();
+		
 
 		//std::string tagkey;
 		//std::string GantryTilt;
@@ -255,10 +253,36 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 				#endif
 
 			}
+//			char age[20];
 			for (int i=0; i < 3; i++) {
 				m_Spacing[i] = m_IO->GetSpacing(i);
 				m_Origin[i]  = m_IO->GetOrigin(i);
 			}
+			//check if image data is coherent...
+			itk::MetaDataDictionary& dict = m_IO->GetMetaDataDictionary();
+			if (dict.HasKey("0028|0107") && dict.HasKey( "0028|0103") && dict.HasKey("0028|0102")) {
+				//get highBit
+				if(itk::MetaDataObject <std::string> * highBit =dynamic_cast<itk::MetaDataObject <std::string> *>(dict["0028|0102"].GetPointer())) 
+				{
+					//get largest value
+					if(itk::MetaDataObject <std::string> * largestValue =dynamic_cast<itk::MetaDataObject <std::string> *>(dict["0028|0107"].GetPointer())) 
+					{
+						//get pixel representation
+						if(itk::MetaDataObject <std::string> * pixelRepresentation =dynamic_cast<itk::MetaDataObject <std::string> *>(dict["0028|0103"].GetPointer())) 
+						{
+							if (pixelRepresentation->GetMetaDataObjectValue() == "1") {//if its signed and largest value > (2^highbit)-1
+								if (atoi(largestValue->GetMetaDataObjectValue().c_str()) > (pow((double)2, atoi(highBit->GetMetaDataObjectValue().c_str())) -1)) {
+									throw GNC::GCS::ControladorCargaException( _Std("Error reading the study: Largest image pixel value data is not coherent with combination of Pixel Representation and High bit") , "ControladorCarga/CargaMultidimensional");
+								}					 
+							} else {
+								if (atoi(largestValue->GetMetaDataObjectValue().c_str()) > (pow((double)2, atoi(highBit->GetMetaDataObjectValue().c_str())+1) -1)) {
+									throw GNC::GCS::ControladorCargaException( _Std("Error reading the study: Largest image pixel value data is not coherent with combination of Pixel Representation and High bit") , "ControladorCarga/CargaMultidimensional");
+								}
+							}
+						}
+					}
+				}
+			}//check if image data is coherent
 		}
 
 		if (m_CurrentNumberOfComponents != m_IO->GetNumberOfComponents() || m_CurrentComponentType != m_IO->GetComponentType() || m_CurrentPixelType != m_IO->GetPixelType() || m_CurrentDimensions[0] != m_IO->GetDimensions(0) || m_CurrentDimensions[1] != m_IO->GetDimensions(1) || m_CurrentDimensions[2] != m_IO->GetDimensions(2) )
@@ -273,7 +297,7 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 							case ImageIO::UCHAR:
 								{
 									typedef unsigned char TypedPixelType;
-									typedef itk::OrientedImage<TypedPixelType, 3 > TypedImageType;
+									typedef itk::Image<TypedPixelType, 3 > TypedImageType;
 									typedef itk::ImageFileReader<TypedImageType> TypedReaderType;
 									TypedReaderType* pTypedReader = static_cast<TypedReaderType*>(m_pReader.GetPointer());
 									pTypedReader->SetFileName(fichero);
@@ -283,7 +307,7 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 							case ImageIO::CHAR:
 								{
 									typedef char TypedPixelType;
-									typedef itk::OrientedImage<TypedPixelType, 3 > TypedImageType;
+									typedef itk::Image<TypedPixelType, 3 > TypedImageType;
 									typedef itk::ImageFileReader<TypedImageType> TypedReaderType;
 									TypedReaderType* pTypedReader = static_cast<TypedReaderType*>(m_pReader.GetPointer());
 									pTypedReader->SetFileName(fichero);
@@ -293,7 +317,7 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 							case ImageIO::USHORT:
 								{
 									typedef unsigned short TypedPixelType;
-									typedef itk::OrientedImage<TypedPixelType, 3 > TypedImageType;
+									typedef itk::Image<TypedPixelType, 3 > TypedImageType;
 									typedef itk::ImageFileReader<TypedImageType> TypedReaderType;
 									TypedReaderType* pTypedReader = static_cast<TypedReaderType*>(m_pReader.GetPointer());
 									pTypedReader->SetFileName(fichero);
@@ -302,8 +326,8 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 								break;
 							case ImageIO::SHORT:
 								{
-									typedef short TypedPixelType;
-									typedef itk::OrientedImage<TypedPixelType, 3 > TypedImageType;
+									typedef unsigned short TypedPixelType;
+									typedef itk::Image<TypedPixelType, 3 > TypedImageType;
 									typedef itk::ImageFileReader<TypedImageType> TypedReaderType;
 									TypedReaderType* pTypedReader = static_cast<TypedReaderType*>(m_pReader.GetPointer());
 									pTypedReader->SetFileName(fichero);
@@ -313,7 +337,7 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 							case ImageIO::UINT:
 								{
 									typedef unsigned int TypedPixelType;
-									typedef itk::OrientedImage<TypedPixelType, 3 > TypedImageType;
+									typedef itk::Image<TypedPixelType, 3 > TypedImageType;
 									typedef itk::ImageFileReader<TypedImageType> TypedReaderType;
 									TypedReaderType* pTypedReader = static_cast<TypedReaderType*>(m_pReader.GetPointer());
 									pTypedReader->SetFileName(fichero);
@@ -323,7 +347,7 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 							case ImageIO::INT:
 								{
 									typedef int TypedPixelType;
-									typedef itk::OrientedImage<TypedPixelType, 3 > TypedImageType;
+									typedef itk::Image<TypedPixelType, 3 > TypedImageType;
 									typedef itk::ImageFileReader<TypedImageType> TypedReaderType;
 									TypedReaderType* pTypedReader = static_cast<TypedReaderType*>(m_pReader.GetPointer());
 									pTypedReader->SetFileName(fichero);
@@ -333,7 +357,7 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 							case ImageIO::ULONG:
 								{
 									typedef unsigned long TypedPixelType;
-									typedef itk::OrientedImage<TypedPixelType, 3 > TypedImageType;
+									typedef itk::Image<TypedPixelType, 3 > TypedImageType;
 									typedef itk::ImageFileReader<TypedImageType> TypedReaderType;
 									TypedReaderType* pTypedReader = static_cast<TypedReaderType*>(m_pReader.GetPointer());
 									pTypedReader->SetFileName(fichero);
@@ -343,7 +367,7 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 							case ImageIO::LONG:
 								{
 									typedef long TypedPixelType;
-									typedef itk::OrientedImage<TypedPixelType, 3 > TypedImageType;
+									typedef itk::Image<TypedPixelType, 3 > TypedImageType;
 									typedef itk::ImageFileReader<TypedImageType> TypedReaderType;
 									TypedReaderType* pTypedReader = static_cast<TypedReaderType*>(m_pReader.GetPointer());
 									pTypedReader->SetFileName(fichero);
@@ -353,7 +377,7 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 							case ImageIO::FLOAT:
 								{
 									typedef float TypedPixelType;
-									typedef itk::OrientedImage<TypedPixelType, 3 > TypedImageType;
+									typedef itk::Image<TypedPixelType, 3 > TypedImageType;
 									typedef itk::ImageFileReader<TypedImageType> TypedReaderType;
 									TypedReaderType* pTypedReader = static_cast<TypedReaderType*>(m_pReader.GetPointer());
 									pTypedReader->SetFileName(fichero);
@@ -362,7 +386,7 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 							case ImageIO::DOUBLE:
 								{
 									typedef double TypedPixelType;
-									typedef itk::OrientedImage<TypedPixelType, 3 > TypedImageType;
+									typedef itk::Image<TypedPixelType, 3 > TypedImageType;
 									typedef itk::ImageFileReader<TypedImageType> TypedReaderType;
 									TypedReaderType* pTypedReader = static_cast<TypedReaderType*>(m_pReader.GetPointer());
 									pTypedReader->SetFileName(fichero);
@@ -384,7 +408,7 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 								{
 									typedef unsigned char TypedComponentType;
 									typedef itk::RGBPixel<TypedComponentType> TypedPixelType;
-									typedef itk::OrientedImage<TypedPixelType, 3 > TypedImageType;
+									typedef itk::Image<TypedPixelType, 3 > TypedImageType;
 									typedef itk::ImageFileReader<TypedImageType> TypedReaderType;
 									TypedReaderType* pTypedReader = static_cast<TypedReaderType*>(m_pReader.GetPointer());
 									pTypedReader->SetFileName(fichero);
@@ -395,7 +419,7 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 								{
 									typedef char TypedComponentType;
 									typedef itk::RGBPixel<TypedComponentType> TypedPixelType;
-									typedef itk::OrientedImage<TypedPixelType, 3 > TypedImageType;
+									typedef itk::Image<TypedPixelType, 3 > TypedImageType;
 									typedef itk::ImageFileReader<TypedImageType> TypedReaderType;
 									TypedReaderType* pTypedReader = static_cast<TypedReaderType*>(m_pReader.GetPointer());
 									pTypedReader->SetFileName(fichero);
@@ -406,7 +430,7 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 							{
 								typedef unsigned short TypedComponentType;
 								typedef itk::RGBPixel<TypedComponentType> TypedPixelType;
-								typedef itk::OrientedImage<TypedPixelType, 3 > TypedImageType;
+								typedef itk::Image<TypedPixelType, 3 > TypedImageType;
 								typedef itk::ImageFileReader<TypedImageType> TypedReaderType;
 								TypedReaderType* pTypedReader = static_cast<TypedReaderType*>(m_pReader.GetPointer());
 								pTypedReader->SetFileName(fichero);
@@ -417,7 +441,7 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 							{
 								typedef short TypedComponentType;
 								typedef itk::RGBPixel<TypedComponentType> TypedPixelType;
-								typedef itk::OrientedImage<TypedPixelType, 3 > TypedImageType;
+								typedef itk::Image<TypedPixelType, 3 > TypedImageType;
 								typedef itk::ImageFileReader<TypedImageType> TypedReaderType;
 								TypedReaderType* pTypedReader = static_cast<TypedReaderType*>(m_pReader.GetPointer());
 								pTypedReader->SetFileName(fichero);
@@ -428,7 +452,7 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 							{
 								typedef unsigned int TypedComponentType;
 								typedef itk::RGBPixel<TypedComponentType> TypedPixelType;
-								typedef itk::OrientedImage<TypedPixelType, 3 > TypedImageType;
+								typedef itk::Image<TypedPixelType, 3 > TypedImageType;
 								typedef itk::ImageFileReader<TypedImageType> TypedReaderType;
 								TypedReaderType* pTypedReader = static_cast<TypedReaderType*>(m_pReader.GetPointer());
 								pTypedReader->SetFileName(fichero);
@@ -439,7 +463,7 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 							{
 								typedef int TypedComponentType;
 								typedef itk::RGBPixel<TypedComponentType> TypedPixelType;
-								typedef itk::OrientedImage<TypedPixelType, 3 > TypedImageType;
+								typedef itk::Image<TypedPixelType, 3 > TypedImageType;
 								typedef itk::ImageFileReader<TypedImageType> TypedReaderType;
 								TypedReaderType* pTypedReader = static_cast<TypedReaderType*>(m_pReader.GetPointer());
 								pTypedReader->SetFileName(fichero);
@@ -450,7 +474,7 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 							{
 								typedef long TypedComponentType;
 								typedef itk::RGBPixel<TypedComponentType> TypedPixelType;
-								typedef itk::OrientedImage<TypedPixelType, 3 > TypedImageType;
+								typedef itk::Image<TypedPixelType, 3 > TypedImageType;
 								typedef itk::ImageFileReader<TypedImageType> TypedReaderType;
 								TypedReaderType* pTypedReader = static_cast<TypedReaderType*>(m_pReader.GetPointer());
 								pTypedReader->SetFileName(fichero);
@@ -461,7 +485,7 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 							{
 								typedef unsigned long TypedComponentType;
 								typedef itk::RGBPixel<TypedComponentType> TypedPixelType;
-								typedef itk::OrientedImage<TypedPixelType, 3 > TypedImageType;
+								typedef itk::Image<TypedPixelType, 3 > TypedImageType;
 								typedef itk::ImageFileReader<TypedImageType> TypedReaderType;
 								TypedReaderType* pTypedReader = static_cast<TypedReaderType*>(m_pReader.GetPointer());
 								pTypedReader->SetFileName(fichero);
@@ -472,7 +496,7 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 							{
 								typedef float TypedComponentType;
 								typedef itk::RGBPixel<TypedComponentType> TypedPixelType;
-								typedef itk::OrientedImage<TypedPixelType, 3 > TypedImageType;
+								typedef itk::Image<TypedPixelType, 3 > TypedImageType;
 								typedef itk::ImageFileReader<TypedImageType> TypedReaderType;
 								TypedReaderType* pTypedReader = static_cast<TypedReaderType*>(m_pReader.GetPointer());
 								pTypedReader->SetFileName(fichero);
@@ -483,7 +507,7 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 							{
 								typedef double TypedComponentType;
 								typedef itk::RGBPixel<TypedComponentType> TypedPixelType;
-								typedef itk::OrientedImage<TypedPixelType, 3 > TypedImageType;
+								typedef itk::Image<TypedPixelType, 3 > TypedImageType;
 								typedef itk::ImageFileReader<TypedImageType> TypedReaderType;
 								TypedReaderType* pTypedReader = static_cast<TypedReaderType*>(m_pReader.GetPointer());
 								pTypedReader->SetFileName(fichero);
@@ -633,6 +657,9 @@ void GNC::StreamingLoader::GetSpacing(double spacing[3])
 
 void GNC::StreamingLoader::SetOutputSpacing(double spacing[3])
 {
+	if (spacing[0] <= 0 || spacing[1] <= 0) {
+		spacing[0] = spacing[1] = 1.0;
+	}
 	m_pOutput->SetOutputSpacing(spacing);
 }
 
@@ -651,11 +678,21 @@ void GNC::StreamingLoader::GetOutputSpacing(double spacing[3])
 	m_pOutput->GetOutputSpacing(spacing);
 }
 
-int GNC::StreamingLoader::GetCurrentSliceIndex()
+int GNC::StreamingLoader::GetCurrentSliceIndex()  const
 {
 	return 0;
 }
 
+std::string GNC::StreamingLoader::GetPatientPosition()
+{
+	std::string patientPositionTag;
+	bool ok = m_IO->GetValueFromTag("0018|5100", patientPositionTag);
+	if (ok) {
+		return patientPositionTag;
+	}
+	return "";	
+}
+
 void GNC::StreamingLoader::RecomponerPipeline()
 {
 	if (m_SignalFile) {
@@ -670,7 +707,7 @@ void GNC::StreamingLoader::RecomponerPipeline()
 		m_pOutput->RemoveAllInputs();
 
 		typedef unsigned short TypedPixelType;
-		typedef itk::OrientedImage<TypedPixelType, 3 > TypedImageType;
+		typedef itk::Image<TypedPixelType, 3 > TypedImageType;
 		typedef itk::ImageToVTKImageFilter<TypedImageType> TypedJoinerType;
 		
 		TypedImageType::Pointer img = TypedImageType::New();
@@ -808,6 +845,7 @@ void GNC::StreamingLoader::RecomponerPipeline()
 								reader->SetImageIO(pIO);
 								reader->SetFileName(m_CurrentFile);
 								reader->SetUseStreaming(true);
+								
 								m_pOutput->SetInputConnection(joiner->GetImporter()->GetOutputPort());
 								//reader->GetOutput()->ReleaseDataFlagOn();
 
@@ -1160,6 +1198,7 @@ void GNC::StreamingLoader::RecomponerPipeline()
 	}
 	if (m_pReader.IsNotNull() && m_pPipelineJoiner.IsNotNull()) {
 		m_pReader->Modified();
+		
 		m_pPipelineJoiner->Modified();
 	}
 	m_pOutput->Modified();
