@@ -13,16 +13,16 @@
 */
 //#define _GINKGO_TRACE
 #if defined(_WINDOWS)
-	#if !defined (_SCL_SECURE_NO_WARNINGS)
-		#define _SCL_SECURE_NO_WARNINGS
-	#endif
-	#if !defined (_CRT_SECURE_NO_WARNINGS)
-		#define _CRT_SECURE_NO_WARNINGS
-	#endif
+#if !defined (_SCL_SECURE_NO_WARNINGS)
+#define _SCL_SECURE_NO_WARNINGS
+#endif
+#if !defined (_CRT_SECURE_NO_WARNINGS)
+#define _CRT_SECURE_NO_WARNINGS
+#endif
 #else
-	#if defined(__DEPRECATED)
-		#undef __DEPRECATED
-	#endif
+#if defined(__DEPRECATED)
+#undef __DEPRECATED
+#endif
 #endif
 
 #include <api/globals.h>
@@ -38,17 +38,19 @@
 #include <wx/ginkgostyle/ginkgostyle.h>
 #include <wx/propiedades/wxpropiedades.h>
 
+#include "downloadagaindialog.h"
 #include "dialogoadquisicion.h"
-#include "downloadelementcontainerpanel.h"
 
 #include <resources/ginkgoresourcesmanager.h>
 #include <main/entorno.h>
-#include <main/controllers/controladorcomandos.h>
+#include <main/controllers/commandcontroller.h>
 #include <main/controllers/controladorpermisos.h>
 #include <main/controllers/controladorlog.h>
 #include <main/controllers/controladoreventos.h>
+#include <main/controllers/historycontroller.h>
 #include <main/controllers/historytoolscontroller.h>
 #include <eventos/progresocomando.h>
+#include <commands/pacsdownloadcommand.h>
 
 #define SIZE_ICONOS 16
 
@@ -85,7 +87,6 @@ GNC::GUI::DialogoAdquisicion* GNC::GUI::DialogoAdquisicion::m_pInstance = NULL;
 GNC::GUI::DialogoAdquisicion::DialogoAdquisicion(wxWindow* pParent) : DialogoAdquisicionBase(pParent)
 {
 	m_pResultado = NULL;
-	m_pDescargasGridTable = NULL;
 	m_SizeRestriction = false;
 	m_SizeOK = false;
 	m_reverseOrder = true;
@@ -97,10 +98,7 @@ GNC::GUI::DialogoAdquisicion::DialogoAdquisicion(wxWindow* pParent) : DialogoAdq
 	m_pAnimation = new wxAnimationCtrl(m_pPanelPACS,wxID_ANY,GinkgoResourcesManager::ProgressBar::GetAniLoading());
 	m_pAnimation->Hide();
 	m_pSizerAnimation->Add(m_pAnimation, 0, wxALIGN_CENTER_VERTICAL|wxALL, 5);
-
-	m_AutoAddSeries = false;
-	m_AutoAddSeriesItem = NULL;
-
+	
 	m_pImageList->Add(GinkgoResourcesManager::History::GetIcoEstudio());
 	m_pImageList->Add(GinkgoResourcesManager::History::GetIcoSerie());
 	m_pImageList->Add(GinkgoResourcesManager::History::GetIcoHombre());
@@ -116,10 +114,6 @@ GNC::GUI::DialogoAdquisicion::DialogoAdquisicion(wxWindow* pParent) : DialogoAdq
 	m_pTreeListResultados->Connect(wxEVT_COMMAND_TREE_BEGIN_DRAG, wxTreeEventHandler( DialogoAdquisicion::OnTreeBeginDrag ), NULL, this);
 	m_pTreeListResultados->Connect(wxEVT_COMMAND_LIST_COL_CLICK, wxListEventHandler( DialogoAdquisicion::OnClickColumnHeader), NULL, this);
 
-	m_pDownloadPanel = new DownloadElementContainerPanel(m_pZonaDescargas);
-	m_pZonaDescargas->GetSizer()->Add(m_pDownloadPanel, 1, wxEXPAND|wxALL, 5);
-	m_pZonaDescargas->Layout();
-
 	if(GNC::GCS::IControladorPermisos::Instance()->Get("core.pacs.limits", "patient_scope")) {
 		int tmpIndex = m_pFieldCombo->FindString(_("Id"));
 		if (tmpIndex > 0) {
@@ -163,8 +157,6 @@ GNC::GUI::DialogoAdquisicion::DialogoAdquisicion(wxWindow* pParent) : DialogoAdq
 			pCheckBox->Connect( wxEVT_KEY_UP, wxKeyEventHandler( DialogoAdquisicion::OnKeyDownFormulario ), NULL, this );
 		}
 		m_pPanelPACS->Layout();
-		m_pPanelSearch->Layout();
-		m_notebook1->Layout();
 	}
 
 	m_pModeloDicom = GNC::GCS::Ptr<IModeloDicom>(new IModeloDicom());
@@ -175,7 +167,7 @@ GNC::GUI::DialogoAdquisicion::DialogoAdquisicion(wxWindow* pParent) : DialogoAdq
 
 GNC::GUI::DialogoAdquisicion::~DialogoAdquisicion()
 {
-	GNC::Entorno::Instance()->GetControladorComandos()->AbortarComandosDeOwner(this);
+	GNC::Entorno::Instance()->GetCommandController()->AbortarComandosDeOwner(this);
 	{
 		this->m_pTreeListResultados->DeleteRoot();
 	}
@@ -214,13 +206,14 @@ bool GNC::GUI::DialogoAdquisicion::Show(bool show)
 	GNC::GCS::ConfigurationController::Instance()->readStringUser("/GinkgoCore/Adquisicion", "PACSDefecto", pacsDef);
 	int defaultIndex = 0;
 	int ind = 0;
-	for (DicomServerHolder* sl = DicomServerList::Instance()->GetList(); sl != NULL; sl = sl->next, ++ind) {
+	ListOfServers = DicomServerList::Instance()->GetServerList();
+	for (DicomServerList::TServerList::iterator it = ListOfServers.begin(); it != ListOfServers.end(); ++it, ++ind)
+	{
 		std::ostringstream ostr;
-		ostr << sl->server.ID << " (" << sl->server.AET << "@" << sl->server.HostName << ":" << sl->server.Port << ")";
+		ostr << (*it)->ID << " (" << (*it)->AET << "@" << (*it)->HostName << ":" << (*it)->Port << ")";
 		serverListString.push_back(wxString::FromUTF8(ostr.str().c_str()));
-		if (sl->server.ID == pacsDef) {
+		if ((*it)->ID == pacsDef) {
 			defaultIndex = ind;
-			m_Mode = sl->server.retrieveSeries?TD_SERIES:TD_STUDIES;
 		}
 	}
 	m_pPACSListaServidores->Clear();
@@ -236,8 +229,12 @@ bool GNC::GUI::DialogoAdquisicion::Show(bool show)
 		m_pPACSListaServidores->Disable();
 	}
 
+	if (IsIconized()) {
+		Iconize(false);
+	}
+
 	if (IsShown())
-	{		
+	{	
 		Raise();
 	}
 	return DialogoAdquisicionBase::Show(show);
@@ -250,25 +247,24 @@ bool GNC::GUI::DialogoAdquisicion::Show(bool show)
 void GNC::GUI::DialogoAdquisicion::OnPACSChanged(wxCommandEvent & )
 {
 	int selected = m_pPACSListaServidores->GetCurrentSelection();
-	DicomServerHolder* sl = DicomServerList::Instance()->GetList();
-	for (int ind = 0; sl != NULL && ind < selected; sl = sl->next, ++ind);
+	DicomServerList::TServerList::iterator pServer = ListOfServers.begin();
+	for (int ind = 0;pServer != ListOfServers.end() && ind < selected; ++pServer,++ind);
 
-	if (sl == NULL) {
+	if (pServer == ListOfServers.end()) {
 		return;
 	}
 
-	GNC::GCS::ConfigurationController::Instance()->writeStringUser("/GinkgoCore/Adquisicion","PACSDefecto", sl->server.ID);
+	GNC::GCS::ConfigurationController::Instance()->writeStringUser("/GinkgoCore/Adquisicion","PACSDefecto", (*pServer)->ID);
 
 	if(m_pComandoPACS != NULL)
 	{
-		GNC::Entorno::Instance()->GetControladorComandos()->AbortarComando(m_pComandoPACS, false);
+		GNC::Entorno::Instance()->GetCommandController()->AbortarComando(m_pComandoPACS, false);
 	}
 	m_pModeloDicom = GNC::GCS::Ptr<IModeloDicom>(new IModeloDicom());
 	{
 		//GNC::GCS::ILocker locker(m_TreeListResultadosLocker);
 		this->m_pTreeListResultados->DeleteRoot();
-		m_AutoAddSeries = false;
-		m_Mode = sl->server.retrieveSeries?TD_SERIES:TD_STUDIES;
+		m_Mode = (*pServer)->retrieveSeries?TD_SERIES:TD_STUDIES;
 	}
 }
 
@@ -305,16 +301,11 @@ void GNC::GUI::DialogoAdquisicion::OnFechaHastaDateChanged( wxDateEvent& /*event
 
 void GNC::GUI::DialogoAdquisicion::OnCancelClick( wxCommandEvent&  )
 {
-	if (m_AutoAddSeries)  {
-		m_AutoAddSeries = false;
-		m_AutoAddSeriesItem = NULL;
-	}
-
 	if(m_pComandoPACS != NULL)
 	{
 		m_pTextControlField->ShowCancelButton(false);
 		ShowAnimation(false);
-		GNC::Entorno::Instance()->GetControladorComandos()->AbortarComando(m_pComandoPACS, false);
+		GNC::Entorno::Instance()->GetCommandController()->AbortarComando(m_pComandoPACS, false);
 		m_pComandoPACS = NULL;
 
 		//GNC::GCS::ILocker locker(m_TreeListResultadosLocker);
@@ -333,16 +324,11 @@ void GNC::GUI::DialogoAdquisicion::OnBusquedaClick( wxCommandEvent&  )
 
 void GNC::GUI::DialogoAdquisicion::Search()
 {
-	if (m_AutoAddSeries)  {
-		m_AutoAddSeries = false;
-		m_AutoAddSeriesItem = NULL;
-	}
-
 	if(m_pComandoPACS != NULL)
 	{
 		m_pTextControlField->ShowCancelButton(false);
 		ShowAnimation(false);
-		GNC::Entorno::Instance()->GetControladorComandos()->AbortarComando(m_pComandoPACS, false);
+		GNC::Entorno::Instance()->GetCommandController()->AbortarComando(m_pComandoPACS, false);
 		m_pComandoPACS = NULL;
 
 		//GNC::GCS::ILocker locker(m_TreeListResultadosLocker);
@@ -423,7 +409,7 @@ void GNC::GUI::DialogoAdquisicion::Search()
 		server, GADAPI::ComandoPACSParams::TA_Estudio, m_pModeloDicom, this); // Buscamos los estudios del paciente
 
 	m_pComandoPACS = new GADAPI::ComandoPACS(pParams);
-	GNC::Entorno::Instance()->GetControladorComandos()->ProcessAsync(_Std("Exploring PACS..."),m_pComandoPACS, this);
+	GNC::Entorno::Instance()->GetCommandController()->ProcessAsync(_Std("Exploring PACS..."),m_pComandoPACS, this);
 	m_pTextControlField->ShowCancelButton(true);
 	ShowAnimation(true);
 }
@@ -464,6 +450,11 @@ void GNC::GUI::DialogoAdquisicion::OnCloseClick( wxCommandEvent& /*event*/ )
 }
 
 void GNC::GUI::DialogoAdquisicion::OnDescargarClick( wxCommandEvent& /*event*/ )
+{
+	AddDescarga();
+}
+
+void GNC::GUI::DialogoAdquisicion::OnLinkClick( wxCommandEvent& /*event*/)
 {
 	AddDescarga(true);
 }
@@ -475,9 +466,12 @@ void GNC::GUI::DialogoAdquisicion::OnTreeSelChanged(wxTreeEvent& event)
 	wxTreeItemId item = event.GetItem();
 	if(item.IsOk()){
 		wxTreeItemId idPadre = m_pTreeListResultados->GetItemParent(item);
-		m_pBDescargar->Enable(idPadre != m_pTreeListResultados->GetRootItem()); // El item es un estudio o una serie
+		bool enabled = idPadre != m_pTreeListResultados->GetRootItem();
+		m_pBDescargar->Enable(enabled); // El item es un estudio o una serie
+		m_pBLink->Enable(enabled && IsLinkSupported());
 	} else {
 		m_pBDescargar->Enable(false);
+		m_pBLink->Enable(false);
 	}
 
 	event.Skip(true);
@@ -487,7 +481,7 @@ void GNC::GUI::DialogoAdquisicion::OnTreeSelChanged(wxTreeEvent& event)
 void GNC::GUI::DialogoAdquisicion::OnTreeItemActivated(wxTreeEvent& event)
 {
 
-	AddDescarga(false);
+	AddDescarga();
 
 	event.Skip(true);
 
@@ -503,23 +497,40 @@ void GNC::GUI::DialogoAdquisicion::OnTreeItemMenu(wxTreeEvent& event)
 		{
 			m_pDlg = pDlg;
 			if (allowDownload) {
-				wxString label;
-				if(series) {
-					label = _("Download series");
-				} else {
-					label = _("Download study");
-				}
-
-				wxMenuItem* descargar = new wxMenuItem( this,wxID_ANY,label);
+				{
+					wxString label;
+					if(series) {
+						label = _("Download series");
+					} else {
+						label = _("Download study");
+					}
+					wxMenuItem* descargar = new wxMenuItem( this,wxID_ANY,label);
 #ifdef __WXMSW__
-				descargar->SetBitmaps(GinkgoResourcesManager::Acquisition::GetIcoDownload());
+					descargar->SetBitmaps(GinkgoResourcesManager::Acquisition::GetIcoDownload());
 #else
-				descargar->SetBitmap(GinkgoResourcesManager::Acquisition::GetIcoDownload());
+					descargar->SetBitmap(GinkgoResourcesManager::Acquisition::GetIcoDownload());
 #endif
-				Append(descargar);
-				this->AppendSeparator();
+					Append(descargar);
+					Connect(descargar->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( PopUpMenuDescargar::OnDescargar ), NULL, this);
+				}
+				if (m_pDlg->IsLinkSupported()) {
+					wxString label;
+					if(series) {
+						label = _("Link series");
+					} else {
+						label = _("Link study");
+					}
+					wxMenuItem* link = new wxMenuItem( this,wxID_ANY,label);
+#ifdef __WXMSW__
+					link->SetBitmaps(GinkgoResourcesManager::History::GetIcoLocalLinked());
+#else
+					link->SetBitmap(GinkgoResourcesManager::History::GetIcoLocalLinked());
+#endif
+					Append(link);
+					Connect(link->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( PopUpMenuDescargar::OnLink ), NULL, this);
+				}				
 
-				Connect(descargar->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( PopUpMenuDescargar::OnDescargar ), NULL, this);
+				this->AppendSeparator();
 			}
 			wxMenuItem* props = new wxMenuItem( this, wxID_ANY, _("Properties..."));
 			Append(props);
@@ -534,6 +545,13 @@ void GNC::GUI::DialogoAdquisicion::OnTreeItemMenu(wxTreeEvent& event)
 		}
 
 		void OnDescargar(wxCommandEvent& )
+		{
+			if (m_pDlg) {
+				m_pDlg->AddDescarga();
+			}
+		}
+
+		void OnLink(wxCommandEvent& )
 		{
 			if (m_pDlg) {
 				m_pDlg->AddDescarga(true);
@@ -583,11 +601,6 @@ void GNC::GUI::DialogoAdquisicion::OnTreeItemExpanded(wxTreeEvent& event)
 		//GNC::GCS::ILocker locker(m_TreeListResultadosLocker);
 		wxTreeItemId item = event.GetItem();
 
-		if (m_AutoAddSeries && (m_AutoAddSeriesItem != item) )  {
-			m_AutoAddSeries = false;
-			m_AutoAddSeriesItem = NULL;
-		}
-
 		if(item && item.IsOk()){
 			m_pTreeListResultados->SortChildren(item);
 			//si el abuelo del item es root => consultar
@@ -596,7 +609,7 @@ void GNC::GUI::DialogoAdquisicion::OnTreeItemExpanded(wxTreeEvent& event)
 				//se cancela el anterior comando y se contrae el item expandido
 				if(m_pComandoPACS != NULL)
 				{
-					GNC::Entorno::Instance()->GetControladorComandos()->AbortarComando(m_pComandoPACS, false);
+					GNC::Entorno::Instance()->GetCommandController()->AbortarComando(m_pComandoPACS, false);
 					m_pComandoPACS = NULL;
 					if(m_lastExpanded.IsOk()) {
 						m_pTreeListResultados->Collapse(m_lastExpanded);
@@ -619,7 +632,7 @@ void GNC::GUI::DialogoAdquisicion::OnTreeItemExpanded(wxTreeEvent& event)
 					"",server, GADAPI::ComandoPACSParams::TA_Serie, m_pModeloDicom, this);
 
 				m_pComandoPACS = new GADAPI::ComandoPACS(pParams);
-				GNC::Entorno::Instance()->GetControladorComandos()->ProcessAsync(_Std("Exploring PACS..."),m_pComandoPACS, this);
+				GNC::Entorno::Instance()->GetCommandController()->ProcessAsync(_Std("Exploring PACS..."),m_pComandoPACS, this);
 				m_pTextControlField->ShowCancelButton(true);
 				ShowAnimation(true);
 				m_lastExpanded = item;
@@ -653,7 +666,7 @@ void GNC::GUI::DialogoAdquisicion::OnTreeBeginDrag(wxTreeEvent& )
 			wxDropSource dragSource(myData,this);
 			wxDragResult result = dragSource.DoDragDrop(wxDrag_AllowMove);
 			if (result == wxDragCopy) {
-				AddDescarga(true);
+				AddDescarga();
 			}
 		}
 	}
@@ -668,25 +681,35 @@ void GNC::GUI::DialogoAdquisicion::OnClickColumnHeader(wxListEvent& event)
 
 std::string GNC::GUI::DialogoAdquisicion::GetServerSeleccionado()
 {
-	std::string id;
-
 	int selected = m_pPACSListaServidores->GetCurrentSelection();
-	DicomServerHolder* sl = DicomServerList::Instance()->GetList();
-	for (int ind = 0; sl != NULL && ind < selected; sl = sl->next, ++ind);
+	DicomServerList::TServerList::iterator pServer = ListOfServers.begin();
+	for (int ind = 0;pServer != ListOfServers.end() && ind < selected; ++pServer,++ind);
 
-	if (sl != NULL) {
-		id = sl->server.ID;
-	} else {
+	if (pServer == ListOfServers.end()) {
 		wxMessageBox(_("Select a valid PACS Server"), _("Info"),
 			wxOK | wxICON_INFORMATION, this);
+		return "";
+	} else {
+		return (*pServer)->ID;
 	}
+}
 
-	return id;
+bool GNC::GUI::DialogoAdquisicion::IsLinkSupported()
+{
+	int selected = m_pPACSListaServidores->GetCurrentSelection();
+	DicomServerList::TServerList::iterator pServer = ListOfServers.begin();
+	for (int ind = 0;pServer != ListOfServers.end() && ind < selected; ++pServer,++ind);
+
+	if (pServer == ListOfServers.end()) {
+		return false;
+	} else {
+		return (*pServer)->retrieveMethod == DicomServer::WADO;
+	}
 }
 
 
 // Obtiene el item seleccionado del TreeList de resultados, genera una descarga, la apila y la inicia.
-void GNC::GUI::DialogoAdquisicion::AddDescarga(bool lanzarBusqueda)
+void GNC::GUI::DialogoAdquisicion::AddDescarga(bool link)
 {
 	{
 		//GNC::GCS::ILocker locker(m_TreeListResultadosLocker);
@@ -698,133 +721,20 @@ void GNC::GUI::DialogoAdquisicion::AddDescarga(bool lanzarBusqueda)
 			} //raiz
 			else if(m_pTreeListResultados->GetItemParent(m_pTreeListResultados->GetItemParent(seleccion)) == m_pTreeListResultados->GetRootItem()){
 				//studies
-				if (m_Mode == TD_STUDIES) {
-					//download study node
-					//std::string uidPaciente = std::string(m_pTreeListResultados->GetItemText(m_pTreeListResultados->GetItemParent(seleccion), COLUMNA_UID).ToUTF8());
-					std::string descPaciente = std::string(m_pTreeListResultados->GetItemText(m_pTreeListResultados->GetItemParent(seleccion)).ToUTF8());
+				//download study node
+				//std::string uidPaciente = std::string(m_pTreeListResultados->GetItemText(m_pTreeListResultados->GetItemParent(seleccion), COLUMNA_UID).ToUTF8());
+				std::string descPaciente = std::string(m_pTreeListResultados->GetItemText(m_pTreeListResultados->GetItemParent(seleccion)).ToUTF8());
 
-					std::string uidStudy = std::string(m_pTreeListResultados->GetItemText(seleccion, COLUMNA_UID).ToUTF8());
-					std::string descStudy = std::string( (m_pTreeListResultados->GetItemText(seleccion) + _T("(") + m_pTreeListResultados->GetItemText(seleccion, COLUMNA_MODALIDAD) + _T(")") ).ToUTF8());
-					std::string modStudy =  std::string( m_pTreeListResultados->GetItemText(seleccion, COLUMNA_MODALIDAD ).ToUTF8());
+				std::string uidStudy = std::string(m_pTreeListResultados->GetItemText(seleccion, COLUMNA_UID).ToUTF8());
+				std::string descStudy = std::string( (m_pTreeListResultados->GetItemText(seleccion) + _T("(") + m_pTreeListResultados->GetItemText(seleccion, COLUMNA_MODALIDAD) + _T(")") ).ToUTF8());
+				std::string modStudy =  std::string( m_pTreeListResultados->GetItemText(seleccion, COLUMNA_MODALIDAD ).ToUTF8());
 
-					if (!IsAllowedToDownload(modStudy)) {
-						LOG_ERROR("GUI/Adquisition", _Std("Download of modality ") << modStudy << _Std(" not allowed"));
-						wxMessageBox(_("You are not allowed to download this kind of modalities."),_("Modality download error"),wxICON_ERROR);
-					} else {
-						bool forceInit = true;
-						if (m_pDownloadPanel->FindDownload(uidStudy)) {
-							forceInit = wxMessageBox(_("Studies are already in the download queue.\nDo you want to repeat download?"),_("Download warning"),wxICON_INFORMATION|wxYES_NO) == wxYES;
-						}
-
-						bool downloaded = m_pDownloadPanel->AddDownload(GetServerSeleccionado(), descPaciente, descStudy,modStudy, forceInit, false, uidStudy, "");
-						m_pTreeListResultados->SetItemBold(seleccion, downloaded);
-					}
-
-				} else { 
-					//series mode, we have to search series in study
-					if (lanzarBusqueda) {
-
-						//estamos en un estudio
-						//std::string uidPaciente = std::string(m_pTreeListResultados->GetItemText(m_pTreeListResultados->GetItemParent(seleccion), COLUMNA_UID).ToUTF8());
-						std::string descPaciente = std::string(m_pTreeListResultados->GetItemText(m_pTreeListResultados->GetItemParent(seleccion)).ToUTF8());
-						std::string uidStudy = std::string(m_pTreeListResultados->GetItemText(seleccion, COLUMNA_UID).ToUTF8());
-
-						// Necesitamos buscar las series
-
-						// Primero comprobamos que no estan ya desplegadas, y asi ahorramos una busqueda en el PACS.
-						wxTreeItemId eid = seleccion;
-						std::string server = GetServerSeleccionado();
-						int numSeriesDescargadas = 0;
-
-						std::list<wxTreeItemId> s_items = m_pTreeListResultados->GetPublicChildren(eid);
-						std::set<std::string> listaModalidad;
-						bool forceInit = true;
-						bool questionMade = false;
-						for (std::list<wxTreeItemId>::iterator ititem = s_items.begin(); ititem != s_items.end(); ++ititem) {
-							wxTreeItemId cid = *ititem;
-
-							std::string uidSerie = std::string(m_pTreeListResultados->GetItemText(cid, COLUMNA_UID).ToUTF8());
-							std::string modalidadSerie = std::string(m_pTreeListResultados->GetItemText(cid, COLUMNA_MODALIDAD).ToUTF8());
-							if (!uidSerie.empty()) { // La serie esta desplegada
-								if( IsAllowedToDownload(modalidadSerie) ) {
-									if (!questionMade && m_pDownloadPanel->FindDownload(uidSerie)) {
-										forceInit = wxMessageBox(_("Series were already in the download queue.\nDo you want to force download?"),_("Download warning"),wxICON_INFORMATION|wxYES_NO) == wxYES;
-										questionMade = true;
-									}
-
-									std::string descSerie = std::string( (m_pTreeListResultados->GetItemText(cid) + _T("(") + m_pTreeListResultados->GetItemText(cid, COLUMNA_MODALIDAD) + _T(")") ).ToUTF8());
-									bool downloaded = m_pDownloadPanel->AddDownload(server, descPaciente, descSerie, modalidadSerie,forceInit, true, uidStudy, uidSerie);
-									m_pTreeListResultados->SetItemBold(cid, downloaded);
-									numSeriesDescargadas++;
-								} else {
-									listaModalidad.insert( modalidadSerie );
-								}
-							}
-						}
-						if (numSeriesDescargadas == 0 && listaModalidad.empty())
-						{
-							// Desplegamos la serie.
-
-							wxTreeItemId item = seleccion;
-							// >>------- Es un cut&paste del evento OnTreeItemExpanded, pero mejor esto que complicar la interfaz invocandolo directamente (lockers, omision de evento, reset de estado de la auto descarga de series , etc..)
-							//se cancela el anterior comando y se contrae el item expandido
-							if(item && item.IsOk()){
-								//si el abuelo del item es root => consultar
-								m_AutoAddSeries = true;
-								m_AutoAddSeriesItem = item;
-							}
-
-							if(m_pComandoPACS != NULL)
-							{
-								GNC::Entorno::Instance()->GetControladorComandos()->AbortarComando(m_pComandoPACS, false);
-								m_pComandoPACS = NULL;
-
-								if(m_lastExpanded.IsOk()) {
-									m_pTreeListResultados->Collapse(m_lastExpanded);
-									m_lastExpanded.Unset();
-								}
-							}
-							std::string server = GetServerSeleccionado();
-
-							if(server=="") {
-								return;
-							}
-
-							GADAPI::ComandoPACSParams * pParams = new GADAPI::ComandoPACSParams(
-								"",
-								"",
-								std::string(m_pTreeListResultados->GetItemText(item,COLUMNA_UID).ToUTF8()),
-								"",
-								GetModalities(),
-								"",
-								"",
-								"",
-								"",server, GADAPI::ComandoPACSParams::TA_Serie, m_pModeloDicom, this);
-
-							m_pComandoPACS = new GADAPI::ComandoPACS(pParams);
-							GNC::Entorno::Instance()->GetControladorComandos()->ProcessAsync(_Std("Exploring PACS..."),m_pComandoPACS, this);
-							m_pTextControlField->ShowCancelButton(true);
-							ShowAnimation(true);
-						}
-						else if ( !listaModalidad.empty() )
-						{
-							std::ostringstream ostr;
-							ostr << _Std("You are not allowed to download this kind of modalities (");
-							bool primero = true;
-							for (std::set<std::string>::iterator it = listaModalidad.begin(); it != listaModalidad.end(); ++it) {
-								if (primero) {
-									ostr << (*it);
-									primero = false;
-								}
-								else {
-									ostr << ", " << (*it);
-								}
-							}
-							ostr << ")";
-							wxMessageBox(wxString::FromUTF8( ostr.str().c_str() ), _("Modality download error"), wxICON_ERROR);
-						}
-					}//lanzar busqueda
-				}//series mode
+				if (!IsAllowedToDownload(modStudy)) {
+					LOG_ERROR("GUI/Adquisition", _Std("Download of modality ") << modStudy << _Std(" not allowed"));
+					wxMessageBox(_("You are not allowed to download this kind of modalities."),_("Modality download error"),wxICON_ERROR);
+				} else {
+					AddDownload(GetServerSeleccionado(), modStudy, false, uidStudy, "", link);
+				}
 				//fin estudio
 			} else {
 				//estamos en una serie
@@ -842,13 +752,7 @@ void GNC::GUI::DialogoAdquisicion::AddDescarga(bool lanzarBusqueda)
 						wxMessageBox(_("You are not allowed to download this kind of modalities."),_("Modality download error"),wxICON_ERROR);
 					}
 					else {
-						bool forceInit = true;
-						if (m_pDownloadPanel->FindDownload(uidSerie)) {
-							forceInit = wxMessageBox(_("Series were already in the download queue.\nDo you want to force download?"),_("Download warning"),wxICON_INFORMATION|wxYES_NO) == wxYES;
-						}
-
-						bool downloaded = m_pDownloadPanel->AddDownload(GetServerSeleccionado(), descPaciente, descSerie, modSerie, forceInit, true, uidStudy, uidSerie);
-						m_pTreeListResultados->SetItemBold(seleccion, downloaded);
+						AddDownload(GetServerSeleccionado(), modSerie, true, uidStudy, uidSerie, link);
 					}
 				}
 			}
@@ -1026,8 +930,6 @@ void GNC::GUI::DialogoAdquisicion::PACSCargarListado(IModeloDicom * pModelo)
 
 					if(estudioTreeId.IsOk() && estudio->ListaSeries().size() > 0) {
 						m_pTreeListResultados->DeleteChildren(estudioTreeId);
-						bool forceInit = true;
-						bool questionMade = false;
 
 						for (IModeloEstudio::ListaSeriesType::const_iterator it3 = estudio->ListaSeries().begin(); it3 != estudio->ListaSeries().end(); ++it3) {
 							const IModeloSerie& s = *it3;
@@ -1080,37 +982,6 @@ void GNC::GUI::DialogoAdquisicion::PACSCargarListado(IModeloDicom * pModelo)
 							m_pTreeListResultados->SetItemImage(serieTreeId,ICONO_SERIE,wxTreeItemIcon_Selected);
 							m_pTreeListResultados->SetItemImage(serieTreeId,ICONO_SERIE,wxTreeItemIcon_Expanded);
 							m_pTreeListResultados->SetItemImage(serieTreeId,ICONO_SERIE,wxTreeItemIcon_SelectedExpanded);
-
-							if (m_AutoAddSeries) {
-
-								//std::string uidPaciente = std::string(m_pTreeListResultados->GetItemText(pacienteTreeId, COLUMNA_UID).ToUTF8());
-								std::string descPaciente = std::string(m_pTreeListResultados->GetItemText(pacienteTreeId).ToUTF8());
-								std::string uidStudy = std::string(m_pTreeListResultados->GetItemText(estudioTreeId, COLUMNA_UID).ToUTF8());
-
-								std::string uidSerie = std::string(m_pTreeListResultados->GetItemText(serieTreeId, COLUMNA_UID).ToUTF8());
-								std::string descSerie = std::string( (m_pTreeListResultados->GetItemText(serieTreeId) + _T("(") + m_pTreeListResultados->GetItemText(serieTreeId, COLUMNA_MODALIDAD) + _T(")") ).ToUTF8());
-
-								std::string modalidadSerie = std::string(m_pTreeListResultados->GetItemText(serieTreeId, COLUMNA_MODALIDAD).ToUTF8());
-
-								if( IsAllowedToDownload( modalidadSerie) ) {
-									if (!questionMade && m_pDownloadPanel->FindDownload(uidSerie)) {
-										Thaw();
-										forceInit = wxMessageBox(_("Series were already in the download queue.\nDo you want to force download?"),_("Download warning"),wxICON_INFORMATION|wxYES_NO) == wxYES;
-										Freeze();
-										questionMade = true;
-									}
-
-									bool downloaded = m_pDownloadPanel->AddDownload(GetServerSeleccionado(), descPaciente, descSerie, modalidadSerie,forceInit, true, uidStudy, uidSerie);
-									m_pTreeListResultados->SetItemBold(serieTreeId, downloaded);
-								} else {
-									listaModalidad.insert(modalidadSerie);
-								}
-							}
-
-						}
-						if (m_AutoAddSeries) {
-							m_AutoAddSeries = false;
-							m_AutoAddSeriesItem = NULL;
 						}
 						m_pTreeListResultados->SortChildren(estudioTreeId);
 						m_pTreeListResultados->Expand(estudioTreeId);
@@ -1308,7 +1179,7 @@ void GNC::GUI::DialogoAdquisicion::PACSCargarListado(IModeloDicom * pModelo)
 						if (!estudioTreeId) {
 							continue;
 						}
-						
+
 						if (m_Mode == TD_SERIES) 
 						{
 							for (IModeloEstudio::ListaSeriesType::const_iterator it3 = e.ListaSeries().begin(); it3 != e.ListaSeries().end(); ++it3) {
@@ -1400,22 +1271,84 @@ void GNC::GUI::DialogoAdquisicion::PACSCargarListado(IModeloDicom * pModelo)
 void GNC::GUI::DialogoAdquisicion::ProcesarEvento(GNC::GCS::Events::IEvent *evt)
 {
 	GNC::GCS::Events::EventoProgresoComando* pEvt = dynamic_cast<GNC::GCS::Events::EventoProgresoComando*> (evt);
-	if (pEvt == NULL  || pEvt->GetComando() == NULL || pEvt->GetComando() != m_pComandoPACS) {
+	if (pEvt == NULL  || pEvt->GetComando() == NULL) {
 		return;
 	}
+	
 	switch (pEvt->GetTipo()) {
-case GNC::GCS::Events::EventoProgresoComando::TEP_Iniciado:
-	break;
-case GNC::GCS::Events::EventoProgresoComando::TEP_Progreso:
-	break;
-case GNC::GCS::Events::EventoProgresoComando::TEP_Finalizado:
-	m_pTextControlField->ShowCancelButton(false);
-	ShowAnimation(false);
-	m_pComandoPACS = NULL;
-	break;
-case GNC::GCS::Events::EventoProgresoComando::TEP_Unknown:
-	break;
+	case GNC::GCS::Events::EventoProgresoComando::TEP_Iniciado:
+		break;
+	case GNC::GCS::Events::EventoProgresoComando::TEP_Progreso:
+		break;
+	case GNC::GCS::Events::EventoProgresoComando::TEP_Unknown:
+		break;
+	case GNC::GCS::Events::EventoProgresoComando::TEP_Finalizado:
+		GNC::GCS::IComando* pCmd = pEvt->GetComando();
+		if (pCmd->GetOwner() == this) {
+			if ( pCmd == m_pComandoPACS ) {
+				m_pTextControlField->ShowCancelButton(false);
+				ShowAnimation(false);
+				m_pComandoPACS = NULL;
+			}
+		}
+		break;
+	
 	}
 }
 
-//endregion
+bool GNC::GUI::DialogoAdquisicion::AddDownload(const std::string& server, const std::string& modality, bool seriesMode, const std::string& studyUID, const std::string& seriesUID, bool link)
+{
+	if (server.empty() || (studyUID.empty() && seriesUID.empty())) {
+		LOG_ERROR("GUI/Adquisition", "Empty mandatory values <serverId>, <studyInstanceUID | serieInstanceUID> while adding serie to download queue");
+		return false;
+	}
+
+	GADAPI::PACSDownloadCommandParams * pParams;
+	{
+		GIL::DICOM::DicomDataset base;
+		if (seriesMode) {
+			if (!seriesUID.empty() && GNC::GCS::HistoryController::Instance()->ExistsSeriesWithUID(seriesUID)) 
+			{
+				DownloadAgainDialog dlg(this, seriesUID, true);
+				int answer = dlg.ShowModal();
+				if (answer != wxID_OK) {
+					return false;
+				}
+			}
+			base.tags["0008|0052"] = "SERIES";
+			base.tags["0020|000e"] = seriesUID; //series instance uid
+			if (!modality.empty()) {
+				base.tags["0008|0060"] = modality; //modalitiy
+			}
+		} else {
+			if (!studyUID.empty()) {
+				if (GNC::GCS::HistoryController::Instance()->ExistsStudyWithUID(studyUID)) 
+				{
+					DownloadAgainDialog dlg(this, studyUID, false);
+					int answer = dlg.ShowModal();
+					if (answer != wxID_OK) {
+						return false;
+					}
+				}
+				base.tags["0020|000d"] = studyUID; //study instance uid
+			
+			}
+			base.tags["0008|0052"] = "STUDY";
+		}
+		pParams = new GADAPI::PACSDownloadCommandParams(server, base, link);
+	}
+
+	if (seriesMode) {
+		LOG_INFO("GUI/Adquisition", _Std("Downloading serie..."));
+	}
+	else {
+		LOG_INFO("GUI/Adquisition", _Std("Downloading study..."));
+	}
+	GNC::GCS::IComando* pCommand = new GADAPI::PACSDownloadCommand(pParams);
+	
+	GNC::Entorno::Instance()->GetCommandController()->ProcessAsync(_Std("Downloading from PACS..."), pCommand, this);
+
+	return true;
+
+	//endregion
+}
\ No newline at end of file
