@@ -1,16 +1,16 @@
 /*
- *
- *  $Id: panelconfiguracionpermisos.cpp $
- *  Ginkgo CADx Project
- *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
- *  http://ginkgo-cadx.com
- *
- *  This file is licensed under LGPL v3 license.
- *  See License.txt for details
- *
- *
- */
+*
+*  $Id: panelconfiguracionpermisos.cpp $
+*  Ginkgo CADx Project
+*
+*  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+*  http://ginkgo-cadx.com
+*
+*  This file is licensed under LGPL v3 license.
+*  See License.txt for details
+*
+*
+*/
 #include <vector>
 #include <sstream>
 #include <limits>
@@ -47,11 +47,11 @@ namespace GNC {
 				SetToolBitmapSize(wxSize(16,16));
 
 				wxAuiDefaultToolBarArt* pToolArt= new wxAuiDefaultToolBarArt();
-			#if defined(USE_PATCHED_LIBS) && !defined(__WXOSX__)
+#if defined(USE_PATCHED_LIBS) && !defined(__WXOSX__)
 				pToolArt->SetBaseColor(color);
 
 				pToolArt->SetFont(fuente);
-			#endif
+#endif
 				SetArtProvider(pToolArt);
 
 				Realize();
@@ -121,6 +121,8 @@ namespace GNC {
 				listId.push_back(GKDCM_Modality);
 				listId.push_back(GKDCM_BodyPartExamined);
 				listId.push_back(GKDCM_Laterality);
+				listId.push_back(GKDCM_ImageLaterality);
+				listId.push_back(GKDCM_PatientOrientation);
 				listId.push_back(GKDCM_InstitutionName);
 				listId.push_back(GKDCM_StationName);
 				listId.push_back(GKDCM_InstitutionalDepartmentName);
@@ -241,130 +243,347 @@ namespace GNC {
 			}
 
 		};
-		
+
 		////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-		class EditHangingProtocolDialog: public EditHangingProtocolDialogBase, public GNC::GCS::IHangingProtocolContract
+		class EditHangingProtocolDialog: public EditHangingProtocolDialogBase
 		{
-			class PreviewLayoutPanel: public wxPanel, public GNC::GCS::IHangingSeriesViewer
+			class StudyWindow: public StudyWindowBase, public GNC::GCS::IHangingProtocolContract
 			{
-			public:
-				PreviewLayoutPanel(EditHangingProtocolDialog* pSelectionManager, wxWindow* pParent, const GNC::GCS::Ptr<GNC::GCS::Matcher>& seriesMatcher = NULL): wxPanel(pParent, wxID_ANY, wxDefaultPosition, wxSize(100,100)),
-					isSelected(false),
-					pEdigHangingDialog(pSelectionManager)
+				class PreviewLayoutPanel: public wxPanel, public GNC::GCS::IHangingSeriesViewer
 				{
-					wxPanel::SetBackgroundColour(wxBG_STYLE_CUSTOM);
-					if (seriesMatcher.IsValid()) {
-						this->seriesMatcher = seriesMatcher;
-					} else {
-						this->seriesMatcher = new GNC::GCS::Matcher();
-						this->seriesMatcher->getMatchingCriteria()[GKDCM_SeriesDescription] =  "";
-						this->seriesMatcher->getMatchingCriteria()[GKDCM_Modality] =  "";
-					}
-
-					this->Connect( wxEVT_LEFT_UP, wxMouseEventHandler( PreviewLayoutPanel::OnLeftClick ) );
-					this->Connect( wxEVT_RIGHT_DOWN, wxMouseEventHandler( PreviewLayoutPanel::OnRightClick ) );
-					this->Connect( wxEVT_PAINT, wxPaintEventHandler( PreviewLayoutPanel::OnPaint ) );
-				}
-
-				~PreviewLayoutPanel()
-				{
-					this->Disconnect( wxEVT_LEFT_UP, wxMouseEventHandler( PreviewLayoutPanel::OnLeftClick ) );
-					this->Disconnect( wxEVT_RIGHT_DOWN, wxMouseEventHandler( PreviewLayoutPanel::OnRightClick ) );
-					this->Disconnect( wxEVT_PAINT, wxPaintEventHandler( PreviewLayoutPanel::OnPaint ) );
-				}
-
-				void select(bool selected) 
-				{
-					if (selected != isSelected) {
-						isSelected = selected;
-						Refresh(true);
-					}
-				}
-
-				GNC::GCS::Ptr<GNC::GCS::Matcher>& getMatcher()
-				{
-					return this->seriesMatcher;
-				}
-
-				void getSeriesBase(GIL::DICOM::DicomDataset& seriesBase)
-				{
-					for (std::map<std::string, std::string>::iterator it = seriesMatcher->getMatchingCriteria().begin(); it != seriesMatcher->getMatchingCriteria().end(); ++it)
+				public:
+					PreviewLayoutPanel(StudyWindow* pSelectionManager, wxWindow* pParent, const GNC::GCS::Ptr<GNC::GCS::Matcher>& seriesMatcher = NULL): wxPanel(pParent, wxID_ANY, wxDefaultPosition, wxSize(100,100)),
+						isSelected(false),
+						pStudyWindow(pSelectionManager)
 					{
-						seriesBase.tags[(*it).first] = (*it).second;
-					}
-				}
-			protected:
-				virtual void OnLeftClick(wxMouseEvent &)
-				{
-					if (pEdigHangingDialog->hangingSupportLevel == GNC::GCS::ModoControlador::THSL_FULL) {
-						pEdigHangingDialog->doSelect(this);
-					}
-				}
+						wxPanel::SetBackgroundColour(wxBG_STYLE_CUSTOM);
+						if (seriesMatcher.IsValid()) {
+							this->seriesMatcher = seriesMatcher;
+						} else {
+							this->seriesMatcher = new GNC::GCS::Matcher();
+							this->seriesMatcher->getMatchingCriteria()[GKDCM_SeriesDescription] =  "";
+							this->seriesMatcher->getMatchingCriteria()[GKDCM_Modality] =  "";
+						}
 
-				virtual void OnRightClick(wxMouseEvent &)
-				{
-					if (pEdigHangingDialog->hangingSupportLevel == GNC::GCS::ModoControlador::THSL_FULL) {
-						pEdigHangingDialog->doSelect(this);
-						wxMenu popupMenu;
-						int id = 0;
-						wxMenuItem* pItem = popupMenu.Append(id, _("Split horizontally..."));
-						#ifdef __WXMSW__
-						pItem->SetBitmaps(GinkgoResourcesManager::LayoutBar::GetIcoLayout2x1Blue());
-						#else
-						pItem->SetBitmap(GinkgoResourcesManager::LayoutBar::GetIcoLayout2x1Blue());
-						#endif						
-						popupMenu.Connect(id++,wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( PreviewLayoutPanel::OnSplitH ), NULL, this);
-						pItem = popupMenu.Append(id, _("Split vertically..."));
-						#ifdef __WXMSW__
-						pItem->SetBitmaps(GinkgoResourcesManager::LayoutBar::GetIcoLayout1x2Blue());
-						#else
-						pItem->SetBitmap(GinkgoResourcesManager::LayoutBar::GetIcoLayout1x2Blue());
-						#endif
-						popupMenu.Connect(id++,wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( PreviewLayoutPanel::OnSplitV ), NULL, this);
-						this->PopupMenu(&popupMenu);
-					}
-				}
-
-				virtual void OnSplitH(wxCommandEvent& )
-				{
-					pEdigHangingDialog->SplitActive(true);
-				}
-
-				virtual void OnSplitV(wxCommandEvent& )
-				{
-					pEdigHangingDialog->SplitActive(false);
-				}
-
-				virtual void OnPaint(wxPaintEvent &/*event*/)
-				{
-					wxPaintDC dc(this);
-					//no muestra la rallita de abajo
-					//wxBufferedPaintDC dc(this);
-
-					const int width = dc.GetSize().x;
-					const int height = dc.GetSize().y;
-					// Title background
-					wxRect rTitle(0, 0, width, height);
-					if (this->isSelected) {
-						dc.GradientFillLinear(rTitle, wxColour(50, 180, 50), wxColour(100, 230, 100), wxWEST);
-					} else {
-						dc.GradientFillLinear(rTitle, wxColour(180, 180, 180), wxColour(230, 230, 230), wxWEST);
+						this->Connect( wxEVT_LEFT_UP, wxMouseEventHandler( PreviewLayoutPanel::OnLeftClick ) );
+						this->Connect( wxEVT_RIGHT_DOWN, wxMouseEventHandler( PreviewLayoutPanel::OnRightClick ) );
+						this->Connect( wxEVT_PAINT, wxPaintEventHandler( PreviewLayoutPanel::OnPaint ) );
 					}
 
-					// Title border
-					dc.SetBrush(*wxTRANSPARENT_BRUSH);
-					if (this->isSelected) {
-						dc.SetPen(wxPen(wxColour(30, 115, 30), 1, wxSOLID));
-					} else {
-						dc.SetPen(wxPen(wxColour(115, 115, 115), 1, wxSOLID));
+					~PreviewLayoutPanel()
+					{
+						this->Disconnect( wxEVT_LEFT_UP, wxMouseEventHandler( PreviewLayoutPanel::OnLeftClick ) );
+						this->Disconnect( wxEVT_RIGHT_DOWN, wxMouseEventHandler( PreviewLayoutPanel::OnRightClick ) );
+						this->Disconnect( wxEVT_PAINT, wxPaintEventHandler( PreviewLayoutPanel::OnPaint ) );
 					}
-					dc.DrawRectangle(rTitle);
-				}
 
-				GNC::GCS::Ptr<GNC::GCS::Matcher> seriesMatcher;
-				bool isSelected;
-				EditHangingProtocolDialog* pEdigHangingDialog;
-			};
+					void select(bool selected) 
+					{
+						if (selected != isSelected) {
+							isSelected = selected;
+							Refresh(true);
+						}
+					}
+
+					GNC::GCS::Ptr<GNC::GCS::Matcher>& getMatcher()
+					{
+						return this->seriesMatcher;
+					}
+
+					void getSeriesBase(GIL::DICOM::DicomDataset& seriesBase)
+					{
+						for (std::map<std::string, std::string>::iterator it = seriesMatcher->getMatchingCriteria().begin(); it != seriesMatcher->getMatchingCriteria().end(); ++it)
+						{
+							seriesBase.tags[(*it).first] = (*it).second;
+						}
+					}
+				protected:
+					virtual void OnLeftClick(wxMouseEvent &)
+					{
+						if (pStudyWindow->hangingSupportLevel == GNC::GCS::ModoControlador::THSL_FULL) {
+							pStudyWindow->doSelect(this);
+						}
+					}
+
+					virtual void OnRightClick(wxMouseEvent &)
+					{
+						if (pStudyWindow->hangingSupportLevel == GNC::GCS::ModoControlador::THSL_FULL) {
+							pStudyWindow->doSelect(this);
+							wxMenu popupMenu;
+							int id = 0;
+							wxMenuItem* pItem = popupMenu.Append(id, _("Split horizontally..."));
+	#ifdef __WXMSW__
+							pItem->SetBitmaps(GinkgoResourcesManager::LayoutBar::GetIcoLayout2x1Blue());
+	#else
+							pItem->SetBitmap(GinkgoResourcesManager::LayoutBar::GetIcoLayout2x1Blue());
+	#endif						
+							popupMenu.Connect(id++,wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( PreviewLayoutPanel::OnSplitH ), NULL, this);
+							pItem = popupMenu.Append(id, _("Split vertically..."));
+	#ifdef __WXMSW__
+							pItem->SetBitmaps(GinkgoResourcesManager::LayoutBar::GetIcoLayout1x2Blue());
+	#else
+							pItem->SetBitmap(GinkgoResourcesManager::LayoutBar::GetIcoLayout1x2Blue());
+	#endif
+							popupMenu.Connect(id++,wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( PreviewLayoutPanel::OnSplitV ), NULL, this);
+							pItem = popupMenu.Append(id, _("Reset"));
+	#ifdef __WXMSW__
+							pItem->SetBitmaps(GinkgoResourcesManager::MenuIcons::GetIcoReset());
+	#else
+							pItem->SetBitmap(GinkgoResourcesManager::MenuIcons::GetIcoReset());
+	#endif
+							popupMenu.Connect(id++,wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( PreviewLayoutPanel::OnResetLayout ), NULL, this);
+							this->PopupMenu(&popupMenu);
+						}
+					}
+
+					virtual void OnSplitH(wxCommandEvent& )
+					{
+						pStudyWindow->SplitActive(true);
+					}
+
+					virtual void OnSplitV(wxCommandEvent& )
+					{
+						pStudyWindow->SplitActive(false);
+					}
+
+					virtual void OnResetLayout(wxCommandEvent &)
+					{
+						pStudyWindow->RebuildLayout();
+					}
+
+					virtual void OnPaint(wxPaintEvent &/*event*/)
+					{
+						wxPaintDC dc(this);
+						//no muestra la rallita de abajo
+						//wxBufferedPaintDC dc(this);
+
+						const int width = dc.GetSize().x;
+						const int height = dc.GetSize().y;
+						// Title background
+						wxRect rTitle(0, 0, width, height);
+						if (this->isSelected) {
+							dc.GradientFillLinear(rTitle, wxColour(50, 180, 50), wxColour(100, 230, 100), wxWEST);
+						} else {
+							dc.GradientFillLinear(rTitle, wxColour(180, 180, 180), wxColour(230, 230, 230), wxWEST);
+						}
+
+						// Title border
+						dc.SetBrush(*wxTRANSPARENT_BRUSH);
+						if (this->isSelected) {
+							dc.SetPen(wxPen(wxColour(30, 115, 30), 1, wxSOLID));
+						} else {
+							dc.SetPen(wxPen(wxColour(115, 115, 115), 1, wxSOLID));
+						}
+						dc.DrawRectangle(rTitle);
+					}
+
+					GNC::GCS::Ptr<GNC::GCS::Matcher> seriesMatcher;
+					bool isSelected;
+					StudyWindow* pStudyWindow;
+				};//end PreviewPanel
+				public:
+					StudyWindow(wxWindow* pParent): StudyWindowBase(pParent), layout(new GNC::GCS::Layout())
+					{
+					}
+
+					StudyWindow(wxWindow* pParent, const GNC::GCS::Ptr<GNC::GCS::Layout>& lo): StudyWindowBase(pParent),
+						layout(lo)
+					{
+					}
+					~StudyWindow()
+					{
+						listPreviewLayouts.clear();
+					}
+
+					void InitPanels(GNC::GCS::ModoControlador::T_HangingProtocolSupportLevel hsl)
+					{
+						this->hangingSupportLevel = hsl;
+
+						editSeriesCriteriaPanel = new EditCriteriaPanel(m_panelSeriesCriteria);
+						m_pSizerSeriesCriteria->Add(editSeriesCriteriaPanel, 1, wxEXPAND|wxALL, 5);
+						m_panelSeriesCriteria->Layout();
+
+						m_pSpinCols->Enable(hangingSupportLevel != GNC::GCS::ModoControlador::THSL_ONLY_1x1);
+						m_pSpinRows->Enable(hangingSupportLevel != GNC::GCS::ModoControlador::THSL_ONLY_1x1);
+						m_pSetupPositionButton->Enable(hangingSupportLevel != GNC::GCS::ModoControlador::THSL_ONLY_1x1);
+
+						//button bar
+						{
+							wxColour barColor = wxColour(200,200,200);
+							wxFont fontBar = wxFont( 10, 70, 90, wxFONTWEIGHT_BOLD, false, wxEmptyString );
+							HangingButtonsBar* m_pButtonsBar = new HangingButtonsBar(m_pLayoutPreview, barColor, fontBar, wxAUI_TB_DEFAULT_STYLE);
+							int i = 1;
+							m_pButtonsBar->AddTool(i, _("Split active horizontally"), GinkgoResourcesManager::LayoutBar::GetIcoLayout2x1Blue(), _("Split active horizontally"));
+							m_pButtonsBar->EnableTool(i, hangingSupportLevel == GNC::GCS::ModoControlador::THSL_FULL);
+							m_pButtonsBar->Connect(i++, wxEVT_COMMAND_TOOL_CLICKED, wxCommandEventHandler(StudyWindow::OnSplitH), NULL, this);
+							m_pButtonsBar->AddTool(i, _("Split active vertically"), GinkgoResourcesManager::LayoutBar::GetIcoLayout1x2Blue(), _("Split active vertically"));
+							m_pButtonsBar->EnableTool(i, hangingSupportLevel == GNC::GCS::ModoControlador::THSL_FULL);
+							m_pButtonsBar->Connect(i++, wxEVT_COMMAND_TOOL_CLICKED, wxCommandEventHandler(StudyWindow::OnSplitV), NULL, this);
+							m_pButtonsBar->AddTool(i, _("Reset"), GinkgoResourcesManager::MenuIcons::GetIcoReset(), _("Reset"));
+							m_pButtonsBar->EnableTool(i, hangingSupportLevel == GNC::GCS::ModoControlador::THSL_FULL);
+							m_pButtonsBar->Connect(i++, wxEVT_COMMAND_TOOL_CLICKED, wxCommandEventHandler(StudyWindow::OnResetLayout), NULL, this);
+							m_pButtonsBar->Realize();
+							m_pSizerLayoutTools->Insert(0,m_pButtonsBar, 0, wxEXPAND| wxALL, 0);
+						} 
+
+						if (layout.IsValid()) {
+							this->m_pSpinRows->SetValue(layout->getRows());
+							this->m_pSpinCols->SetValue(layout->getColumns());
+						}
+						//dolayout...
+						doLayout();
+					}
+
+					/**
+					IHangingProtocolContract
+					*/
+					virtual wxWindow* createSeriesViewer(const std::map<std::string, std::string>& /*properties*/, long /*pk = -1*/, const GNC::GCS::Ptr<GNC::GCS::Matcher>& matcher)
+					{
+						listPreviewLayouts.push_back(new PreviewLayoutPanel(this, m_pLayoutPreview, matcher));
+						return listPreviewLayouts.back();
+					}
+
+					virtual const std::list<long>& getOpeningSeries()
+					{
+						return fooList;
+					}
+					//
+					void doLayout()
+					{
+						m_pLayoutPreview->Freeze();
+						selectedPreview = NULL;
+						m_pPreviewSizer->Clear(true);
+						listPreviewLayouts.clear();
+
+						layout->doLayout(this, m_pPreviewSizer);
+
+						if (!listPreviewLayouts.empty()) {
+							for (std::list<PreviewLayoutPanel*>::const_iterator it = listPreviewLayouts.begin(); it != listPreviewLayouts.end(); ++it) {
+								(*it)->select((*it) == selectedPreview);
+							}
+							doSelect(listPreviewLayouts.front());
+						}
+
+						m_pLayoutPreview->Layout();
+						m_pLayoutPreview->Thaw();
+						Layout();
+					}
+					
+					void doSelect(PreviewLayoutPanel* pPanel) {
+						if (selectedPreview == pPanel)
+							return;
+						m_pLayoutPreview->Freeze();
+						if (selectedPreview != NULL) {
+							selectedPreview->select(false);
+							//store matcher...
+							editSeriesCriteriaPanel->updateMatcher(selectedPreview->getMatcher());
+						}
+						selectedPreview = pPanel;
+						selectedPreview->select(true);
+
+						editSeriesCriteriaPanel->loadMatcher(selectedPreview->getMatcher());
+						m_pLayoutPreview->Thaw();
+					}
+
+					void SplitActive(bool horizontally)
+					{
+						m_pLayoutPreview->Freeze();
+						wxBoxSizer* pNewSizer;
+						if (horizontally) {
+							pNewSizer = new wxBoxSizer(wxVERTICAL);
+						} else {
+							pNewSizer = new wxBoxSizer(wxHORIZONTAL);
+						}
+						wxSizer* pSizerActive = (wxSizer*)selectedPreview->GetContainingSizer();
+						wxSizerItem* pItem = pSizerActive->GetItem(selectedPreview);
+
+						pItem->SetSizer(pNewSizer);
+						pNewSizer->Add(selectedPreview, 1, wxEXPAND|wxALL);
+						std::map<std::string, std::string> prop;
+						pNewSizer->Add(createSeriesViewer(prop, -1, NULL), 1, wxEXPAND|wxALL);
+						m_pLayoutPreview->Layout();
+						m_pLayoutPreview->Thaw();
+					}			
+
+					GNC::GCS::Ptr<GNC::GCS::Layout> GetLayout()
+					{
+						if (selectedPreview != NULL) {
+							editSeriesCriteriaPanel->updateMatcher(selectedPreview->getMatcher());
+						}
+
+						if (hangingSupportLevel == GNC::GCS::ModoControlador::THSL_FULL) {
+							GNC::GCS::Ptr<GNC::GCS::Layout> pLayout = GNC::GCS::Layout::getLayoutFromSizer(m_pPreviewSizer);
+							pLayout->copyWindowProperties(*layout);
+							return pLayout;
+						} else {
+							GNC::GCS::Ptr<GNC::GCS::Layout> pLayout(new GNC::GCS::Layout());
+							pLayout->setRows(m_pSpinRows->GetValue());
+							pLayout->setColumns(m_pSpinCols->GetValue());
+							GNC::GCS::Ptr<GNC::GCS::Matcher> pSeriesMatcher(new GNC::GCS::Matcher());
+							editSeriesCriteriaPanel->updateMatcher(pSeriesMatcher);
+							pLayout->setMatcher(pSeriesMatcher);
+							pLayout->copyWindowProperties(*layout);
+							return pLayout;
+						}
+					}
+				protected:
+					virtual void OnSpinRows( wxSpinEvent&  )
+					{
+						RebuildLayout();
+					}
+
+					virtual void OnSpinCols( wxSpinEvent&  )
+					{
+						RebuildLayout();
+					}
+
+					virtual void OnSplitH(wxCommandEvent &)
+					{
+						SplitActive(true);
+					}
+
+					virtual void OnSplitV(wxCommandEvent &)
+					{
+						SplitActive(false);
+					}
+
+					virtual void OnResetLayout(wxCommandEvent &) 
+					{
+						RebuildLayout();
+					}
+
+					virtual void RebuildLayout() 
+					{
+						//rebuild layout...
+						layout->setColumns(m_pSpinCols->GetValue());
+						layout->setRows(m_pSpinRows->GetValue());
+						doLayout();
+					}
+
+				
+					//setup window position
+					virtual void OnSetupWindowPositionClick(wxCommandEvent &) 
+					{
+						SetupWindowPositionBase dlg(this);
+						layout->applyWindowProperties(&dlg);
+						if (dlg.ShowModal() == wxID_OK) {
+							layout->setWindowProperties(dlg.IsMaximized(), dlg.GetPosition().x, dlg.GetPosition().y, dlg.GetSize().x, dlg.GetSize().y);
+						}
+					}
+
+					virtual void OnSetDefaultWindowPosition(wxCommandEvent &)
+					{
+						layout->setDefaultPosition();
+					}
+
+
+					GNC::GCS::Ptr<GNC::GCS::Layout> layout;
+					EditCriteriaPanel* editSeriesCriteriaPanel;
+					std::list<long> fooList;
+					PreviewLayoutPanel* selectedPreview;
+					std::list<PreviewLayoutPanel*> listPreviewLayouts;
+					GNC::GCS::ModoControlador::T_HangingProtocolSupportLevel hangingSupportLevel;
+				};//end StudyWindow
 		public:
 			EditHangingProtocolDialog(wxWindow* pParent): EditHangingProtocolDialogBase(pParent)
 			{	
@@ -376,7 +595,6 @@ namespace GNC {
 
 			~EditHangingProtocolDialog()
 			{
-				listPreviewLayouts.clear();
 			}
 
 			virtual int ShowModal()
@@ -392,6 +610,9 @@ namespace GNC {
 						studyMatcher->getMatchingCriteria()[GKDCM_ModalitiesInStudy] =  "";
 						studyMatcher->getMatchingCriteria()[GKDCM_StudyDescription] =  "";
 						hangingProtocol->setStudyMatcher(studyMatcher);
+						//add new layout...
+						GNC::GCS::Ptr<GNC::GCS::Layout> layout(new GNC::GCS::Layout());
+						hangingProtocol->addLayout(layout);
 					} else {
 						return wxID_CANCEL;
 					}
@@ -400,152 +621,11 @@ namespace GNC {
 				return EditHangingProtocolDialogBase::ShowModal();
 			}
 
-			/**
-			IHangingProtocolContract
-			*/
-			virtual wxWindow* createSeriesViewer(const std::map<std::string, std::string>& /*properties*/, long /*pk = -1*/, const GNC::GCS::Ptr<GNC::GCS::Matcher>& matcher)
-			{
-				listPreviewLayouts.push_back(new PreviewLayoutPanel(this, m_pLayoutPreview, matcher));
-				return listPreviewLayouts.back();
-			}
-
-			virtual const std::list<long>& getOpeningSeries()
-			{
-				return fooList;
-			}
-			//
-			void doLayout()
-			{
-				m_pLayoutPreview->Freeze();
-				selectedPreview = NULL;
-				m_pPreviewSizer->Clear(true);
-				listPreviewLayouts.clear();
-				if (!hangingProtocol->getLayout().IsValid()) {
-					//basic layout...
-					GNC::GCS::Ptr<GNC::GCS::Layout> layout(new GNC::GCS::Layout());
-					layout->setRows(m_pSpinRows->GetValue());
-					layout->setColumns(m_pSpinCols->GetValue());
-					hangingProtocol->setLayout(layout);
-				}
-
-				hangingProtocol->getLayout()->doLayout(this, m_pPreviewSizer);
-				
-				if (!listPreviewLayouts.empty()) {
-					for (std::list<PreviewLayoutPanel*>::const_iterator it = listPreviewLayouts.begin(); it != listPreviewLayouts.end(); ++it) {
-						(*it)->select((*it) == selectedPreview);
-					}
-					doSelect(listPreviewLayouts.front());
-				}
-
-				m_pLayoutPreview->Layout();
-				m_pLayoutPreview->Thaw();
-				m_pLayoutPreview->Refresh();
-			}
-
-			void doSelect(PreviewLayoutPanel* pPanel) {
-				if (selectedPreview == pPanel)
-					return;
-				m_pLayoutPreview->Freeze();
-				if (selectedPreview != NULL) {
-					selectedPreview->select(false);
-					//store matcher...
-					editSeriesCriteriaPanel->updateMatcher(selectedPreview->getMatcher());
-				}
-				selectedPreview = pPanel;
-				selectedPreview->select(true);
-
-				editSeriesCriteriaPanel->loadMatcher(selectedPreview->getMatcher());
-				m_pLayoutPreview->Thaw();
-			}
-
-			void SplitActive(bool horizontally)
-			{
-				m_pLayoutPreview->Freeze();
-				wxBoxSizer* pNewSizer;
-				if (horizontally) {
-					pNewSizer = new wxBoxSizer(wxVERTICAL);
-				} else {
-					pNewSizer = new wxBoxSizer(wxHORIZONTAL);
-				}
-				wxSizer* pSizerActive = (wxSizer*)selectedPreview->GetContainingSizer();
-				wxSizerItem* pItem = pSizerActive->GetItem(selectedPreview);
-
-				pItem->SetSizer(pNewSizer);
-				pNewSizer->Add(selectedPreview, 1, wxEXPAND|wxALL);
-				std::map<std::string, std::string> prop;
-				pNewSizer->Add(createSeriesViewer(prop, -1, NULL), 1, wxEXPAND|wxALL);
-				m_pLayoutPreview->Layout();
-				m_pLayoutPreview->Thaw();
-			}
-
-			GNC::GCS::Ptr<GNC::GCS::HangingProtocol>& getHangingProtocol()
-			{
-				if (selectedPreview != NULL) {
-					editSeriesCriteriaPanel->updateMatcher(selectedPreview->getMatcher());
-				}
-
-				this->hangingProtocol->setDescription(std::string(m_textDescription->GetValue().ToUTF8()));
-				this->hangingProtocol->setName(std::string(m_textName->GetValue().ToUTF8()));
-				GNC::GCS::Ptr<GNC::GCS::Matcher> pStudyMatcher(new GNC::GCS::Matcher());
-				editStudyCriteriaPanel->updateMatcher(pStudyMatcher);
-				this->hangingProtocol->setStudyMatcher(pStudyMatcher);
-				if (hangingSupportLevel == GNC::GCS::ModoControlador::THSL_FULL) {
-					this->hangingProtocol->setLayout(GNC::GCS::Layout::getLayoutFromSizer(m_pPreviewSizer));
-				} else {
-					GNC::GCS::Ptr<GNC::GCS::Layout> pLayout(new GNC::GCS::Layout());
-					pLayout->setRows(m_pSpinRows->GetValue());
-					pLayout->setColumns(m_pSpinCols->GetValue());
-					GNC::GCS::Ptr<GNC::GCS::Matcher> pSeriesMatcher(new GNC::GCS::Matcher());
-					editSeriesCriteriaPanel->updateMatcher(pSeriesMatcher);
-					pLayout->setMatcher(pSeriesMatcher);
-					this->hangingProtocol->setLayout(pLayout);
-				}
-				return this->hangingProtocol;
-			}
-		protected:
-			virtual void OnSpinRows( wxSpinEvent&  )
-			{
-				RebuildLayout();
-			}
-
-			virtual void OnSpinCols( wxSpinEvent&  )
-			{
-				RebuildLayout();
-			}
-
-			virtual void OnSplitH(wxCommandEvent &)
-			{
-				SplitActive(true);
-			}
-
-			virtual void OnSplitV(wxCommandEvent &)
-			{
-				SplitActive(false);
-			}
-
-			virtual void RebuildLayout() 
-			{
-				//rebuild layout...
-				GNC::GCS::Ptr<GNC::GCS::Layout> newLayout(new GNC::GCS::Layout());
-				newLayout->setColumns(m_pSpinCols->GetValue());
-				newLayout->setRows(m_pSpinRows->GetValue());
-				hangingProtocol->setLayout(newLayout);
-				doLayout();
-				Layout();
-			}
 
 			void InitPanels()
 			{
-				editStudyCriteriaPanel = new EditCriteriaPanel(m_panelStudyCriteria);
+				editStudyCriteriaPanel = new EditCriteriaPanel(m_pGeneralPanel);
 				m_pSizerStudyCriteria->Add(editStudyCriteriaPanel, 1, wxEXPAND|wxALL, 5);
-				m_panelStudyCriteria->Layout();
-				m_pPanelGeneral->Layout();
-
-				editSeriesCriteriaPanel = new EditCriteriaPanel(m_panelSeriesCriteria);
-				m_pSizerSeriesCriteria->Add(editSeriesCriteriaPanel, 1, wxEXPAND|wxALL, 5);
-				m_panelSeriesCriteria->Layout();
-				m_pPanelLayout->Layout();
-
 
 				//fillin hanging...
 				m_textOpeningMode->SetValue(wxT("Unknown"));
@@ -559,48 +639,76 @@ namespace GNC {
 					}
 				}
 
-				m_pSpinCols->Enable(hangingSupportLevel != GNC::GCS::ModoControlador::THSL_ONLY_1x1);
-				m_pSpinRows->Enable(hangingSupportLevel != GNC::GCS::ModoControlador::THSL_ONLY_1x1);
-
-				//button bar
+				for (GNC::GCS::HangingProtocol::TListOfLayouts::const_iterator it = hangingProtocol->getLayouts().begin(); it != hangingProtocol->getLayouts().end(); ++it)
 				{
-					wxColour barColor = wxColour(200,200,200);
-					wxFont fontBar = wxFont( 10, 70, 90, wxFONTWEIGHT_BOLD, false, wxEmptyString );
-					HangingButtonsBar* m_pButtonsBar = new HangingButtonsBar(m_pLayoutPreview, barColor, fontBar, wxAUI_TB_DEFAULT_STYLE);
-					int i = 1;
-					m_pButtonsBar->AddTool(i, _("Split active horizontally"), GinkgoResourcesManager::LayoutBar::GetIcoLayout2x1Blue(), _("Split active horizontally"));
-					m_pButtonsBar->EnableTool(i, hangingSupportLevel == GNC::GCS::ModoControlador::THSL_FULL);
-					m_pButtonsBar->Connect(i++, wxEVT_COMMAND_TOOL_CLICKED, wxCommandEventHandler(EditHangingProtocolDialog::OnSplitH), NULL, this);
-					m_pButtonsBar->AddTool(i, _("Split active vertically"), GinkgoResourcesManager::LayoutBar::GetIcoLayout1x2Blue(), _("Split active vertically"));
-					m_pButtonsBar->EnableTool(i, hangingSupportLevel == GNC::GCS::ModoControlador::THSL_FULL);
-					m_pButtonsBar->Connect(i++, wxEVT_COMMAND_TOOL_CLICKED, wxCommandEventHandler(EditHangingProtocolDialog::OnSplitV), NULL, this);
-					m_pButtonsBar->Realize();
-					m_pSizerLayoutTools->Insert(0,m_pButtonsBar, 0, wxEXPAND| wxALL, 0);
-				}
+					if ((*it).IsValid()) {
+						StudyWindow* sw = new StudyWindow(m_pNoteBookWindows, (*it));
+						m_pNoteBookWindows->AddPage(sw, wxString::Format(_("Window %d"), m_pNoteBookWindows->GetPageCount()));
+						sw->InitPanels(hangingSupportLevel);
+					}
+				}								
+
+				m_pAddButton->Enable(hangingSupportLevel != GNC::GCS::ModoControlador::THSL_ONLY_1x1);
+				m_pBDelete->Enable(hangingSupportLevel != GNC::GCS::ModoControlador::THSL_ONLY_1x1 && m_pNoteBookWindows->GetPageCount() > 1);
 
 				m_textName->SetValue(wxString::FromUTF8(hangingProtocol->getName().c_str()));
-				m_textDescription->SetValue(wxString::FromUTF8(hangingProtocol->getDescription().c_str()));
+				this->editStudyCriteriaPanel->loadMatcher(hangingProtocol->getStudyMatcher());			
 
-				this->editStudyCriteriaPanel->loadMatcher(hangingProtocol->getStudyMatcher());
-				
-				if (hangingProtocol->getLayout().IsValid()) {
-					this->m_pSpinRows->SetValue(hangingProtocol->getLayout()->getRows());
-					this->m_pSpinCols->SetValue(hangingProtocol->getLayout()->getColumns());
-				}
-				//dolayout...
-				m_notebook1->Layout();
-				doLayout();
+				m_pNoteBookWindows->Layout();
+				m_pGeneralPanel->Layout();
+				m_pBody->Layout();
 				Layout();
+
+				int ySize = 0;
+				ySize = m_pGeneralPanel->GetSize().x;
+				m_pBody->SetVirtualSize(-1, ySize);
 			}
 
+			GNC::GCS::Ptr<GNC::GCS::HangingProtocol>& getHangingProtocol()
+			{
+				this->hangingProtocol->clearLayouts();
+				this->hangingProtocol->setName(std::string(m_textName->GetValue().ToUTF8()));
+				GNC::GCS::Ptr<GNC::GCS::Matcher> pStudyMatcher(new GNC::GCS::Matcher());
+				editStudyCriteriaPanel->updateMatcher(pStudyMatcher);
+				this->hangingProtocol->setStudyMatcher(pStudyMatcher);
+				for (int i = 0; i < m_pNoteBookWindows->GetPageCount(); ++i) {
+					wxWindow* pWin = m_pNoteBookWindows->GetPage(i);
+					StudyWindow* sw = dynamic_cast<StudyWindow*> (pWin);
+					if (sw != NULL) {
+						GNC::GCS::Ptr<GNC::GCS::Layout> pLayout = sw->GetLayout();
+						if (pLayout.IsValid()) {
+							this->hangingProtocol->addLayout(pLayout);
+						}
+					}
+				}
+				return this->hangingProtocol;
+			}
+
+
 		protected:
-			GNC::GCS::Ptr<GNC::GCS::HangingProtocol> hangingProtocol;
-			EditCriteriaPanel* editStudyCriteriaPanel;			
-			EditCriteriaPanel* editSeriesCriteriaPanel;
-			std::list<long> fooList;
-			PreviewLayoutPanel* selectedPreview;
-			std::list<PreviewLayoutPanel*> listPreviewLayouts;
+			virtual void OnAddStudyWindowClick(wxCommandEvent &)
+			{
+				Freeze();
+				StudyWindow* sw = new StudyWindow(m_pNoteBookWindows);
+				m_pNoteBookWindows->AddPage(sw, wxString::Format(_("Window %d"), m_pNoteBookWindows->GetPageCount()), true);
+				sw->InitPanels(hangingSupportLevel);
+				m_pBDelete->Enable(hangingSupportLevel != GNC::GCS::ModoControlador::THSL_ONLY_1x1 && m_pNoteBookWindows->GetPageCount() > 1);
+				Thaw();
+			}
+
+			virtual void OnDeleteStudyWindowClick(wxCommandEvent &)
+			{
+				if (m_pNoteBookWindows->GetPageCount() > 1) {
+					Freeze();
+					m_pNoteBookWindows->DeletePage(m_pNoteBookWindows->GetSelection());
+					Thaw();
+				}
+				m_pBDelete->Enable(hangingSupportLevel != GNC::GCS::ModoControlador::THSL_ONLY_1x1 && m_pNoteBookWindows->GetPageCount() > 1);
+			}
+
 			GNC::GCS::ModoControlador::T_HangingProtocolSupportLevel hangingSupportLevel;
+			EditCriteriaPanel* editStudyCriteriaPanel;	
+			GNC::GCS::Ptr<GNC::GCS::HangingProtocol> hangingProtocol;	
 		};
 		////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 		class wxTreeItemDataProtocols: public wxTreeItemData
