@@ -1,16 +1,16 @@
-/*
- *  
- *  $Id: panelconfiguracionpacs.cpp $
- *  Ginkgo CADx Project
- *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
- *  http://ginkgo-cadx.com
- *
- *  This file is licensed under LGPL v3 license.
- *  See License.txt for details
- *
- *
- */
+ /*
+*  
+*  $Id: panelconfiguracionpacs.cpp $
+*  Ginkgo CADx Project
+*
+*  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+*  http://ginkgo-cadx.com
+*
+*  This file is licensed under LGPL v3 license.
+*  See License.txt for details
+*
+*
+*/
 #include <vector>
 #include <sstream>
 #include <limits>
@@ -23,6 +23,7 @@
 #include <main/controllers/controladorlog.h>
 #include <main/controllers/controladorpermisos.h>
 
+#include <wx/uri.h>
 #include <wx/msgdlg.h>
 #include <wx/msgout.h>
 #include <wx/filename.h>
@@ -50,9 +51,9 @@
 namespace GNC {
 	namespace GUI {
 
-/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-///////////////////////DialogoEditarCertificado//////////////////////////////////////////////////////////////////////////////////
-/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+		/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+		///////////////////////DialogoEditarCertificado//////////////////////////////////////////////////////////////////////////////////
+		/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 		class DialogoEditarCertificado: public DialogoEditarCertificadoBase
 		{
@@ -62,7 +63,7 @@ namespace GNC {
 				m_Ok = false;
 				m_pTextoCertificado->SetValue(wxString::FromUTF8(cert.c_str()));
 				m_pTextoPrivateKey->SetValue(wxString::FromUTF8(privateKey.c_str()));
-				
+
 				if (permitirDefecto) {
 					m_pCheckDefault->SetValue(cert.size() == 0 && privateKey.size() == 0);
 				} else {
@@ -73,7 +74,7 @@ namespace GNC {
 					Layout();
 					Refresh(true);
 				}
-				
+
 				RefrescarEstado();
 			}
 			~DialogoEditarCertificado()
@@ -170,12 +171,12 @@ namespace GNC {
 				std::string cert(m_pTextoPrivateKey->GetValue().ToUTF8());
 				return cert;
 			}
-			
+
 			bool GetUseDefaultCert()
 			{
 				return m_pCheckDefault->GetValue();
 			}
-			
+
 			bool Validar()
 			{
 				bool ok = true;
@@ -197,9 +198,9 @@ namespace GNC {
 			bool m_Ok;	
 		};
 
-/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-///////////////////////DialogoLocalPACS//////////////////////////////////////////////////////////////////////////////////////////
-/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+		/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+		///////////////////////DialogoLocalPACS//////////////////////////////////////////////////////////////////////////////////////////
+		/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 		class DialogoLocalPACS: public DialogoLocalPACSBase
 		{
@@ -282,9 +283,9 @@ namespace GNC {
 			std::string m_privateKey;
 		};
 
-/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-///////////////////////DialogoServidorPACS///////////////////////////////////////////////////////////////////////////////////////
-/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+		/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+		///////////////////////DialogoServidorPACS///////////////////////////////////////////////////////////////////////////////////////
+		/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 		class DialogoServidorPACS: public DialogoServidorPACSBase
 		{
 		public:
@@ -310,6 +311,15 @@ namespace GNC {
 					m_pPanelSeguridad->Show(false);
 					m_notebook1->RemovePage(1);
 				}
+
+				//worklist settings...
+#ifndef GINKGO_PRO
+				m_pWorkListPanel->Show(false);
+#endif
+				//
+
+				LoadMessageDefaultValues();
+				RefreshHL7Panel();
 			}
 
 			~DialogoServidorPACS()
@@ -317,15 +327,27 @@ namespace GNC {
 
 			}
 
-			void GetParametros(PanelConfiguracionPACS::TipoPACS& tipoPacs)
+			void GetParametros(DicomServer& tipoPacs)
 			{
-				tipoPacs.id = std::string(m_pId->GetValue().ToUTF8());
-				tipoPacs.aet= std::string(m_pAET->GetValue().ToUTF8());
-				tipoPacs.host = std::string(m_pHost->GetValue().ToUTF8());
-				tipoPacs.puerto = atoi(m_pPuerto->GetValue().ToUTF8());
-				tipoPacs.pdu = m_pPDU->GetValue();
+				tipoPacs.ID = std::string(m_pId->GetValue().ToUTF8());
+				tipoPacs.AET= std::string(m_pAET->GetValue().ToUTF8());
+				tipoPacs.HostName = std::string(m_pHost->GetValue().ToUTF8());
+				tipoPacs.Port = atoi(m_pPuerto->GetValue().ToUTF8());
+				tipoPacs.PDU = m_pPDU->GetValue();
 
-				tipoPacs.retrieveWithMove = m_pRetrieveMethod->GetSelection() == 0;
+				switch (m_pRetrieveMethod->GetSelection()) {
+				case 2:
+					tipoPacs.retrieveMethod = DicomServer::WADO;
+					break;
+				case 1:
+					tipoPacs.retrieveMethod = DicomServer::GET;
+					break;
+				case 0:
+				default:
+					tipoPacs.retrieveMethod = DicomServer::MOVE;
+					break;
+				}
+				tipoPacs.wadoURI = std::string(m_pWadoURL->GetValue().ToUTF8());
 				tipoPacs.retrieveSeries = m_pRetrieveMode->GetSelection() == 0;
 
 				tipoPacs.reuseConnection = m_pReuseConnection->GetValue();
@@ -335,25 +357,40 @@ namespace GNC {
 
 					tipoPacs.pacsUser = m_pUser->GetValue().ToUTF8();
 					tipoPacs.pacsPass = m_pPassword->GetValue().ToUTF8();
-					
+
 					tipoPacs.verifyCredentials = m_pVerifyServer->GetValue();
 
 					tipoPacs.certificate = m_certificado;
 					tipoPacs.privateKey = m_privateKey;
 				}
 				tipoPacs.defaultCharset = m_pComboCharset->GetValue().ToUTF8();
+
+				//wl
+				tipoPacs.GetWlConfig().useDICOMMPPS = m_pCheckDICOMMPPS->IsChecked();
+				if (m_pCheckHL7->IsChecked()) {
+					tipoPacs.GetWlConfig().useAbortMessage = m_pCheckAbort->IsChecked();
+					tipoPacs.GetWlConfig().useCompletedMessage = m_pCheckCompleted->IsChecked();
+					tipoPacs.GetWlConfig().useInProgressMessage = m_pCheckInProgress->IsChecked();
+				} else {
+					tipoPacs.GetWlConfig().useAbortMessage = tipoPacs.GetWlConfig().useCompletedMessage = tipoPacs.GetWlConfig().useInProgressMessage = false;
+				}
+				tipoPacs.GetWlConfig().abortTemplate = m_pTextAbort->GetValue().ToUTF8();
+				tipoPacs.GetWlConfig().completedTemplate = m_pTextCompleted->GetValue().ToUTF8();
+				tipoPacs.GetWlConfig().inProgressTemplate = m_pTextProgress->GetValue().ToUTF8();
+				//
 			}
 
-			void SetParametros(PanelConfiguracionPACS::TipoPACS& tipoPacs)
+			void SetParametros(DicomServer& tipoPacs)
 			{
-				m_pId->SetValue(wxString::FromUTF8(tipoPacs.id.c_str()));
-				m_pAET->SetValue(wxString::FromUTF8(tipoPacs.aet.c_str()));
-				m_pHost->SetValue(wxString::FromUTF8(tipoPacs.host.c_str()));
-				m_pPuerto->SetValue(wxString::Format(wxT("%d"), tipoPacs.puerto));
-				m_pPDU->SetValue(wxString::Format(wxT("%d"), tipoPacs.pdu));
+				m_pId->SetValue(wxString::FromUTF8(tipoPacs.ID.c_str()));
+				m_pAET->SetValue(wxString::FromUTF8(tipoPacs.AET.c_str()));
+				m_pHost->SetValue(wxString::FromUTF8(tipoPacs.HostName.c_str()));
+				m_pPuerto->SetValue(wxString::Format(wxT("%d"), tipoPacs.Port));
+				m_pPDU->SetValue(wxString::Format(wxT("%d"), tipoPacs.PDU));
 
-				m_pRetrieveMethod->SetSelection(tipoPacs.retrieveWithMove?0:1);
+				m_pRetrieveMethod->SetSelection((int)tipoPacs.retrieveMethod);
 				m_pRetrieveMode->SetSelection(tipoPacs.retrieveSeries?0:1);
+				m_pWadoURL->SetValue(wxString::FromUTF8(tipoPacs.wadoURI.c_str()));
 
 				m_pReuseConnection->SetValue(tipoPacs.reuseConnection);
 
@@ -367,8 +404,22 @@ namespace GNC {
 					m_certificado = tipoPacs.certificate;
 					m_privateKey = tipoPacs.privateKey;
 				}
-				
+
 				m_pComboCharset->SetValue(wxString::FromUTF8(tipoPacs.defaultCharset.c_str()));
+
+				//wl
+				m_pCheckDICOMMPPS->SetValue(tipoPacs.GetWlConfig().useDICOMMPPS);
+				m_pCheckHL7->SetValue(tipoPacs.GetWlConfig().useAbortMessage || tipoPacs.GetWlConfig().useCompletedMessage || tipoPacs.GetWlConfig().useInProgressMessage);
+				m_pCheckAbort->SetValue(tipoPacs.GetWlConfig().useAbortMessage);
+				m_pCheckCompleted->SetValue(tipoPacs.GetWlConfig().useCompletedMessage);
+				m_pCheckInProgress->SetValue(tipoPacs.GetWlConfig().useInProgressMessage);
+				m_pTextAbort->SetValue(wxString::FromUTF8(tipoPacs.GetWlConfig().abortTemplate.c_str()));
+				m_pTextCompleted->SetValue(wxString::FromUTF8(tipoPacs.GetWlConfig().completedTemplate.c_str()));
+				m_pTextProgress->SetValue(wxString::FromUTF8(tipoPacs.GetWlConfig().inProgressTemplate.c_str()));
+				//
+				RefreshHL7Panel();
+				wxCommandEvent evt;
+				OnRetrieveMethodChoice(evt);
 			}
 
 			virtual void OnAdvancedConfiguration(wxCommandEvent&)
@@ -387,6 +438,13 @@ namespace GNC {
 				}
 			}
 
+			virtual void OnRetrieveMethodChoice(wxCommandEvent&)
+			{
+				bool enableWADO = m_pRetrieveMethod->GetSelection() == DicomServer::WADO;
+				m_pWadoURL->Enable(enableWADO);
+				m_pRetrieveMode->Enable(!enableWADO);
+			}
+
 			virtual void OnCancelClick(wxCommandEvent &){
 				m_Ok=false;
 				Close();
@@ -454,6 +512,22 @@ namespace GNC {
 						sstream << _Std("\n- If you want to use SSL/TLS you have to set a valid certificate and private key") ;
 					}
 
+					if (m_pRetrieveMethod->GetSelection() == DicomServer::WADO) {
+						if (m_pWadoURL->GetValue().IsEmpty()) {
+							ok = false;
+							sstream << _Std("\n- If you want to use WADO you have to fill in wado url") ;
+						} else {
+							wxURI uri(m_pWadoURL->GetValue());
+							if (uri.GetScheme().IsEmpty()) {
+								sstream << _Std("\n- WADO URL doesn't contains scheme (i.e. http://)") ;
+								ok = false;
+							} else if (uri.GetServer().IsEmpty()) {
+								sstream << _Std("\n- WADO URL doesn't contains host") ;
+								ok = false;
+							}
+						}
+					}
+
 					if(!ok)
 						wxMessageBox(wxString::FromUTF8(sstream.str().c_str()),_("Info"),wxOK | wxICON_INFORMATION, this);
 				}else{
@@ -465,76 +539,139 @@ namespace GNC {
 			virtual void OnProbarClick(wxCommandEvent &)
 			{
 				if(Validar()) {
-					long puerto;
-					long pdu = m_pPDU->GetValue();
-					if(m_pPuerto->GetValue().ToLong(&puerto)){
+					bool success = true;
+					std::ostringstream errorMsg;
+					std::string errorTitle;
 
-						EchoAssociation as("C-ECHO");
-						if (m_pUseSSL->GetValue()) {
-							if (m_certificado.empty() || m_privateKey.empty()) {							
-								as.SetTLS(m_configLocal.certificate, m_configLocal.privateKey, m_pVerifyServer->GetValue());
-							}
-							else {
-								as.SetTLS(m_certificado, m_privateKey, m_pVerifyServer->GetValue());
-							}
-						}
-						if (m_pUser->GetValue() != wxEmptyString) {
-							as.SetUserPass(std::string(m_pUser->GetValue().ToUTF8()), std::string(m_pPassword->GetValue().ToUTF8()));
-						}
-						CONDITION cond;
-						wxBusyInfo* info = new wxBusyInfo(_("Testing the connection to the node ..."));
-						
-						std::string aet(m_pAET->GetValue().ToUTF8());
-						std::string host(m_pHost->GetValue().ToUTF8());
+					{
+						long puerto;
+						long pdu = m_pPDU->GetValue();
 
-						as.Create(aet, host, puerto, m_aetLocal, UID_VerificationSOPClass);
+						wxBusyInfo info( _("Testing the connection to the node ...") );
 
-						GIL::DICOM::DCMTK::Network* pNetwork = NULL;
-						try {
-							pNetwork = GIL::DICOM::DCMTK::Network::Instance(this);
-						}
-						catch(...)
-						{
-						}
-						if(pNetwork != NULL) {
-							as.SetTimeout(10);
-							pNetwork->InitializeNetwork(as.GetTimeout());
-							cond = pNetwork->ConnectAssociation(&as, pdu);
-							if (cond.good()) {
-								if (as.SendEchoRequest())
-								{			
-									LOG_DEBUG("C-TEST", _Std("Connection test successful"));
-									delete info;
-									info = NULL;
-									wxMessageBox(_("Successful connection test."),_("Info"),wxOK | wxICON_INFORMATION, this);
+						// 1: Check DICOM interface
+						errorTitle = _Std("DICOM Error");
+
+						if(m_pPuerto->GetValue().ToLong(&puerto)) {
+
+							EchoAssociation as("C-ECHO");
+							if (m_pUseSSL->GetValue()) {
+								if (m_certificado.empty() || m_privateKey.empty()) {							
+									as.SetTLS(m_configLocal.certificate, m_configLocal.privateKey, m_pVerifyServer->GetValue());
 								}
 								else {
-									delete info;
-									info = NULL;
-									wxMessageBox(_("The service did not respond correctly to the C-ECHO"),_("Error"), wxICON_ERROR, this);
+									as.SetTLS(m_certificado, m_privateKey, m_pVerifyServer->GetValue());
 								}
 							}
-							else {
-								LOG_ERROR("C-TEST", _Std("The service did not respond properly:") << cond.text());
-								delete info;
-								info = NULL;
-								wxMessageBox(_("The service did not respond correctly to the DICOM standard:")  + wxString::FromUTF8(cond.text()), _("Error"), wxICON_ERROR, this);
+							if (m_pUser->GetValue() != wxEmptyString) {
+								as.SetUserPass(std::string(m_pUser->GetValue().ToUTF8()), std::string(m_pPassword->GetValue().ToUTF8()));
+							}
+							CONDITION cond;
+
+							std::string aet(m_pAET->GetValue().ToUTF8());
+							std::string host(m_pHost->GetValue().ToUTF8());
+
+							as.Create(aet, host, puerto, m_aetLocal, UID_VerificationSOPClass);
+
+							GIL::DICOM::DCMTK::Network* pNetwork = NULL;
+							try {
+								pNetwork = GIL::DICOM::DCMTK::Network::Instance(this);
+							}
+							catch(const std::exception& ex)
+							{
+								success = false;
+								errorMsg << _Std("Unable to connect: Could not start network support.") << ":\n" << ex.what();
+							}
+
+							if(success) {
+								as.SetTimeout(10);
+								pNetwork->InitializeNetwork(as.GetTimeout());
+								cond = pNetwork->ConnectAssociation(&as, pdu);
+								if (cond.good()) {
+									cond = as.SendEchoRequest();
+									if (cond.bad())	{
+										success = false;
+										errorMsg << _Std("The service did not respond correctly to the C-ECHO") << ":\n" << cond.text();
+									}	
+								}
+								else {
+									success = false;
+									errorMsg << _Std("The service did not respond correctly to the DICOM standard") << ":\n" << cond.text();
+								}
+								as.Drop(cond);
+								GIL::DICOM::DCMTK::Network::FreeInstance(this);
+								pNetwork = NULL;
 							}
-							as.Drop();
-							GIL::DICOM::DCMTK::Network::FreeInstance(this);
-							pNetwork = NULL;
 						}
 						else {
-							LOG_ERROR("C-TEST", _Std("Unable to connect: Could not start network support."));
-							delete info;
-							info = NULL;
-							wxMessageBox(_("Error starting network support"), _("Error"), wxICON_ERROR, this);
+							success = false;
+							errorMsg << _Std("Invalid port number");
 						}
+
+						// 2: check if wado support is enabled.
+
+						if (success && ( m_pRetrieveMethod->GetSelection() == (int)DicomServer::WADO ) ) {
+							errorTitle = _Std("WADO Error");
+							 std::string url(m_pWadoURL->GetValue().ToUTF8());
+							 try {
+								GNC::GCS::IEntorno::Instance()->GetPACSController()->TestWADOURL(url);
+							 }
+							 catch (const GIL::DICOM::PACSException& ex) {
+								 success = false;
+								 errorMsg << ex.GetCause();
+							 }
+						}
+					}
+
+					if (success) {
+						std::string resp = _Std("Connection test successful");
+						LOG_INFO("C-TEST", resp);
+						wxMessageBox(wxString::FromUTF8(resp.c_str()), _("Info"), wxOK | wxICON_INFORMATION, this);
+						
+					}
+					else {
+						LOG_ERROR("C-TEST", errorTitle << ":" << errorMsg.str());
+						wxMessageBox(wxString::FromUTF8(errorMsg.str().c_str()), wxString::FromUTF8(errorTitle.c_str()), wxICON_ERROR, this);
 					}
 				}
 
 			}
 
+			virtual void OnChecWL(wxCommandEvent &)
+			{
+				RefreshHL7Panel();
+			}
+
+			virtual void RefreshHL7Panel()
+			{
+				m_pPanelHL7->Enable(m_pCheckHL7->GetValue());
+				m_pTextAbort->Enable(m_pCheckAbort->GetValue());
+				m_pTextCompleted->Enable(m_pCheckCompleted->GetValue());
+				m_pTextProgress->Enable(m_pCheckInProgress->GetValue());
+				m_pPanelHL7->Refresh(true);
+			}
+
+			virtual void OnMessageDefaultValues(wxCommandEvent&)
+			{
+				LoadMessageDefaultValues();
+			}
+
+			virtual void LoadMessageDefaultValues()
+			{
+				GNC::GCS::Permisos::EstadoPermiso perm = GNC::GCS::IControladorPermisos::Instance()->Get("gnkwl.messages", "inprogress");
+				if (perm) {
+					m_pTextProgress->SetValue(wxString::FromUTF8(perm.GetRawValue().c_str()));
+				}
+				perm = GNC::GCS::IControladorPermisos::Instance()->Get("gnkwl.messages", "completed");
+				if (perm) {
+					m_pTextCompleted->SetValue(wxString::FromUTF8(perm.GetRawValue().c_str()));
+				}
+				perm = GNC::GCS::IControladorPermisos::Instance()->Get("gnkwl.messages", "abort");
+				if (perm) {
+					m_pTextAbort->SetValue(wxString::FromUTF8(perm.GetRawValue().c_str()));
+				}
+			}
+
 			PanelConfiguracionPACS::TipoConfigLocal& m_configLocal;
 
 			bool m_Ok;
@@ -547,16 +684,16 @@ namespace GNC {
 		};
 
 
-/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-///////////////////////PanelConfiguracionPACS////////////////////////////////////////////////////////////////////////////////////
-/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+		/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+		///////////////////////PanelConfiguracionPACS////////////////////////////////////////////////////////////////////////////////////
+		/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 		PanelConfiguracionPACS::PanelConfiguracionPACS(wxWindow* pParent,IDialogoConfiguracion* pDialogo): PanelConfiguracionPACSBase(pParent), IPasoConfiguracion(pDialogo)
 		{
 			this->m_pTreeListPACS->AddColumn(_("Name"), 200, wxALIGN_LEFT, -1, true, false);
 			this->m_pTreeListPACS->AddColumn(_("Use by default"), 70, wxALIGN_LEFT, -1, true, false);
 			Recargar();
-			
+
 			m_pHelpBitmap->SetBitmap(GinkgoResourcesManager::MenuIcons::GetIcoHelp());
 
 			if(!GNC::GCS::IControladorPermisos::Instance()->Get("core.pacs.limits","pacs_tls")) {
@@ -584,7 +721,7 @@ namespace GNC {
 			m_pAETLocal->SetValue(wxString::FromUTF8(strTmp.c_str()));
 			m_pAETReal->SetLabel(wxString::FromUTF8( GNC::Entorno::Instance()->ParseAET(strTmp).substr(0, 16).c_str() ));
 
-			DicomServer* serverLocal = DicomServerList::Instance()->GetLocalServer();
+			GNC::GCS::Ptr<DicomServer> serverLocal = DicomServerList::Instance()->GetLocalServer();
 			m_pPuertoLocal->SetValue(wxString::Format(wxT("%d"),serverLocal->GetPort()));
 
 			wxTextValidator OnlyNum = wxTextValidator(wxFILTER_NUMERIC);
@@ -598,36 +735,19 @@ namespace GNC {
 
 			if(GNC::GCS::IControladorPermisos::Instance()->Get("core.pacs.limits","remote_pacs")) {
 				m_pPACSServers->Enable(true);
-				
+
 				m_pTreeListPACS->DeleteRoot();
 				wxTreeItemId idRoot = m_pTreeListPACS->AddRoot(wxT("Root"));
 				m_servidores.clear();
 
-				DicomServerList::Instance()->FreeInstance();
-				for (DicomServerHolder* sl = DicomServerList::Instance()->GetList(); sl != NULL; sl = sl->next) {
-					TipoPACS tp;
-					tp.id = sl->server.ID;
-					tp.aet = sl->server.AET;
-					tp.host = sl->server.HostName;
-					tp.isDefault = sl->server.isDefault;
-					tp.puerto = sl->server.Port;
-					tp.pdu = sl->server.PDU;
-					tp.retrieveWithMove = sl->server.retrieveWithMove;
-					tp.retrieveSeries = sl->server.retrieveSeries;
+				DicomServerList::Instance()->Reload();
 
-					tp.reuseConnection = sl->server.reuseConnection;
-					
-					tp.useTLS = sl->server.useTLS;
-					tp.pacsUser = sl->server.pacsUser;
-					tp.pacsPass = sl->server.pacsPass;
-					
-					tp.verifyCredentials = sl->server.verifyCredentials;
-					tp.certificate = sl->server.certificate;
-					tp.privateKey = sl->server.privateKey;
-					tp.defaultCharset = sl->server.defaultCharset;
-					m_servidores.push_back(tp);
-					wxTreeItemId idItem = m_pTreeListPACS->AppendItem(idRoot, wxString::FromUTF8(tp.id.c_str()));
-					if(tp.isDefault) {
+				DicomServerList::TServerList ListOfServers = DicomServerList::Instance()->GetServerList();
+				for (DicomServerList::TServerList::iterator it = ListOfServers.begin(); it != ListOfServers.end(); ++it)
+				{
+					m_servidores.push_back((*it));
+					wxTreeItemId idItem = m_pTreeListPACS->AppendItem(idRoot, wxString::FromUTF8((*it)->ID.c_str()));
+					if((*it)->isDefault) {
 						m_pTreeListPACS->SetItemText(idItem, 1, _("Yes"));
 					} else {
 						m_pTreeListPACS->SetItemText(idItem, 1, _("No"));
@@ -701,7 +821,7 @@ namespace GNC {
 			GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/PACS/Local","certificate",m_configLocal.certificate);
 
 			GIL::DICOM::PACSController::Instance()->StartServer();
-			
+
 			if(GNC::GCS::IControladorPermisos::Instance()->Get("core.pacs.limits","remote_pacs")) {
 				wxString clave;
 				wxString valor;
@@ -710,29 +830,39 @@ namespace GNC {
 
 				for(TipoListaPACS::iterator it = m_servidores.begin(); it!= m_servidores.end(); ++it){
 					GNC::GCS::ConfigurationController::TMapValues pacs;
-					pacs["Identificador"] = (*it).id;
-					pacs["AET"] = (*it).aet;
-					pacs["Host"] = (*it).host;
-					pacs.insertInt("Puerto",(*it).puerto);
-					pacs.insertInt("PDU",(*it).pdu);
-					pacs.insertBool("useTLS", (*it).useTLS);
-					pacs.insertBool("verifyCredentials", (*it).verifyCredentials);
-					pacs.insertBool("retrieveWithMove", (*it).retrieveWithMove);
-					pacs.insertBool("reuseConnection", (*it).reuseConnection);
-					pacs.insertBool("retrieveSeries", (*it).retrieveSeries);
-					pacs["pacsUser"] = (*it).pacsUser;
-					pacs["pacsPass"] = (*it).pacsPass;
-					pacs["certificate"] = (*it).certificate;
-					pacs["privateKey"] = (*it).privateKey;
-					pacs.insertBool("isDefault", (*it).isDefault);
-					pacs["defaultCharset"] = (*it).defaultCharset;
+					pacs["Identificador"] = (*it)->ID;
+					pacs["AET"] = (*it)->AET;
+					pacs["Host"] = (*it)->HostName;
+					pacs.insertInt("Puerto",(*it)->Port);
+					pacs.insertInt("PDU",(*it)->PDU);
+					pacs.insertBool("useTLS", (*it)->useTLS);
+					pacs.insertBool("verifyCredentials", (*it)->verifyCredentials);
+					pacs.insertInt("retrieveMethod", (*it)->retrieveMethod);
+					pacs["wadoURI"] = (*it)->wadoURI;
+					pacs.insertBool("reuseConnection", (*it)->reuseConnection);
+					pacs.insertBool("retrieveSeries", (*it)->retrieveSeries);
+					pacs["pacsUser"] = (*it)->pacsUser;
+					pacs["pacsPass"] = (*it)->pacsPass;
+					pacs["certificate"] = (*it)->certificate;
+					pacs["privateKey"] = (*it)->privateKey;
+					pacs.insertBool("isDefault", (*it)->isDefault);
+					pacs["defaultCharset"] = (*it)->defaultCharset;
+					//wl
+					pacs.insertBool("useDICOMMPPS", (*it)->GetWlConfig().useDICOMMPPS);
+					pacs.insertBool("useAbortMessage", (*it)->GetWlConfig().useAbortMessage);
+					pacs.insertBool("useCompletedMessage", (*it)->GetWlConfig().useCompletedMessage);
+					pacs.insertBool("useInProgressMessage", (*it)->GetWlConfig().useInProgressMessage);
+					pacs["abortTemplate"] = (*it)->GetWlConfig().abortTemplate;
+					pacs["completedTemplate"] = (*it)->GetWlConfig().completedTemplate;
+					pacs["inProgressTemplate"] = (*it)->GetWlConfig().inProgressTemplate;
+					//
 					pacsList.push_back(pacs);
 				}
 				GNC::GCS::ConfigurationController::Instance()->writeGroupGeneral("/GinkgoCore/PACS/Servidores", pacsList, "Server");
 				DicomServerList::Instance()->Reload();
 			}
 			else {
-				DicomServerList::Instance()->FreeInstance();
+				DicomServerList::Instance()->Reload();
 			}
 
 			return true;
@@ -768,20 +898,20 @@ namespace GNC {
 		void PanelConfiguracionPACS::OnNuevoClick(wxCommandEvent &){
 			std::list<std::string> listIdsPacs;
 			for (TipoListaPACS::iterator it = m_servidores.begin(); it != m_servidores.end(); ++it) {
-				listIdsPacs.push_back((*it).id);
+				listIdsPacs.push_back((*it)->ID);
 			}
 			DialogoServidorPACS dialogo(this, m_configLocal, m_pPuertoLocal->GetValue(), wxString::FromUTF8( GNC::Entorno::Instance()->ParseAET( std::string(m_pAETLocal->GetValue().ToUTF8()) ).c_str() ), listIdsPacs );
 			dialogo.ShowModal();
 			if(dialogo.m_Ok){
-				TipoPACS tp;
-				dialogo.GetParametros(tp);
+				GNC::GCS::Ptr<DicomServer> tp(new DicomServer());
+				dialogo.GetParametros(*tp);
 				if (m_pTreeListPACS->GetChildrenCount(m_pTreeListPACS->GetRootItem()) == 0) {
-					tp.isDefault = true;
+					tp->isDefault = true;
 				}
 				m_servidores.push_back(tp);
 
-				wxTreeItemId idItem = m_pTreeListPACS->AppendItem(m_pTreeListPACS->GetRootItem(), wxString::FromUTF8(tp.id.c_str()));
-				if(tp.isDefault) {
+				wxTreeItemId idItem = m_pTreeListPACS->AppendItem(m_pTreeListPACS->GetRootItem(), wxString::FromUTF8(tp->ID.c_str()));
+				if(tp->isDefault) {
 					m_pTreeListPACS->SetItemText(idItem, 1, _("Yes"));
 				} else {
 					m_pTreeListPACS->SetItemText(idItem, 1, _("No"));
@@ -801,21 +931,21 @@ namespace GNC {
 
 				std::list<std::string> listIdsPacs;
 				for (TipoListaPACS::iterator it = m_servidores.begin(); it != m_servidores.end(); ++it) {
-					if((*it).id != idSeleccionado){
-						listIdsPacs.push_back((*it).id);
+					if((*it)->ID != idSeleccionado){
+						listIdsPacs.push_back((*it)->ID);
 					}
 				}
 
 				for(TipoListaPACS::iterator it = m_servidores.begin(); it != m_servidores.end(); ++it){
-					if((*it).id == idSeleccionado){
+					if((*it)->ID == idSeleccionado){
 						DialogoServidorPACS dialogo(this, m_configLocal, m_pPuertoLocal->GetValue(), wxString::FromUTF8( GNC::Entorno::Instance()->ParseAET( std::string( m_pAETLocal->GetValue().ToUTF8() ) ).c_str() ), listIdsPacs);
-						dialogo.SetParametros((*it));
+						dialogo.SetParametros(*(*it));
 
 						dialogo.ShowModal();
 						if(dialogo.m_Ok){
-							dialogo.GetParametros((*it));
+							dialogo.GetParametros(*(*it));
 							//se refresca el combo
-							m_pTreeListPACS->SetItemText(id,wxString::FromUTF8((*it).id.c_str()));
+							m_pTreeListPACS->SetItemText(id,wxString::FromUTF8((*it)->ID.c_str()));
 							m_pTreeListPACS->SelectItem(id);
 
 							wxTreeEvent evt;
@@ -834,7 +964,7 @@ namespace GNC {
 				int answer = wxMessageBox(_("Confirm the removal of the node") + wxString::FromUTF8(idSeleccionado.c_str()), _("Data modified"), wxYES_NO | wxCANCEL, this);
 				if(answer == wxYES){
 					for(TipoListaPACS::iterator it = m_servidores.begin(); it != m_servidores.end(); ++it){
-						if((*it).id == idSeleccionado){
+						if((*it)->ID == idSeleccionado){
 							m_pTreeListPACS->Delete(itemSeleccionado);
 							m_servidores.erase(it);
 							break;
@@ -853,10 +983,10 @@ namespace GNC {
 			if(itemSeleccionado.IsOk()){
 				std::string idSeleccionado(m_pTreeListPACS->GetItemText(itemSeleccionado).ToUTF8());
 				for(TipoListaPACS::iterator it = m_servidores.begin(); it != m_servidores.end(); ++it){
-					if((*it).id == idSeleccionado){
-						(*it).isDefault = true;
+					if((*it)->ID == idSeleccionado){
+						(*it)->isDefault = true;
 					} else {
-						(*it).isDefault = false;
+						(*it)->isDefault = false;
 					}
 				}
 				wxTreeItemIdValue cookie;
