@@ -31,7 +31,7 @@
 
 #include <main/entorno.h>
 #include <main/controllers/controladorextensiones.h>
-#include <main/controllers/controladorcomandos.h>
+#include <main/controllers/commandcontroller.h>
 #include <main/controllers/pacscontroller.h>
 #include <commands/comandoincluirhistorial.h>
 #include <api/dicom/imodelodicom.h>
