@@ -18,7 +18,7 @@
 
 #include "droptargetmainwindow.h"
 #include <commands/comandoincluirhistorial.h>
-#include <main/controllers/controladorcomandos.h>
+#include <main/controllers/commandcontroller.h>
 #include <main/gui/mainwindow/ventanaprincipal.h>
 #include <main/entorno.h>
 
