@@ -33,7 +33,7 @@
 #include <main/controllers/historycontroller.h>
 #include <main/controllers/controladoreventos.h>
 #include <main/controllers/controladorpermisos.h>
-#include <main/controllers/controladorcomandos.h>
+#include <main/controllers/commandcontroller.h>
 #include <main/controllers/configurationcontroller.h>
 #include <main/controllers/controladorvistas.h>
 #include <main/controllers/controladorlog.h>
@@ -42,8 +42,10 @@
 #include <main/controllers/streaming/streamingloader.h>
 #include <main/controllers/integrationcontroller.h>
 #include <main/controllers/hangingprotocolcontroller.h>
+#include <main/controllers/windowattributescontroller.h>
 
 #include <commands/comandoincluirhistorial.h>
+#include <commands/synchronizationcommand.h>
 
 #include <main/gui/import/wxwizardimportacionginkgo.h>
 #include <main/gui/acquisition/dialogoadquisicion.h>
@@ -69,12 +71,13 @@
 
 #define ICONO_ESTUDIO 0
 #define ICONO_SERIE 1
-#define ICONO_HOMBRE 2
-#define ICONO_MUJER 3
-#define ICONO_OTRO 4
+#define ICONO_LOCAL_DATABASE 2
+#define ICONO_LOCAL_LINKED 3
+#define ICONO_WADO_LINKED 4
 
 
-#define SIZE_THUMBNAILS 96
+#define SIZE_THUMBNAILS 76
+#define HISTORY_WINDOW_ID "GinkgoCADxHistory"
 
 		
 
@@ -161,12 +164,13 @@ namespace GNC {
 					return false;
 				}
 				wxTreeItemId nodeStudy = mapOfStudies[pk_study];
-				m_pTree->DeleteChildren(nodeStudy);
+				//m_pTree->DeleteChildren(nodeStudy);
 				GNC::GCS::HistoryController::SeriesModelList seriesList;
 				GNC::GCS::HistoryController::Instance()->GetSeriesFromStudy(pk_study, seriesList);
 				for(GNC::GCS::HistoryController::SeriesModelList::const_iterator it = seriesList.begin(); it != seriesList.end(); ++it) {
-					InsertSeries(nodeStudy,(*it));
+					InsertOrUpdateSeries(nodeStudy,(*it));
 				}
+				//delete series that doesn't exists...
 				m_pTree->SortChildren(nodeStudy, m_sortCriteria, m_reverse);
 
 				return true;				
@@ -258,18 +262,24 @@ namespace GNC {
 
 				//iconos
 				int icono = 0;
-				if(studyModel.pat_sex == 'M') {
-					icono = ICONO_HOMBRE;
-				} else if(studyModel.pat_sex == 'F') {
-					icono = ICONO_MUJER;
-				} else {
-					icono = ICONO_OTRO;
+				switch(studyModel.location)
+				{
+					case GNC::GCS::IHistoryController::TL_LocalDatabase:
+						icono = ICONO_LOCAL_DATABASE;
+						break;
+					case GNC::GCS::IHistoryController::TL_LocalLinked:
+						icono = ICONO_LOCAL_LINKED;
+						break;
+					case GNC::GCS::IHistoryController::TL_WadoLinked:
+						icono = ICONO_WADO_LINKED;
+						break;
 				}
 
 				if(itMap != mapOfStudies.end()) 
 				{
 					idNode = (*itMap).second;	
 					m_pTree->SetItemText(m_pTree->GetRootItem(), wxString::FromUTF8(studyModel.pat_name.c_str()));
+					m_pTree->SetItemImage(idNode, icono, wxTreeItemIcon_Max);
 					if (m_pTree->GetChildrenCount(idNode) == 0) {
 						m_pTree->AppendItem(idNode, _("Searching..."));
 					}
@@ -309,6 +319,8 @@ namespace GNC {
 				m_pTree->SetItemText(idNode, COL_DATE_TIME, dateTimeStr);
 				m_pTree->SetItemText(idNode, COL_ACCNUMBER, wxString::FromUTF8(studyModel.study_acc_no.c_str()));
 				m_pTree->SetItemText(idNode, COL_PK, wxString::Format(wxT("%d"),(studyModel.pk)));
+				m_pTree->SetItemText(idNode, COL_LOCATION, wxString::Format(wxT("%c"),(GNC::GCS::IHistoryController::LocationToChar(studyModel.location))));
+
 				if (studyModel.pending_tasks > 0) {
 					m_pTree->SetItemBackgroundColour(idNode, wxColour(255,128,64));
 				} else {
@@ -316,9 +328,9 @@ namespace GNC {
 				}
 				m_pTree->SetItemText(idNode, COL_PENDING_TASKS, wxString::Format(wxT("%d"),studyModel.pending_tasks));
 
-				//to enable expand...
-				if (m_pTree->GetChildrenCount(idNode) == 0) {
-					//m_pTree->AppendItem(idNode, _("Searching..."));
+				//if it's expanded then refresh series...
+				if (m_pTree->IsExpanded(idNode)) {
+					ExpandStudy(studyModel.pk);
 				}
 
 				return idNode;
@@ -345,7 +357,7 @@ namespace GNC {
 				}
 			}
 
-			wxTreeItemId InsertSeries(wxTreeItemId parent, const GNC::GCS::HistoryController::SeriesModel& model)
+			wxTreeItemId InsertOrUpdateSeries(wxTreeItemId parent, const GNC::GCS::HistoryController::SeriesModel& model)
 			{
 				wxDateTime seriesDate;
 				seriesDate.ParseFormat(wxString::FromUTF8( model.series_datetime.c_str() ).GetData(), wxT("%Y-%m-%dT%H:%M:%S"), wxDefaultDateTime);
@@ -359,12 +371,46 @@ namespace GNC {
 					}
 				}
 
-				wxTreeItemId idNode = m_pTree->AppendItem(parent, wxString::FromUTF8(model.series_desc.c_str()), -1, -1, NULL);
+				int icono = 0;
+				switch(model.location)
+				{
+					case GNC::GCS::IHistoryController::TL_LocalDatabase:
+						icono = ICONO_LOCAL_DATABASE;
+						break;
+					case GNC::GCS::IHistoryController::TL_LocalLinked:
+						icono = ICONO_LOCAL_LINKED;
+						break;
+					case GNC::GCS::IHistoryController::TL_WadoLinked:
+						icono = ICONO_WADO_LINKED;
+						break;
+				}
+
+				wxTreeItemId idNode;
+				wxTreeItemIdValue cookie;
+				wxTreeItemId searchingNode;
+				wxString modelPK = wxString::Format(wxT("%d"),model.pk);
+				for (wxTreeItemId child = m_pTree->GetFirstChild(parent, cookie); child.IsOk(); child = m_pTree->GetNextChild(parent, cookie)) {
+					if (m_pTree->GetItemText(child, COL_PK).CompareTo(modelPK) == 0) {
+						idNode = child;
+						m_pTree->SetItemText(idNode, wxString::FromUTF8(model.series_desc.c_str()));
+						m_pTree->SetItemImage(idNode, icono, wxTreeItemIcon_Max);
+						break;
+					} else if (m_pTree->GetItemText(child, COL_PK).IsEmpty()) {
+						searchingNode = child;
+					}
+				}
+				if (searchingNode.IsOk()) {
+					m_pTree->Delete(searchingNode);
+				}
+				if (!idNode.IsOk()) {
+					idNode = m_pTree->AppendItem(parent, wxString::FromUTF8(model.series_desc.c_str()), icono, icono, NULL);
+				}
 				m_pTree->SetItemText(idNode, COL_MODALITY, wxString::FromUTF8(model.series_modality.c_str()));
 				m_pTree->SetItemText(idNode, COL_DESCRIPTION, wxString::FromUTF8(model.series_desc.c_str()));
 				m_pTree->SetItemText(idNode, COL_DATE_TIME, dateTimeStr);
 				m_pTree->SetItemText(idNode, COL_PENDING_TASKS, wxString::Format(wxT("%d"),model.pendingTasks.size()));
-				m_pTree->SetItemText(idNode, COL_PK, wxString::Format(wxT("%d"),model.pk));
+				m_pTree->SetItemText(idNode, COL_PK, modelPK);
+				m_pTree->SetItemText(idNode, COL_LOCATION, wxString::Format(wxT("%c"),(GNC::GCS::IHistoryController::LocationToChar(model.location))));
 				return idNode;
 			}
 
@@ -413,7 +459,7 @@ namespace GNC {
 
 			void OnOpenMenu(wxCommandEvent& )
 			{
-				HistoryPanel->OpenSeriesOrStudy(SeriesPk, true);
+				HistoryPanel->OpenSeriesOrStudy(SeriesPk, true,!GNC::GCS::IControladorPermisos::Instance()->Get("core.restrictions", "reutilize_study"));
 			}
 
 			void OnOpenWithMenu(wxCommandEvent& )
@@ -438,7 +484,7 @@ void launchTasks(const std::list<GNC::GCS::HistoryController::TaskModel>& tasks)
 		//TODO all tasks are sendcommands
 		GADAPI::SendPACSCommand* pCmd = new GADAPI::SendPACSCommand((*it).pk, (*it).seriesId);
 		pCmd->init((*it).data);
-		GNC::ControladorComandos::Instance()->ProcessAsync("",pCmd,NULL);
+		GNC::CommandController::Instance()->ProcessAsync("",pCmd,NULL);
 	}
 }
 //---------------------------------------------------------------------------
@@ -462,8 +508,13 @@ void GNC::GUI::HistoryPanel3::FreeInstance()
 GNC::GUI::HistoryPanel3* GNC::GUI::HistoryPanel3::m_pInstance = NULL;
 
 
-GNC::GUI::HistoryPanel3::HistoryPanel3(wxWindow* pParent) : HistoryPanel3Base(pParent), Loader(new GNC::StreamingLoader())
+GNC::GUI::HistoryPanel3::HistoryPanel3(wxWindow* pParent) : HistoryPanel3Base(pParent), Loader(new GNC::StreamingLoader()),
+	m_RefreshOnIdle(false)
 {
+	//load attributes
+	GNC::GCS::WindowAttributesController::LoadWindowAttributes(HISTORY_WINDOW_ID, this, false);
+	//
+
 	m_pImageList = new wxImageList(SIZE_ICONOS,SIZE_ICONOS,true);
 	m_pTimerReload = new ReloadHistoryTimer(this);
 	
@@ -491,15 +542,15 @@ GNC::GUI::HistoryPanel3::HistoryPanel3(wxWindow* pParent) : HistoryPanel3Base(pP
 	if (bmp.IsOk()) {
 		m_pImageList->Add(bmp);
 	}
-	bmp = GinkgoResourcesManager::History::GetIcoHombre();
+	bmp = GinkgoResourcesManager::History::GetIcoLocalFile();
 	if (bmp.IsOk()) {
 		m_pImageList->Add(bmp);
 	}
-	bmp = GinkgoResourcesManager::History::GetIcoMujer();
+	bmp = GinkgoResourcesManager::History::GetIcoLocalLinked();
 	if (bmp.IsOk()) {
 		m_pImageList->Add(bmp);
 	}
-	bmp = GinkgoResourcesManager::History::GetIcoOtro();
+	bmp = GinkgoResourcesManager::History::GetIcoWadoLinked();
 	if (bmp.IsOk()) {
 		m_pImageList->Add(bmp);
 	}
@@ -565,7 +616,11 @@ GNC::GUI::HistoryPanel3::~HistoryPanel3()
 	ViewImage2D->Detach();
 	//necesario para que no haga un doble delete
 	ViewInteractor2D->Delete();
-	ViewInteractor2D->Reparent(NULL);		
+	ViewInteractor2D->Reparent(NULL);
+
+	//save window attributes
+	GNC::GCS::WindowAttributesController::SaveWindowAttributes(HISTORY_WINDOW_ID, this);
+
 }
 
 void GNC::GUI::HistoryPanel3::ReloadHistory()
@@ -706,7 +761,47 @@ void GNC::GUI::HistoryPanel3::ReloadCombos(bool checkPurgue)
 	}
 }
 
+
 void GNC::GUI::HistoryPanel3::RefreshSearch(bool force)
+{
+	if (force) {
+		doRefresh(force);
+	} else {
+		m_RefreshOnIdle = true;
+	}
+}
+
+void GNC::GUI::HistoryPanel3::checkPendingTasks()
+{
+	//throw pending commands...
+	if (GNC::GCS::HistoryController::Instance()->IsPendingTasks()) {
+		if (wxMessageBox(_("There are pending tasks, do you want to execute them?"), _("Pending tasks"), wxYES_NO , GNC::Entorno::Instance()->GetVentanaRaiz()) == wxYES)
+		{
+			std::list<GNC::GCS::HistoryController::TaskModel> tasks;
+			GNC::GCS::HistoryController::Instance()->GetPendingTasks(tasks);
+			launchTasks(tasks);
+			RefreshSearch();
+		}
+	}
+}
+
+void GNC::GUI::HistoryPanel3::GetSelectedSeriesPk(std::list<long>& listOfPks)
+{
+	std::set<long> setOfPks;
+	m_pTableModel->GetSeriesPkSelected(setOfPks);
+	for (std::set<long>::iterator it = setOfPks.begin(); it != setOfPks.end(); ++it) {
+		listOfPks.push_back((*it));
+	}
+}
+
+void GNC::GUI::HistoryPanel3::OnHistoryPanelIdle( wxIdleEvent& /*event*/ )
+{
+	if (m_RefreshOnIdle) {
+		doRefresh();
+	}
+}
+
+void GNC::GUI::HistoryPanel3::doRefresh(bool force)
 {
 	RefreshPatientFilter();
 	RefreshModalityFilter();
@@ -737,32 +832,9 @@ void GNC::GUI::HistoryPanel3::RefreshSearch(bool force)
 	}
 
 	Thaw();
+	m_RefreshOnIdle = false;
 }
 
-void GNC::GUI::HistoryPanel3::checkPendingTasks()
-{
-	//throw pending commands...
-	if (GNC::GCS::HistoryController::Instance()->IsPendingTasks()) {
-		if (wxMessageBox(_("There are pending tasks, do you want to execute them?"), _("Pending tasks"), wxYES_NO , GNC::Entorno::Instance()->GetVentanaRaiz()) == wxYES)
-		{
-			std::list<GNC::GCS::HistoryController::TaskModel> tasks;
-			GNC::GCS::HistoryController::Instance()->GetPendingTasks(tasks);
-			launchTasks(tasks);
-			RefreshSearch();
-		}
-	}
-}
-
-void GNC::GUI::HistoryPanel3::GetSelectedSeriesPk(std::list<long>& listOfPks)
-{
-	std::set<long> setOfPks;
-	m_pTableModel->GetSeriesPkSelected(setOfPks);
-	for (std::set<long>::iterator it = setOfPks.begin(); it != setOfPks.end(); ++it) {
-		listOfPks.push_back((*it));
-	}
-}
-
-
 void GNC::GUI::HistoryPanel3::RefreshPatientFilter()
 {
 	if (m_pPatientCombo->GetSelection() > 0) {
@@ -903,9 +975,9 @@ void GNC::GUI::HistoryPanel3::OnTreeItemActivated(wxTreeEvent& event)
 		long pk;
 		m_pTreeListResults->GetItemText(item, COL_PK).ToLong(&pk);		
 		if (m_pTreeListResults->GetItemParent(item) != m_pTreeListResults->GetRootItem()){
-			OpenSeriesOrStudy(pk, true);
+			OpenSeriesOrStudy(pk, true,!GNC::GCS::IControladorPermisos::Instance()->Get("core.restrictions", "reutilize_study"));
 		} else {
-			OpenSeriesOrStudy(pk, false);
+			OpenSeriesOrStudy(pk, false,!GNC::GCS::IControladorPermisos::Instance()->Get("core.restrictions", "reutilize_study"));
 		}
 		event.Skip(false);
 	}
@@ -950,6 +1022,20 @@ void GNC::GUI::HistoryPanel3::OnTreeItemMenu(wxTreeEvent& event)
 				menu.AppendSeparator();
 			}
 			GNC::HistoryToolsController::Instance()->AppendsToolInMenu(&menu, &menu, GNC::GCS::IHistoryTool::TFamily_Q_R);
+			{
+				//synchronize option
+				bool enableSynchronize = GNC::GCS::IHistoryController::Instance()->CharToLocation(*m_pTreeListResults->GetItemText(item, COL_LOCATION).ToUTF8()) 
+					== GNC::GCS::IHistoryController::TL_WadoLinked;
+				wxMenuItem* pMenuSynchronize = new wxMenuItem(&menu, idMenuItem, wxString( _("Synchronize") ), _("Synchronize"), wxITEM_NORMAL );
+				#ifdef __WXMSW__
+				pMenuSynchronize->SetBitmaps(GinkgoResourcesManager::Acquisition::GetIcoDownload());
+				#else
+				pMenuSynchronize->SetBitmap(GinkgoResourcesManager::Acquisition::GetIcoDownload());
+				#endif
+				menu.Append(pMenuSynchronize);
+				menu.Enable(idMenuItem, enableSynchronize);				
+				menu.Connect(idMenuItem++,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( HistoryPanel3::OnSynchronizeSelected),NULL,this);
+			}
 			if (menu.GetMenuItemCount() > 0 && !menu.GetMenuItems().back()->IsSeparator()) {
 				menu.AppendSeparator();
 			}
@@ -1033,7 +1119,7 @@ void GNC::GUI::HistoryPanel3::OnTreeSelChanged(wxTreeEvent& event)
 
 void GNC::GUI::HistoryPanel3::OnTreeKeyDown(wxTreeEvent& event)
 {
-	if (event.GetKeyCode() == WXK_DELETE) {
+	if (event.GetKeyCode() == WXK_DELETE || event.GetKeyCode() == WXK_BACK|| event.GetKeyCode() == WXK_NUMPAD_DELETE) {
 		RemoveSelected();
 		event.Veto();
 	} else {
@@ -1110,7 +1196,7 @@ void GNC::GUI::HistoryPanel3::OnThumbnailDClick(wxThumbnailEvent& /*evt*/)
 		wxHistoryImageThumbnailItem* pItem = static_cast<wxHistoryImageThumbnailItem*>(m_pThumbnails->GetItem(selected));
 		if (pItem->GetType() == wxHistoryImageThumbnailItem::TI_Series) {
 			//open series
-			OpenSeriesOrStudy(pItem->GetSeriesPk(), true);
+			OpenSeriesOrStudy(pItem->GetSeriesPk(), true,!GNC::GCS::IControladorPermisos::Instance()->Get("core.restrictions", "reutilize_study"));
 		} else {
 			//open image
 			GNC::GCS::IVista* pView = GetViewFromSeries(pItem->GetSeriesPk());
@@ -1119,7 +1205,7 @@ void GNC::GUI::HistoryPanel3::OnThumbnailDClick(wxThumbnailEvent& /*evt*/)
 				std::string pathOfFile(TOPATH(pItem->GetFilename()));
 				pView->ActivarRuta(pItem->GetFilePk());				
 			} else  {
-				OpenSeriesOrStudy(pItem->GetSeriesPk(), true);
+				OpenSeriesOrStudy(pItem->GetSeriesPk(), true,!GNC::GCS::IControladorPermisos::Instance()->Get("core.restrictions", "reutilize_study"));
 			}
 		}
 	}
@@ -1147,11 +1233,11 @@ void GNC::GUI::HistoryPanel3::OnOpenMenu(wxCommandEvent& /*event*/)
 	if (item.IsOk() && m_pTreeListResults->GetItemParent(item) != m_pTreeListResults->GetRootItem()) {
 		long pk;
 		m_pTreeListResults->GetItemText(item, COL_PK).ToLong(&pk);
-		OpenSeriesOrStudy(pk, true);
+		OpenSeriesOrStudy(pk, true,!GNC::GCS::IControladorPermisos::Instance()->Get("core.restrictions", "reutilize_study"));
 	} else if (item.IsOk() && m_pTreeListResults->GetItemParent(item) == m_pTreeListResults->GetRootItem()) {
 		long pk;
 		m_pTreeListResults->GetItemText(item, COL_PK).ToLong(&pk);
-		OpenSeriesOrStudy(pk, false);
+		OpenSeriesOrStudy(pk, false,!GNC::GCS::IControladorPermisos::Instance()->Get("core.restrictions", "reutilize_study"));
 	}
 }
 
@@ -1194,6 +1280,11 @@ void GNC::GUI::HistoryPanel3::OnAdvancedTasksEdition(wxCommandEvent& /*event*/)
 	AdvancedTasksEdition();
 }
 
+void GNC::GUI::HistoryPanel3::OnSynchronizeSelected(wxCommandEvent& /*event*/)
+{
+	SynchronizeSelected();
+}
+
 
 GNC::GCS::IVista* GNC::GUI::HistoryPanel3::GetViewFromSeries(long pk_series)
 {
@@ -1234,8 +1325,9 @@ void GNC::GUI::HistoryPanel3::OpenSeriesOrStudyWith(long pk, bool isSeries)
 
 	OpenWithDialog::ListaModalidades listaModalidades;
 	for (GNC::GCS::IHistoryController::SeriesModelList::iterator itSeries = seriesModelList.begin(); itSeries != seriesModelList.end(); ++itSeries) {
-		for (GNC::GCS::HistoryController::StringList::iterator it = (*itSeries).tsuids.begin(); it != (*itSeries).tsuids.end(); ++it) {
-			listaModalidades.push_back(std::pair<std::string,std::string>((*itSeries).series_modality, (*it)));
+		GNC::GCS::IHistoryController::SeriesModel& seriesModel = (*itSeries);
+		for (GNC::GCS::HistoryController::StringList::iterator it = seriesModel.tsuids.begin(); it != seriesModel.tsuids.end(); ++it) {
+			listaModalidades.push_back(std::pair<std::string,std::string>(seriesModel.series_modality, (*it)));
 		}
 	}
 
@@ -1350,13 +1442,6 @@ void GNC::GUI::HistoryPanel3::OpenSeriesOrStudy(long pk, bool isSeries, bool for
 		}
 	}
 
-	if (seriesIsAlreadyOpen) {
-		int answer = wxMessageBox(_("The series selected is already open\nDo you want to open it again?"),_("Open again"), wxYES_NO , GNC::Entorno::Instance()->GetVentanaRaiz());
-		if (answer != wxYES) {
-			return;
-		}
-	}
-
 	if(pModo != NULL && pModulo != NULL){
 		//openinG!!!
 		OpenSeries(seriesModelList, pModulo, pModo->GetId(), hp);
@@ -1550,6 +1635,24 @@ void GNC::GUI::HistoryPanel3::AdvancedTasksEdition()
 	RefreshSearch();
 }
 
+void GNC::GUI::HistoryPanel3::SynchronizeSelected()
+{
+	std::set<long> setOfPks;
+	m_pTableModel->GetSeriesPkSelected(setOfPks);
+
+	if (setOfPks.empty()) {
+		wxMessageBox(_("Select at least one series"), _("Info"), wxOK | wxICON_WARNING);
+		return;
+	}
+
+	GNC::GCS::HistoryController::IdList pkList;
+	pkList.insert(pkList.begin(), setOfPks.begin(), setOfPks.end());
+	
+	GADAPI::SynchronizationCommandParameters* pParams = new GADAPI::SynchronizationCommandParameters(pkList, NULL);
+	GADAPI::SynchronizationCommand* pCmd = new GADAPI::SynchronizationCommand(pParams);
+	GNC::GCS::ICommandController::Instance()->ProcessAsync("syncronizing...", pCmd, NULL);
+}
+
 void GNC::GUI::HistoryPanel3::LoadPreviewsFromStudy(const wxTreeItemId& itemStudy)
 {
 	wxWindowDisabler disableAll;
@@ -1561,13 +1664,17 @@ void GNC::GUI::HistoryPanel3::LoadPreviewsFromStudy(const wxTreeItemId& itemStud
 	long pkStudy;
 	m_pTreeListResults->GetItemText(itemStudy, COL_PK).ToLong(&pkStudy);
 
+	GNC::GCS::IHistoryController::TLocation location = GNC::GCS::IHistoryController::CharToLocation(*m_pTreeListResults->GetItemText(itemStudy, COL_LOCATION).ToUTF8());
+
 	GNC::GCS::HistoryController::SeriesModelList seriesList;
 	GNC::GCS::HistoryController::Instance()->GetSeriesFromStudy(pkStudy, seriesList);
 	
 	for (GNC::GCS::HistoryController::SeriesModelList::const_iterator it = seriesList.begin(); it != seriesList.end(); ++it) {
 		GNC::GCS::HistoryController::FileModel frame = GNC::GCS::HistoryController::Instance()->GetFrameOfReference((*it).pk);
 		wxString pathOfItem = wxString::Format(wxT("%ld"),frame.pk);
-		wxHistoryImageThumbnailItem* pItem = new wxHistoryImageThumbnailItem(pathOfItem, wxHistoryImageThumbnailItem::TI_Series, (*it).pk, frame.pk, !frame.file_path.empty());
+		
+
+		wxHistoryImageThumbnailItem* pItem = new wxHistoryImageThumbnailItem(pathOfItem, wxHistoryImageThumbnailItem::TI_Series, (*it).pk, frame.pk, location);
 		m_pThumbnails->Insert(pItem);
 	}
 	m_pThumbnails->Thaw();
@@ -1583,12 +1690,12 @@ void GNC::GUI::HistoryPanel3::LoadPreviewsFromSeries(const wxTreeItemId& itemSer
 
 	long pk;
 	m_pTreeListResults->GetItemText(itemSeries, COL_PK).ToLong(&pk);
-	GNC::GCS::HistoryController::FileModelList listOfFiles;
+	GNC::GCS::HistoryController::LightFileModelList listOfFiles;
 	GNC::GCS::HistoryController::Instance()->GetSeriesSortedFileModels(pk, listOfFiles);
 
-	for (GNC::GCS::HistoryController::FileModelList::const_iterator it = listOfFiles.begin(); it != listOfFiles.end(); ++it) {
+	for (GNC::GCS::HistoryController::LightFileModelList::const_iterator it = listOfFiles.begin(); it != listOfFiles.end(); ++it) {
 		wxString pathOfItem = wxString::Format(wxT("%ld"),(*it).pk);
-		wxHistoryImageThumbnailItem* pItem = new wxHistoryImageThumbnailItem(pathOfItem, wxHistoryImageThumbnailItem::TI_Image, pk, (*it).pk, !(*it).file_path.empty());
+		wxHistoryImageThumbnailItem* pItem = new wxHistoryImageThumbnailItem(pathOfItem, wxHistoryImageThumbnailItem::TI_Image, pk, (*it).pk, (*it).location);
 		m_pThumbnails->Append(pItem);
 	}
 	m_pThumbnails->Thaw();
