@@ -30,11 +30,12 @@ namespace GNC {
 	}
 
 	namespace GUI {
+		class ImportProfileToolBar;
 
 		class PasoPefilImportacion: public PasoPerfilImportacionBase, public IPasoWizard
 		{
 			public:
-				PasoPefilImportacion(wxWindow* pParent,IWizard* pWizard, GNC::GCS::IEntorno* pEntorno);
+				PasoPefilImportacion(wxWindow* pParent,IWizard* pWizard);
 				~PasoPefilImportacion();
 
 				GNC::GCS::IModuleController* GetControladorSeleccionado(){
@@ -42,8 +43,8 @@ namespace GNC {
 				};
 
 			protected:
-				GNC::GCS::IEntorno* m_pEntorno;
 				GNC::GCS::IModuleController* m_pControladorModulo;
+				ImportProfileToolBar* m_pToolBar;
 
 			//region "Metodos heredados de IPasoWizard"
 				virtual std::string GetTitle();
