@@ -1,16 +1,16 @@
 /*
- *  
- *  $Id: selectimagesimportation.cpp $
- *  Ginkgo CADx Project
- *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
- *  http://ginkgo-cadx.com
- *
- *  This file is licensed under LGPL v3 license.
- *  See License.txt for details
- *
- *
- */
+*  
+*  $Id: selectimagesimportation.cpp $
+*  Ginkgo CADx Project
+*
+*  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+*  http://ginkgo-cadx.com
+*
+*  This file is licensed under LGPL v3 license.
+*  See License.txt for details
+*
+*
+*/
 #include <vector>
 #include <sstream>
 
@@ -52,6 +52,7 @@
 #include <vtk/vtkginkgoimageviewer.h>
 
 #include <wx/mimetype.h>
+#include <wx/clipbrd.h>
 
 #define ID_BUTTON_HIDE 0
 #define ID_BUTTON_ROTATE_LEFT 1
@@ -69,11 +70,11 @@ namespace GNC {
 				SetToolBitmapSize(wxSize(16,16));
 
 				wxAuiDefaultToolBarArt* pToolArt= new wxAuiDefaultToolBarArt();
-			#if defined(USE_PATCHED_LIBS) && !defined(__WXOSX__)
+#if defined(USE_PATCHED_LIBS) && !defined(__WXOSX__)
 				pToolArt->SetBaseColor(color);
 
 				pToolArt->SetFont(fuente);
-			#endif
+#endif
 				SetArtProvider(pToolArt);
 
 				Realize();
@@ -89,10 +90,10 @@ namespace GNC {
 		{
 		public:
 			DropTargetSelectImages(SelectImagesImportation* pParent, const std::list<std::string>& fileSpecs) : 
-					wxFileDropTarget(),
-					m_pParent(pParent),
-					m_fileSpecs(fileSpecs),
-					m_enabled(true)
+				wxFileDropTarget(),
+				m_pParent(pParent),
+				m_fileSpecs(fileSpecs),
+				m_enabled(true)
 			{
 			}
 
@@ -137,9 +138,9 @@ namespace GNC {
 		class TimerDirectory : public wxTimer {
 		public:
 			TimerDirectory(SelectImagesImportation* pSelectImages) :
-					m_path(),
-					m_monitorize(false),
-					m_pSelectImages(pSelectImages)
+				m_path(),
+				m_monitorize(false),
+				m_pSelectImages(pSelectImages)
 			{
 			}
 
@@ -152,7 +153,7 @@ namespace GNC {
 				m_path = wxString::FromUTF8(path.c_str());
 				m_monitorize = monitorize;
 			}
-			
+
 			virtual void Notify()
 			{
 				if (m_monitorize) {
@@ -181,7 +182,7 @@ namespace GNC {
 			AdjustScrollbars();
 			m_firstAttach = true;
 			m_pwxImagePreview = new wxImage();
-			
+
 			m_fileSpecs = fileSpecs;
 			if (defaultFilter.IsEmpty()) {
 #if defined(_WIN32) || defined(__WXMAC__)
@@ -211,15 +212,18 @@ namespace GNC {
 			int idButton = 0;
 			m_pButtonsBar->AddTool(idButton, _("Select files..."), GinkgoResourcesManager::MenuIcons::GetIcoImportar(), _("Select files from filesystem"));
 			m_pButtonsBar->Connect(idButton++, wxEVT_COMMAND_TOOL_CLICKED, wxCommandEventHandler(SelectImagesImportation::OnSelectFiles), NULL, this);
-			
+
 			GNC::GCS::IEntorno::MapaUbicaciones& mapa = GNC::Entorno::Instance()->GetUbicaciones();
-			
+
 			for (GNC::GCS::IEntorno::MapaUbicaciones::iterator it = mapa.begin(); it != mapa.end(); ++it) {
 				GIL::Ubicacion* u = (*it).second;
 
 				m_pButtonsBar->AddTool(idButton, wxString::FromUTF8(u->Titulo.c_str()), GinkgoResourcesManager::MenuIcons::GetIcoImportar(), wxString::FromUTF8(u->Descripcion.c_str()), wxITEM_CHECK);
 				m_pButtonsBar->Connect(idButton++, wxEVT_COMMAND_TOOL_CLICKED, wxCommandEventHandler(SelectImagesImportation::OnUbicacionClick), NULL, this);
 			}
+			m_pButtonsBar->AddSeparator();
+			m_pButtonsBar->AddTool(idButton, _("Paste"), GinkgoResourcesManager::MenuIcons::GetIcoPaste(), _("Paste from clipboard"));
+			m_pButtonsBar->Connect(idButton++, wxEVT_COMMAND_TOOL_CLICKED, wxCommandEventHandler(SelectImagesImportation::OnPasteFromClipboard), NULL, this);
 
 			m_pButtonsBar->Realize();
 			m_pSizerButtons->Add(m_pButtonsBar, 1, wxEXPAND| wxALL, 0);
@@ -227,11 +231,11 @@ namespace GNC {
 			ButtonsBar* pToolPreview = new ButtonsBar(m_pPreviewPanel, barColor, fontBar);
 			pToolPreview->AddTool(ID_BUTTON_HIDE,_("Back"), GinkgoResourcesManager::Acquisition::GetIcoAdquireFile(), _("Back"));
 			pToolPreview->Connect(ID_BUTTON_HIDE,wxEVT_COMMAND_TOOL_CLICKED, wxCommandEventHandler( SelectImagesImportation::OnHidePreview),NULL,this);
-			
+
 			pToolPreview->Realize();
 			m_pPreviewPanel->GetSizer()->Insert(0,pToolPreview,0,wxEXPAND);
 			m_pPreviewPanel->Layout();
-			
+
 			m_pImagenes->Connect(wxEVT_COMMAND_THUMBNAIL_LEFT_DCLICK,wxCommandEventHandler(SelectImagesImportation::OnThumbLeftDClickSelected),NULL,this);
 			m_pImagenes->Connect(wxEVT_COMMAND_THUMBNAIL_RIGHT_CLICK,wxCommandEventHandler(SelectImagesImportation::OnThumbRightClickSelected),NULL,this);
 			m_pImagenes->Connect(wxEVT_KEY_DOWN, wxKeyEventHandler(SelectImagesImportation::OnImagenesKeyDown),NULL,this);
@@ -279,8 +283,17 @@ namespace GNC {
 				DeleteSelectedThumbnails();
 				event.Skip(false);
 			}
-			else
-			{
+			else if ( event.ControlDown()) {
+				if (event.GetKeyCode() == 86 ) {
+					wxCommandEvent ev;
+					OnPasteFromClipboard(ev);
+					event.Skip(false);
+				}
+				else {
+					event.Skip(true);
+				}
+			}
+			else {
 				event.Skip(true);
 			}
 		}
@@ -293,7 +306,7 @@ namespace GNC {
 		void SelectImagesImportation::DeleteSelectedThumbnails()
 		{
 			bool deleteFromDisk = false;
-				///if monitoring... ask
+			///if monitoring... ask
 			GIL::Ubicacion* pUbicacion = GetUbicacionSelected();
 			if (pUbicacion != NULL) {
 				if (pUbicacion->Monitorize) {
@@ -369,7 +382,7 @@ namespace GNC {
 				m_pButtonRemoveAll->Hide();
 				m_pButtonPreview->Hide();
 
-				
+
 
 				vtkSmartPointer<vtkImageData> data = vtkSmartPointer<vtkImageData>::New();
 				double spacing[3] = {1.0f,1.0f,1.0f};
@@ -396,8 +409,7 @@ namespace GNC {
 				m_panelStep0->Refresh();
 			} else {
 				wxFileName fileName(pathTmp);
-				wxMimeTypesManager manager;
-				wxFileType* fileType = manager.GetFileTypeFromExtension(fileName.GetExt());
+				wxFileType* fileType = wxTheMimeTypesManager->GetFileTypeFromExtension(fileName.GetExt());
 				if (fileType != NULL) {
 					wxExecute(fileType->GetOpenCommand(pathTmp));
 					delete fileType;
@@ -434,6 +446,62 @@ namespace GNC {
 			event.Skip();
 		}
 
+		void SelectImagesImportation::OnPasteFromClipboard(wxCommandEvent& ) {
+
+			if (wxTheClipboard->Open()) {
+				if (wxTheClipboard->IsSupported( wxDF_BITMAP ))
+				{
+					wxBitmapDataObject bmpData;
+					wxTheClipboard->GetData( bmpData );
+					wxBitmap bmp = bmpData.GetBitmap();
+
+					wxFileName tempDir = FROMPATH(m_dirTemp);
+					wxFileName tempFileName(wxT("clipboard_") + wxString::Format(wxT("%d"),rand()));
+					//if files will be cleaned at the end, we have to copy it in temporally folder
+					wxString tempFile = tempDir.GetFullPath() + wxFileName::GetPathSeparator() + tempFileName.GetName() + wxT(".bmp");
+
+					if (bmp.SaveFile(tempFile, wxBITMAP_TYPE_BMP)) {
+
+						wxThumbnailItem* pItem = NULL;
+						pItem = new wxMemoryImageThumbnailItem(tempFile, bmp.ConvertToImage());
+						m_pImagenes->Insert( pItem, m_pImagenes->GetCount());
+
+						{
+							GNC::GCS::ConfigurationController::Instance()->writeStringUser("/GinkgoCore/Importacion", "LastMethod", "clipboard");
+							GNC::GCS::ConfigurationController::Instance()->Flush();
+						}
+					}
+					else {
+						LOG_ERROR("Importation", "Unable to save bitmap");
+					}
+					
+				} else if(wxTheClipboard->IsSupported( wxDF_FILENAME )) {
+					wxFileDataObject fileData;
+					wxTheClipboard->GetData(fileData);
+					wxArrayString images;
+					for(wxArrayString::const_iterator it = fileData.GetFilenames().begin(); it!= fileData.GetFilenames().end(); ++it)
+					{
+						if(wxDirExists((*it))) {
+							ScanPath((*it));
+						} else if(wxFileExists((*it))){
+							wxFileName filename((*it));
+							wxString extensionFile = filename.GetExt().Lower();
+							for (std::list<std::string>::iterator itSpecs = m_fileSpecs.begin(); itSpecs != m_fileSpecs.end(); ++itSpecs) {
+								wxFileName ext(wxString::FromUTF8((*itSpecs).c_str()).Lower());
+								if (extensionFile == ext.GetExt().Lower()) {
+									images.push_back((*it));
+									break;
+								}
+							}
+						}
+					}
+					AddImages(images);
+				}
+				wxTheClipboard->Close();
+			}
+
+		}
+
 		void SelectImagesImportation::OnSelectFiles(wxCommandEvent & )
 		{
 			UnCheckAll();
@@ -458,9 +526,10 @@ namespace GNC {
 				wxBusyInfo info(_("Creating Thumbnail..."));
 				wxArrayString paths;
 				seleccionarFichero.GetPaths(paths);
-				
+
 				{
 					GNC::GCS::ConfigurationController::Instance()->writeStringUser("/GinkgoCore/Importacion", "PathDefecto", std::string(wxPathOnly(seleccionarFichero.GetPath()).ToUTF8()));
+					GNC::GCS::ConfigurationController::Instance()->writeStringUser("/GinkgoCore/Importacion", "LastMethod", "file");
 					GNC::GCS::ConfigurationController::Instance()->Flush();
 				}
 
@@ -620,7 +689,7 @@ namespace GNC {
 			return NULL;
 		}
 
-//region "Metodos heredados de Ipasowizard"
+		//region "Metodos heredados de Ipasowizard"
 
 		bool SelectImagesImportation::Attach()
 		{
@@ -638,8 +707,12 @@ namespace GNC {
 				}
 				if (it == mapa.end()) {
 					//opens select file dialog...
-					wxCommandEvent openDialogEvent(wxEVT_COMMAND_TOOL_CLICKED, 0);
-					m_pButtonsBar->AddPendingEvent(openDialogEvent);
+					std::string method;
+					GNC::GCS::ConfigurationController::Instance()->readStringUser("/GinkgoCore/Importacion", "LastMethod", method);
+					if (method.empty() || method == "file") {
+						wxCommandEvent openDialogEvent(wxEVT_COMMAND_TOOL_CLICKED, 0);
+						m_pButtonsBar->GetEventHandler()->AddPendingEvent(openDialogEvent);
+					}
 				} else {
 					SetUbicacion((*it).second, id);
 				}
@@ -650,7 +723,7 @@ namespace GNC {
 			if (pUbicacion != NULL && pUbicacion->Monitorize) {
 				m_pTimerDirectory->Start(100,true);
 			}
-			
+
 			return true;
 		}
 
@@ -690,7 +763,7 @@ namespace GNC {
 			wxArrayString paths=this->GetSelectedPaths();
 			if(paths.GetCount()==0){
 				wxMessageBox(_("You must select at least one image"), _("Info"),
-					 wxOK | wxICON_INFORMATION, this);
+					wxOK | wxICON_INFORMATION, this);
 				return false;
 			}
 
@@ -708,12 +781,12 @@ namespace GNC {
 				if(!wxFileName::FileExists((*it))){
 					wxString str(_("The file"));
 					wxMessageBox(str <<(*it) <<_(" doesn't exist"), _("Info"),
-					 wxOK | wxICON_INFORMATION, this);
+						wxOK | wxICON_INFORMATION, this);
 					m_pListaFicheros->clear();
 					//el fichero no existe
 					return false;
 				}
-				
+
 				wxString wxDirTmp = FROMPATH(m_dirTemp);
 				wxFileName fileName((*it));
 				//if files will be cleaned at the end, we have to copy it in temporally folder
@@ -738,6 +811,6 @@ namespace GNC {
 			//
 			return true;
 		}
-	//endregion
+		//endregion
 	}
 }
