@@ -26,7 +26,7 @@ public:
 
 	virtual void OnSize(wxSizeEvent &event);
 
-	virtual void OnTextURL(wxTextUrlEvent &event);
+	virtual void OnTextURL(wxHtmlLinkEvent &event);
 
 private:
 
