@@ -42,6 +42,9 @@ public:
 	void EscribeLicenciaSQLLite();
 	void EscribeLicenciaCharLS();
 	void WriteDarkGlassLicense();
+	void WriteLibcurl();
+	void WriteLibJsonCpp();
+
 
 	GNC::GCS::IModuleController::TExtraLicensesMap ExtraMap;
 //endregion
