@@ -51,6 +51,7 @@
 #include <main/gui/license/acceptlicensedialog.h>
 #include <main/gui/import/wxwizardimportacionginkgo.h>
 #include <main/gui/acquisition/dialogoadquisicion.h>
+#include <main/gui/ginkgocloud/ginkgocloudsearchdialog.h>
 #include <main/gui/history3/historypanel3.h>
 #include <main/gui/progress/statusbarprogreso.h>
 #include <main/gui/configuration/dialogoconfiguracion.h>
@@ -72,7 +73,7 @@
 #include <main/controllers/controladorextensiones.h>
 #include <main/controllers/integrationcontroller.h>
 #include <main/controllers/controladorvistas.h>
-#include <main/controllers/controladorcomandos.h>
+#include <main/controllers/commandcontroller.h>
 #include <main/controllers/controladorpermisos.h>
 #include <main/controllers/controladorhl7.h>
 #include <main/controllers/controladorenviohl7.h>
@@ -81,6 +82,7 @@
 #include <main/controllers/controladoreventos.h>
 #include <main/controllers/dcmtk/dicomservers.h>
 #include <main/controllers/configurationcontroller.h>
+#include <main/controllers/windowattributescontroller.h>
 
 #include <commands/comandoactualizaciones.h>
 #include <commands/comandoincluirhistorial.h>
@@ -110,6 +112,8 @@
 #define ID_EXTENSIONS_SUPPORT 1081
 #define ID_OPEN_TEST_CARD 1082
 
+#define MAIN_WINDOW_ID "GinkgoCADxMain"
+
 //////////////////////////
 #if defined(GINKGO_PRO)
 int InitTest(const std::string& pathTests);
@@ -124,19 +128,23 @@ public:
 	}
 	virtual void *Entry() 
 	{
+		LOG_INFO("INITWX", "Launching from external thread");
 		InitTest(m_path);
+		LOG_INFO("INITWX", "tests complete, launching closing command");
 
 		class CloseCommand: public GADAPI::ISynchronizedWithGUI
 		{
 			virtual void ExecuteSynchronized(GADAPI::ISynchronizedData* )
 			{
+				LOG_INFO("INITWX", "Closing Ginkgo CADx...");
 				GNC::Entorno::Instance()->GetVentanaPrincipal()->Close(true);
 				wxExit();
 				exit(0);
 			}
 		};
 		GADAPI::CommandSynchronizeWithGUI* pCmd = new GADAPI::CommandSynchronizeWithGUI(new CloseCommand());
-		GNC::ControladorComandos::Instance()->ProcessAsync("", pCmd, NULL);
+		GNC::CommandController::Instance()->ProcessAsync("", pCmd, NULL);
+		LOG_INFO("INITWX", "closing command launched");
 		
 		return NULL;
 	}
@@ -178,6 +186,10 @@ END_EVENT_TABLE()
 VentanaPrincipal::VentanaPrincipal(const wxString& title) : VentanaPrincipalBase(NULL, wxID_ANY, title), m_mgr(m_pPanelCentral, AUI_NAMESPACE wxAUI_MGR_ALLOW_FLOATING | AUI_NAMESPACE  wxAUI_MGR_TRANSPARENT_DRAG |AUI_NAMESPACE  wxAUI_MGR_VENETIAN_BLINDS_HINT ),
 	StartupView(NULL)
 {
+	//load attributes
+	GNC::GCS::WindowAttributesController::LoadWindowAttributes(MAIN_WINDOW_ID, this, true);
+	//
+
     //SetDoubleBuffered(true);
 	m_Iniciada = false;
 	m_VersionChecked = false;
@@ -219,7 +231,7 @@ VentanaPrincipal::VentanaPrincipal(const wxString& title) : VentanaPrincipalBase
 		m_mgr.AddPane(pStatusBar->m_pPanelTareas, pi);
 	}
 
-	GNC::ControladorComandos::Instance()->RegistrarProgreso(pStatusBar);
+	GNC::CommandController::Instance()->RegistrarProgreso(pStatusBar);
 	Connect(wxEVT_PROGRESO, EventoProgresoFunctionHandler(VentanaPrincipal::OnComando), NULL, this);
 
 	m_pNoteBook = new AUI_NAMESPACE wxAuiNotebook(m_pPanelCentral, wxID_ANY,wxDefaultPosition,
@@ -262,9 +274,10 @@ VentanaPrincipal::~VentanaPrincipal()
 	m_pNoteBook->Disconnect( wxEVT_CHILD_FOCUS, wxChildFocusEventHandler( VentanaPrincipal::OnNotebookFocus ) );
 
 	Disconnect(wxEVT_PROGRESO, EventoProgresoFunctionHandler(VentanaPrincipal::OnComando), NULL, this);
-	GNC::ControladorComandos::Instance()->RegistrarProgreso(NULL);
+	GNC::CommandController::Instance()->RegistrarProgreso(NULL);
 	GNC::GUI::DialogoAdquisicion::FreeInstance();
-	GNC::GCS::IControladorComandos::Instance()->AbortarComandosDeOwner(NULL);
+	GNC::GUI::GinkgoCloudSearchDialog::FreeInstance();
+	GNC::GCS::ICommandController::Instance()->AbortarComandosDeOwner(NULL);
 	//cierra la ventana si esta abierta
 	GNC::GUI::VentanaControlHL7::CerrarSiAbierta();
 	GNC::GUI::VentanaControlLogs::CerrarSiAbierta();
@@ -303,6 +316,9 @@ VentanaPrincipal::~VentanaPrincipal()
 	pEntorno->ViewsObservers.remove(this);
 	pEntorno->SetVentanaPrincipal(NULL);
 	pEntorno->SetVentanaRaiz(NULL);
+
+	//save attributes
+	GNC::GCS::WindowAttributesController::SaveWindowAttributes(MAIN_WINDOW_ID, this);
 }
 
 //region "Eventos de comprobacion de actualizaciones"
@@ -336,13 +352,13 @@ void VentanaPrincipal::ComprobarActualizaciones()
 
 				if (wxDateTime::Now().Subtract(lastDate).GetDays() > iPeriod) {
 					tryCheck = true;
-					GNC::GCS::IControladorComandos::Instance()->ProcessAsync(_Std("Check Updates"),
+					GNC::GCS::ICommandController::Instance()->ProcessAsync(_Std("Check Updates"),
 						new GNC::ComandoComprobarActualizaciones(new GNC::ComandoComprobarActualizacionesParams(updates.ObtenerValor<std::string>(), false) ), this);
 				}
 
 			} else {
 				//if there is no date in the ini file update will be checked
-				GNC::GCS::IControladorComandos::Instance()->ProcessAsync(_Std("Check Updates"),
+				GNC::GCS::ICommandController::Instance()->ProcessAsync(_Std("Check Updates"),
 					new GNC::ComandoComprobarActualizaciones(new GNC::ComandoComprobarActualizacionesParams(updates.ObtenerValor<std::string>(), false) ), this);
 				tryCheck = true;
 			}
@@ -422,6 +438,9 @@ void VentanaPrincipal::ForzarCambioVista(GNC::GCS::IVista* pVistaCambiar)
 					//desencajado
 					GNC::GUI::DetachedDialog* pDialogo = dynamic_cast<GNC::GUI::DetachedDialog*> (pVentana->GetParent());
 					if(pDialogo != NULL) {
+						if (pDialogo->IsIconized()) {
+							pDialogo->Iconize(false);
+						}
 						pDialogo->Raise();
 					}
 				}
@@ -454,8 +473,7 @@ void VentanaPrincipal::OnOnlineHelp(wxCommandEvent& /*event*/)
 			urlManual.Replace(wxT("\\"), wxString(wxFileName::GetPathSeparator()));
 			wxFileName executable_path = wxStandardPaths::Get().GetExecutablePath();
 			wxString pathDocument = executable_path.GetPath() + wxFileName::GetPathSeparator() + urlManual;
-			wxMimeTypesManager manager;
-			wxFileType* fileType = manager.GetFileTypeFromMimeType(wxT("application/pdf"));
+			wxFileType* fileType = wxTheMimeTypesManager->GetFileTypeFromMimeType(wxT("application/pdf"));
 			if (fileType == NULL) {
 				wxMessageBox(_("There isn't any pdf reader registered in the system"), _("Info"), wxICON_WARNING|wxOK);
 				return;
@@ -489,7 +507,7 @@ void VentanaPrincipal::OnOpenTestCard(wxCommandEvent& /*event*/)
 	GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorialParams* pParams = new GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorialParams(stdpath, false, GNC::GCS::IHistoryController::TAA_LINK);
 	pParams->m_abrirDespuesDeCargar = true;
 	GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorial* pCmd = new GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorial(pParams);
-	GNC::Entorno::Instance()->GetControladorComandos()->ProcessAsync(_Std("Included in the history ..."),pCmd, NULL);
+	GNC::Entorno::Instance()->GetCommandController()->ProcessAsync(_Std("Included in the history ..."),pCmd, NULL);
 }
 
 /* Evento de lanzamiento de la comprobacion de actualizaciones */
@@ -501,7 +519,7 @@ void VentanaPrincipal::OnCheckForUpdates(wxCommandEvent& /*event*/)
 		wxMessageBox(_("There is no URL to check updates on the current configuration."), _("Check update error"),wxICON_ERROR);
 	}
 	else {
-		GNC::GCS::IControladorComandos::Instance()->ProcessAsync(_Std("Check Updates"),
+		GNC::GCS::ICommandController::Instance()->ProcessAsync(_Std("Check Updates"),
 			new GNC::ComandoComprobarActualizaciones(new GNC::ComandoComprobarActualizacionesParams(updates.ObtenerValor<std::string>(), true) ), this);
 
 		GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/LastUpdateDateTime", "LastDate", std::string(wxDateTime::Now().Format().ToUTF8()));
@@ -533,7 +551,7 @@ void VentanaPrincipal::OnWindowClose(wxCloseEvent& event) {
 #endif
 	SuperFreeze();
 
-	GNC::ControladorComandos::ListaNombreComandos comandos =  GNC::ControladorComandos::Instance()->GetComandosActivos();
+	GNC::CommandController::ListaNombreComandos comandos =  GNC::CommandController::Instance()->GetComandosActivos();
 	if(comandos.size()>0 && event.CanVeto()) {
 		DialogoComandosEnEjecucion dlg(this,comandos);
 #if defined (_WINDOWS)
@@ -556,7 +574,7 @@ void VentanaPrincipal::OnWindowClose(wxCloseEvent& event) {
 		}
 	}
 
-	GNC::GCS::IControladorComandos::Instance()->AbortarComandosDeOwner(this);
+	GNC::GCS::ICommandController::Instance()->AbortarComandosDeOwner(this);
 
 	if(CerrarTodosLosTabsYPanelGrids()) {
 		//cerramos todos las ventanas flotantes que podamos haber abierto...
@@ -684,7 +702,7 @@ void VentanaPrincipal::OnKeyDown(wxKeyEvent& event)
 		wxKeyEvent evt = event;
 		wxWindow* win = pVista->GetWindow();
 		if (win) {
-			win->AddPendingEvent(evt);
+			win->GetEventHandler()->AddPendingEvent(evt);
 		}
 		event.Skip(false);
 	}
@@ -881,6 +899,9 @@ void VentanaPrincipal::EncajarDesencajar(GNC::GCS::IVista* pVista) {
 void VentanaPrincipal::ShowStartUp(bool show) 
 {
 	bool update = false;
+	if (StartupView == NULL) {
+		return;
+	}
 	if (StartupView->GetWindow()->IsShown() != show) {
 		m_mgr.GetPane(StartupView->GetWindow()).Show(show);
 		GNC::GCS::ControladorVistas::Instance()->SolicitarActivarVista(StartupView);
@@ -1007,6 +1028,7 @@ void VentanaPrincipal::OnInicioAplicacion(wxCommandEvent &)
 			}
 			#if defined(GINKGO_PRO)
 			else if (param.CmpNoCase(wxT("-unittest")) == 0) {
+				LOG_INFO("INITWX", "Running unitttests");
 				if (argc <= i+1) {
 					LOG_ERROR("INITWX", "no tests cases found for -unittest option. Usage -unittest <path_test_cases>");
 				} else {
@@ -1066,124 +1088,139 @@ void VentanaPrincipal::OnInicioAplicacion(wxCommandEvent &)
 void VentanaPrincipal::EjecutarParametro(const wxString cadena, bool doLogin)
 {
 	std::string xmlString("");
-	
-	wxFileName path = cadena;
+	std::string errorMsg;
+
 	bool error = false;
 	
-	if (path.IsOk()) {
-		LOG_DEBUG("Core", "Interpretando " << std::string(TOPATH(path.GetFullPath())).c_str());
-		if (path.IsRelative()) {
-			LOG_DEBUG("Core", "Convirtiendo ruta en absoluta");
-			#if defined(__WXGTK__)
-			
-			char* invocation_dir = getenv("INVOCATION_DIR");					
-			if (invocation_dir != NULL) {
-				wxString invocationDir = wxString::FromUTF8(invocation_dir);
-				if (!invocationDir.IsEmpty()) {
-					path = invocationDir + wxFileName::GetPathSeparator() + path.GetFullPath();
-				}
-			}
-			#else
-			path.MakeAbsolute();
-			#endif
-			LOG_DEBUG("Core", "Ruta absoluta: " << std::string(TOPATH(path.GetFullPath())).c_str());
+	if (cadena.Lower().StartsWith(wxT("ginkgocadx://"))) {
+		try {
+			xmlString = GIL::IntegrationController::Instance()->ParsesModelFromURL(cadena);
+		} catch (GIL::IntegrationException& ex) {
+			LOG_ERROR("GIL/WF", "Semantic/Sintactic error parsing integration url: " << ex.GetFullCause());
+			wxMessageBox(_("Semantic/Sintactic error parsing integration URL (see log for details):\n") + wxString::FromUTF8(ex.GetCause().c_str()),_("Error"),wxICON_INFORMATION);
 		}
+	}
+	else {
 
-		if(wxDirExists(path.GetFullPath()) && path.IsDirReadable()){
-			if(doLogin) {
-				Login();
-			}
-			std::list<std::string> rutas;
-			rutas.push_back(std::string(TOPATH( path.GetFullPath() )));
-			GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorialParams* pParams = new GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorialParams(rutas,true,GNC::GCS::IHistoryController::TAA_LINK);
-			GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorial* pCmd = new GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorial(pParams);
-			GNC::Entorno::Instance()->GetControladorComandos()->ProcessAsync(_Std("Included in the history ..."),pCmd, NULL);
-			return ;
-		} else if(path.FileExists() && path.IsFileReadable()){
-
-			//estamos ante un fichero
-			//se mira a ver si a partir del byte 128 pone DICM
-			wxFile fichero(path.GetFullPath(), wxFile::read);
-
-			bool esGzip = false;
-			bool esDicom = false;
-			if(fichero.IsOpened()){
-				char buffer[128];
-				if(fichero.Read(buffer,128) == 128){
-					esGzip = ((unsigned char)buffer[0]==0x1f) && ((unsigned char)buffer[1]==0x8b);
-					char numeroMagico[4];
-					if(fichero.Read(numeroMagico,4) == 4){
-						std::string str(numeroMagico,4);
-						if(str == "DICM") {
-							esDicom = true;
-						}
+		wxFileName path = cadena;
+		
+	
+		if (path.IsOk()) {
+			LOG_DEBUG("Core", "Interpretando " << std::string(TOPATH(path.GetFullPath())).c_str());
+			if (path.IsRelative()) {
+				LOG_DEBUG("Core", "Convirtiendo ruta en absoluta");
+				#if defined(__WXGTK__)
+			
+				char* invocation_dir = getenv("INVOCATION_DIR");					
+				if (invocation_dir != NULL) {
+					wxString invocationDir = wxString::FromUTF8(invocation_dir);
+					if (!invocationDir.IsEmpty()) {
+						path = invocationDir + wxFileName::GetPathSeparator() + path.GetFullPath();
 					}
 				}
+				#else
+				path.MakeAbsolute();
+				#endif
+				LOG_DEBUG("Core", "Ruta absoluta: " << std::string(TOPATH(path.GetFullPath())).c_str());
 			}
-			if(esDicom) {
-				if (doLogin) {
+
+			if(wxDirExists(path.GetFullPath()) && path.IsDirReadable()){
+				if(doLogin) {
 					Login();
 				}
-				//si no es un xml pues sera un dicom...
 				std::list<std::string> rutas;
-				rutas.push_back(std::string(TOPATH(path.GetFullPath()) ));
+				rutas.push_back(std::string(TOPATH( path.GetFullPath() )));
 				GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorialParams* pParams = new GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorialParams(rutas,true,GNC::GCS::IHistoryController::TAA_LINK);
 				GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorial* pCmd = new GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorial(pParams);
-				GNC::Entorno::Instance()->GetControladorComandos()->ProcessAsync(_Std("Included in the history ..."),pCmd, NULL);			
-			} else {				
-				//se lee el modelo
-				bool loaded = false;
-				wxXmlDocument documento;
-				if (esGzip) {
-					wxFileInputStream* fileIn = new wxFileInputStream(path.GetFullPath());
-					wxZlibInputStream zInput(fileIn);
-					loaded = documento.Load(zInput);
-				} else {
-					loaded = documento.Load(path.GetFullPath());
-				}
-				if(loaded) {
-					wxStringOutputStream out;
-					documento.Save(out);
-					xmlString=out.GetString().ToUTF8();
-				} else {
-					//dcmurl file...
-					LOG_DEBUG("GIL/WF", "Try reading dcmurl file...");
-					wxTextFile dcmURLFile;
-					if (!dcmURLFile.Open(path.GetFullPath(), wxMBConvUTF8())) {
-						for (wxString line = dcmURLFile.GetFirstLine(); !dcmURLFile.Eof(); line = dcmURLFile.GetNextLine()) {
-							wxFileName fileName(line);
-							if (fileName.IsRelative()) {
-								fileName.MakeAbsolute(path.GetPath());
-							}
-							if (wxFileExists(fileName.GetFullPath())) {
-								EjecutarParametro(fileName.GetFullPath());
-							} else {
-								LOG_ERROR("GIL/WF", "File doesn't exists");
-								break;
+				GNC::Entorno::Instance()->GetCommandController()->ProcessAsync(_Std("Included in the history ..."), pCmd, NULL);
+				return ;
+			} else if(path.FileExists() && path.IsFileReadable()){
+
+				//estamos ante un fichero
+				//se mira a ver si a partir del byte 128 pone DICM
+				wxFile fichero(path.GetFullPath(), wxFile::read);
+
+				bool esGzip = false;
+				bool esDicom = false;
+				if(fichero.IsOpened()){
+					char buffer[128];
+					if(fichero.Read(buffer,128) == 128){
+						esGzip = ((unsigned char)buffer[0]==0x1f) && ((unsigned char)buffer[1]==0x8b);
+						char numeroMagico[4];
+						if(fichero.Read(numeroMagico,4) == 4){
+							std::string str(numeroMagico,4);
+							if(str == "DICM") {
+								esDicom = true;
 							}
 						}
 					}
-					LOG_ERROR("GIL/WF", "Error al interpretar el fichero de entrada: XML mal formado");
-					wxMessageBox(_("Malformed XML"),_("Error"),wxICON_INFORMATION);
+				}
+				if(esDicom) {
 					if (doLogin) {
 						Login();
 					}
+					//si no es un xml pues sera un dicom...
+					std::list<std::string> rutas;
+					rutas.push_back(std::string(TOPATH(path.GetFullPath()) ));
+					GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorialParams* pParams = new GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorialParams(rutas,true,GNC::GCS::IHistoryController::TAA_LINK);
+					GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorial* pCmd = new GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorial(pParams);
+					GNC::Entorno::Instance()->GetCommandController()->ProcessAsync(_Std("Included in the history ..."),pCmd, NULL);			
+				} else {				
+					//se lee el modelo
+					bool loaded = false;
+					wxXmlDocument documento;
+					if (esGzip) {
+						wxFileInputStream* fileIn = new wxFileInputStream(path.GetFullPath());
+						wxZlibInputStream zInput(fileIn);
+						loaded = documento.Load(zInput);
+					} else {
+						loaded = documento.Load(path.GetFullPath());
+					}
+					if(loaded) {
+						wxStringOutputStream out;
+						documento.Save(out);
+						xmlString=out.GetString().ToUTF8();
+					} else {
+						//dcmurl this is a file with a relative path...
+						LOG_DEBUG("GIL/WF", "Try reading dcmurl file...");
+						wxTextFile dcmURLFile;
+						if (!dcmURLFile.Open(path.GetFullPath(), wxMBConvUTF8())) {
+							for (wxString line = dcmURLFile.GetFirstLine(); !dcmURLFile.Eof(); line = dcmURLFile.GetNextLine()) {
+								wxFileName fileName(line);
+								if (fileName.IsRelative()) {
+									fileName.MakeAbsolute(path.GetPath());
+								}
+								if (wxFileExists(fileName.GetFullPath())) {
+									EjecutarParametro(fileName.GetFullPath());
+								} else {
+									LOG_ERROR("GIL/WF", "File doesn't exists");
+									break;
+								}
+							}
+						}
+						LOG_ERROR("GIL/WF", "Error al interpretar el fichero de entrada: XML mal formado");
+						wxMessageBox(_("Malformed XML"),_("Error"),wxICON_INFORMATION);
+						if (doLogin) {
+							Login();
+						}
+					}
 				}
 			}
+			else {
+				error = true;
+			}
 		}
 		else {
 			error = true;
 		}
 	}
-	else {
-		error = true;
-	}
 	if (error) {
-		LOG_ERROR("GIL/WF", "Error al interpretar los parámetros de la línea de comandos. No existe el fichero o directorio (" << path.GetFullPath().ToUTF8() << ")" );
+		LOG_ERROR("GIL/WF", "Error al interpretar los parámetros de la línea de comandos. (" << cadena.ToUTF8() << ") : " << errorMsg );
 			wxMessageBox(
-				_("Error in interpreting the parameters of the command line. The file or directory doesn't exist (")
-				+ path.GetFullPath()
-				+ wxString::FromUTF8(")")
+				_("Error in interpreting the parameters of the command line. (")
+				+ cadena
+				+ wxT(") : ")
+				+ wxString::FromUTF8(errorMsg.c_str())
 				,_("Error"), wxICON_INFORMATION);
 			if (doLogin) {
 				Login();
@@ -1195,7 +1232,7 @@ void VentanaPrincipal::EjecutarParametro(const wxString cadena, bool doLogin)
 	if(xmlString != "") {
 		try {
 			GIL::IntegrationModelList listaModelos;	
-			GIL::IntegrationController::Instance()->ParsearModeloIntegracion(listaModelos,xmlString, path.GetPath());
+			GIL::IntegrationController::Instance()->ParsearModeloIntegracion(listaModelos, xmlString, cadena);
 			GIL::IntegrationController::Instance()->Process(listaModelos);
 		}
 		catch (GIL::IntegrationException& ex) {
@@ -1433,7 +1470,9 @@ void VentanaPrincipal::CargarHistorial()
 		if (param.CmpNoCase(wxT("-unittest")) == 0) {
 			//drop file
 			std::string dirPath = GNC::GCS::HistoryController::GetDefaultDicomDirPath();
+			LOG_INFO("INITWX", "Removing default dicomdir:" << dirPath);
 			GNC::GCS::IEntorno::Instance()->RemoveDirRecursive(dirPath);
+			LOG_INFO("INITWX", "Default dicomdir removed successfully");
 			break;
 		}
 	}
@@ -1468,13 +1507,13 @@ void VentanaPrincipal::OnComando(EventoProgreso& evento)
 {
 	switch (evento.GetTipo()) {
 		case EventoProgreso::ComandoIniciado:
-			GNC::ControladorComandos::Instance()->OnComandoLanzado(evento.GetThreadId());
+			GNC::CommandController::Instance()->OnComandoLanzado(evento.GetThreadId());
 			break;
 		case EventoProgreso::ComandoEjecutando:
-			GNC::ControladorComandos::Instance()->OnComandoProgreso(evento.GetThreadId());
+			GNC::CommandController::Instance()->OnComandoProgreso(evento.GetThreadId());
 			break;
 		case EventoProgreso::ComandoFinalizado:
-			GNC::ControladorComandos::Instance()->OnComandoFinalizado(evento.GetThreadId());
+			GNC::CommandController::Instance()->OnComandoFinalizado(evento.GetThreadId());
 			break;
 		default:
 			std::cerr << "Error, Tipo de notificacion de comando desconocida." << std::endl;
@@ -1603,10 +1642,10 @@ bool VentanaPrincipal::CerrarVista(GNC::GCS::IVista* pVista)
 		return true;
 
 	//it's important to avoid focus errors
-	this->Raise();
 	if (this->IsIconized()) {
 		this->Restore();
 	}
+	this->Raise();
 
 	wxWindow* pWindow = pVista->GetWindow();
 	//if it's a tab...
