@@ -29,6 +29,7 @@
 #include <main/controllers/controladoreventos.h>
 #include <widgets/wanotacionesquina.h>
 #include <widgets/wanotacionposicion.h>
+#include <widgets/wstaticrule.h>
 
 #include "widgetsmanager.h"
 
@@ -930,6 +931,8 @@ void GNC::WidgetsManager::CrearWidgetAnotador(GNC::GCS::IAnotador* pAnotador)
 	InsertarWidget(pW);
 	GNC::GCS::Widgets::WAnotacionPosicion* pPosicion = new GNC::GCS::Widgets::WAnotacionPosicion(pAnotador,this,-1,"",-1);
 	InsertarWidget(pPosicion);
+	GNC::GCS::Widgets::WStaticRule* pStaticRule = new GNC::GCS::Widgets::WStaticRule(this,-1,"",-1);
+	InsertarWidget(pStaticRule);
 }
 
 void GNC::WidgetsManager::EnableAnotacionDinamica(bool /*enable*/)
@@ -952,6 +955,11 @@ void GNC::WidgetsManager::MostrarOcultarAnotador()
 			GNC::GCS::Widgets::WAnotador* pAnotador = dynamic_cast<GNC::GCS::Widgets::WAnotador*> (w);
 			if (pAnotador != NULL) {
 				pAnotador->Ocultar(!pAnotador->EstaOculto());
+			} else {
+				GNC::GCS::Widgets::WStaticRule* pStaticRule = dynamic_cast<GNC::GCS::Widgets::WStaticRule*> (w);
+				if (pStaticRule != NULL) {
+					pStaticRule->Ocultar(!pStaticRule->EstaOculto());
+				}
 			}
 		}
 	}
