@@ -17,6 +17,7 @@
 #if defined(ENABLE_ANONYMIZETOOL)
 
 #include <main/gui/anonymize/anonymizedialog.h>
+#include <main/gui/history3/synchronizedialog.h>
 #include <resources/ginkgoresourcesmanager.h>
 #include <main/controllers/historytoolscontroller.h>
 
@@ -35,14 +36,25 @@ void GNC::AnonymizeTool::Execute()
 	GNC::GCS::IHistoryPanel* pHistory = GNC::HistoryToolsController::Instance()->GetHistoryPanel();
 	std::list<long> listOfPks;
 	pHistory->GetSelectedSeriesPk(listOfPks);
+	Execute (listOfPks);
+}
 
-	if (listOfPks.empty()) {
+void GNC::AnonymizeTool::Execute(const std::list<long>& seriesPk) 
+{
+	GNC::GCS::IHistoryPanel* pHistory = GNC::HistoryToolsController::Instance()->GetHistoryPanel();
+	if (seriesPk.empty()) {
 		wxMessageBox(_("Select at least one series"), _("Info"), wxICON_INFORMATION, pHistory->GetWxWindow());
 		return;
 	}
 
-	GNC::GUI::AnonymizeDialog dlg(pHistory->GetWxWindow(), listOfPks);
-	dlg.ShowModal();
+	if (!AreSeriesFullyDownloaded(seriesPk)) {
+		GNC::GUI::SynchronizeDialog dlg(pHistory->GetWxWindow(), seriesPk, this);
+		dlg.ShowModal();
+	} else {
+		GNC::GUI::AnonymizeDialog dlg(pHistory->GetWxWindow(), seriesPk);
+		dlg.ShowModal();
+	}
+
 }
 
 #endif
