@@ -23,7 +23,7 @@ namespace GNC {
 
 	class DicomizeTool : public GNC::GCS::IHistoryTool {
 	public:
-		static const GNC::GCS::IHistoryTool::UID ID =  HCore_Dicomize;
+		static const GNC::GCS::IHistoryTool::UID ID =  HCore_DicomizeFromHistory;
 		DicomizeTool();
 		virtual ~DicomizeTool();
 		virtual bool Enabled();
