@@ -23,12 +23,13 @@ namespace GNC {
 
 	class SendPACSTool : public GNC::GCS::IHistoryTool {
 	public:
-		static const GNC::GCS::IHistoryTool::UID ID =  HCore_PacsUpload;
+		static const GNC::GCS::IHistoryTool::UID ID =  HCore_HistoryPACSUpload;
 		SendPACSTool();
 		virtual ~SendPACSTool();
 		virtual bool Enabled();
 
-		virtual void Execute();
+		virtual void Execute();		
+		virtual void Execute(const std::list<long>& seriesPk);
 	};
 }
 #endif
