@@ -151,7 +151,7 @@ void GNC::ToolController::InitializeToolController()
 	for (TToolMap::iterator it = m_tools.begin(); it != m_tools.end(); ++it) 
 	{
 		GNC::GCS::IWidgetTool* pWidgetTool = dynamic_cast<GNC::GCS::IWidgetTool*> ((*it).second);
-		if (pWidgetTool != NULL && pWidgetTool->FamilyId == GNC::GCS::ITool::TFamiliaVisualizacion) {
+		if (pWidgetTool != NULL && pWidgetTool->FamilyId == GNC::GCS::ITool::TFamiliaVisualizacion && pWidgetTool->IsReady()) {
 			if (m_leftTool == NULL) {
 				GNC::GCS::TriggerButton buttonMask;
 				buttonMask.EnableLeft();
@@ -201,7 +201,7 @@ void GNC::ToolController::ReconnectToolController()
 void GNC::ToolController::AddTool(long idTool, GNC::GCS::IContract* pContract)
 {
 	GNC::GCS::ITool* pTool = GNC::GCS::IToolsRegistry::Instance()->NewTool(idTool);
-	if (pTool != NULL) {
+	if (pTool != NULL && pTool->IsReady()) {
 		GNC::GCS::IContractable* pContractableTool = dynamic_cast<GNC::GCS::IContractable*>(pTool);
 		if (pContractableTool) {
 			if (pContractableTool->IsValidContract(pContract)) {				
@@ -214,6 +214,8 @@ void GNC::ToolController::AddTool(long idTool, GNC::GCS::IContract* pContract)
 		}
 		pTool->SetToolBar(this);
 		m_tools[idTool] = pTool;
+	} else if (pTool != NULL) {
+		delete pTool;
 	}
 }
 
@@ -234,7 +236,7 @@ GNC::GCS::ITool* GNC::ToolController::GetTool(long idTool)
 void GNC::ToolController::Enable(long idTool, bool enabled)
 {
 	GNC::GCS::ITool* pTool = GetTool(idTool);
-	if (pTool != NULL && pTool->Enabled != enabled) {
+	if (pTool != NULL && pTool->IsEnabled() != enabled) {
 		pTool->Enable(enabled);
 		ReconnectToolController();
 		GNC::GCS::IEventsController::Instance()->ProcesarEvento(new GNC::GCS::Events::ToolEnabledEvent(enabled, pTool, this));
@@ -250,7 +252,7 @@ wxWindow* GNC::ToolController::CreateNewToolBar(wxWindow* pParent, GNC::GCS::ITo
 	for (TToolMap::iterator it = m_tools.begin(); it != m_tools.end(); ++it) 
 	{
 		GNC::GCS::ITool*& pTool = (*it).second;
-		if (pTool->GetFamily() == family) {
+		if (pTool->GetFamily() == family && pTool->IsReady()) {
 			pTool->AppendToolIn(pToolController);
 		}
 	}
@@ -270,7 +272,7 @@ wxWindow* GNC::ToolController::CreateNewToolBar(wxWindow* pParent, const GNC::GC
 	for (TToolMap::iterator it = m_tools.begin(); it != m_tools.end(); ++it) 
 	{
 		GNC::GCS::ITool*& pTool = (*it).second;
-		if (setOfIds.find(pTool->ID) != setOfIds.end()) {
+		if (setOfIds.find(pTool->ID) != setOfIds.end() && pTool->IsReady()) {
 			pTool->AppendToolIn(pToolController);
 		}
 	}
@@ -289,7 +291,7 @@ wxWindow* GNC::ToolController::CreateNewToolBar(wxWindow* pParent, bool alignLef
 	for (TToolMap::iterator it = m_tools.begin(); it != m_tools.end(); ++it) 
 	{
 		GNC::GCS::ITool*& pTool = (*it).second;
-		if (mapOfFamilies.find(pTool->GetFamily()) == mapOfFamilies.end()) {
+		if (mapOfFamilies.find(pTool->GetFamily()) == mapOfFamilies.end() && pTool->IsReady()) {
 			mapOfFamilies[pTool->GetFamily()] = new GNC::GUI::wxGinkgoToolBar(toolBarPanel, this, pTool->GetFamily()); 
 			if (!alignLeft) {
 				mapOfFamilies[pTool->GetFamily()]->AddStretchSpacer(1);
@@ -317,7 +319,7 @@ void GNC::ToolController::AppendsToolInMenu(wxEvtHandler* pParent, wxMenu* pMenu
 	for (TToolMap::iterator it = m_tools.begin(); it != m_tools.end(); ++it) 
 	{
 		GNC::GCS::ITool*& pTool = (*it).second;
-		if (pTool->GetFamily() == family) {
+		if (pTool->GetFamily() == family && pTool->IsReady()) {
 			if (mapSubFamilies.find(pTool->GetSubFamily()) == mapSubFamilies.end()) {
 				mapSubFamilies[pTool->GetSubFamily()] = std::list<GNC::GCS::ITool*>();
 			}
@@ -371,7 +373,7 @@ void GNC::ToolController::ActivateTool(long idTool, const GNC::GCS::TriggerButto
 	//activation will be processed in next iteration of loop event to avoid that component that request activation has been removed in action execution
 	GNC::GUI::wxActivateToolAsync evt(this, idTool, buttonMask, pWindow);
 	evt.SetId(EventHandler->GetId());
-	GNC::GCS::IEntorno::Instance()->GetVentanaRaiz()->AddPendingEvent(evt);
+	GNC::GCS::IEntorno::Instance()->GetVentanaRaiz()->GetEventHandler()->AddPendingEvent(evt);
 }
 
 void GNC::ToolController::DoActivateTool(long idTool, const GNC::GCS::TriggerButton& buttonMask, wxWindow* pWindow)
@@ -442,8 +444,9 @@ void GNC::ToolController::AppendDropDownMenu(long idTool, wxEvtHandler* pParent,
 		return;
 	}
 	GNC::GCS::ITool* pTool = m_tools[idTool];
-
-	pTool->AppendDropDownMenu(pParent,pMenu);
+	if (pTool->IsReady()) {
+		pTool->AppendDropDownMenu(pParent,pMenu);
+	}
 }
 
 GNC::GCS::IWidgetTool* GNC::ToolController::GetLeftTool()
