@@ -244,9 +244,28 @@ wxBitmap GinkgoResourcesManager::History::GetIcoAllPatients() {
 	LoadPNG(bmp, HistoryDir, wxT("ico_all_patients.png"));
 	return bmp;
 }
-wxBitmap GinkgoResourcesManager::History::GetIcoLinked() {
+
+wxBitmap GinkgoResourcesManager::History::GetIcoLocalLinked() {
 	wxBitmap bmp;
-	LoadPNG(bmp, HistoryDir, wxT("ico_linked.png"));
+	LoadPNG(bmp, HistoryDir, wxT("ico_local_linked.png"));
+	return bmp;
+}
+
+wxBitmap GinkgoResourcesManager::History::GetIcoLocalFile() {
+	wxBitmap bmp;
+	LoadPNG(bmp, HistoryDir, wxT("ico_local_file.png"));
+	return bmp;
+}
+
+wxBitmap GinkgoResourcesManager::History::GetIcoWadoLinked() {
+	wxBitmap bmp;
+	LoadPNG(bmp, HistoryDir, wxT("ico_wado_linked.png"));
+	return bmp;
+}
+
+wxBitmap GinkgoResourcesManager::History::GetIcoWadoLinkedPreview() {
+	wxBitmap bmp;
+	LoadPNG(bmp, HistoryDir, wxT("ico_wado_linked_preview.png"));
 	return bmp;
 }
 
@@ -412,6 +431,27 @@ wxBitmap GinkgoResourcesManager::ToolIcons::GetIcoTrackball(){
 	return bmp;
 }
 
+wxBitmap GinkgoResourcesManager::ToolIcons::GetIcoDownloadCloud()
+{
+	wxBitmap bmp;
+	LoadPNG(bmp, ToolIconsDir, wxT("ico_download_cloud.png"));
+	return bmp;
+}
+
+wxBitmap GinkgoResourcesManager::ToolIcons::GetIcoSearchCloud()
+{
+	wxBitmap bmp;
+	LoadPNG(bmp, ToolIconsDir, wxT("ico_search_cloud.png"));
+	return bmp;
+}
+
+wxBitmap GinkgoResourcesManager::ToolIcons::GetIcoCopyToClipboard()
+{
+	wxBitmap bmp;
+	LoadPNG(bmp, ToolIconsDir, wxT("ico_copy.png"));
+	return bmp;
+}
+
 // Menu Icons
 wxBitmap GinkgoResourcesManager::MenuIcons::GetIcoAbrir(){
 	wxBitmap bmp;
@@ -558,6 +598,11 @@ wxBitmap GinkgoResourcesManager::MenuIcons::GetIcoCross(){
 	LoadPNG(bmp, MenuIconsDir, wxT("ico_cross.png"));
 	return bmp;
 }
+wxBitmap GinkgoResourcesManager::MenuIcons::GetIcoPaste(){
+	wxBitmap bmp;
+	LoadPNG(bmp, MenuIconsDir, wxT("ico_paste.png"));
+	return bmp;
+}
 
 // Logos
 wxBitmap GinkgoResourcesManager::Logos::GetLogoGinkgo48x48(){
@@ -613,6 +658,17 @@ wxBitmap GinkgoResourcesManager::BigIcons::GetIcoBigAcquire(){
 	return bmp;
 }
 
+wxBitmap GinkgoResourcesManager::BigIcons::GetIcoBigGinkgoCloudSearch(){
+	wxBitmap bmp;
+	LoadPNG(bmp, BigIconsDir, wxT("ico_search_ginkgocloud.png"));
+	return bmp;
+}
+wxBitmap GinkgoResourcesManager::BigIcons::GetIcoDefaultDicomizer(){
+	wxBitmap bmp;
+	LoadPNG(bmp, BigIconsDir, wxT("ico_default_dicomizer.png"));
+	return bmp;
+}
+
 // Cursors
 wxImage GinkgoResourcesManager::Cursors::GetCursorTransparente(){
 	wxImage img;
