@@ -642,6 +642,8 @@ void vtkGinkgoImageViewer::UpdateDisplayExtent()
 			directionCosines->DeepCopy(IImagePropertiesProxy->GetDirection());
 			IImagePropertiesProxy->GetOutputOrigin(origin.v);
 			IImagePropertiesProxy->GetOutputSpacing(spacing.v);
+		} else {
+			LOG_ERROR("ginkgoImageViewer", "you are tying to load an image from a input connection without properties proxy");
 		}
 	}
 	else {
@@ -1043,28 +1045,26 @@ void vtkGinkgoImageViewer::SetupPipeline(bool forceReload)
 
 	SetTindex(0);
 
+	//save camera position to restore if we have to mantain zoom or zoom and pan
+	double focal[3], pos[3];
+	GetRelativePositionOfCamera(focal, pos);
+	UpdateOrientation();
+
 	UpdateDisplayExtent();
 
-	if (!mantenerVista)
+	//se comprueba si han cambiado las dimensiones o el spacing
+	bool mantenerZoom = true;
 	{
 
-		double focal[3], pos[3];
-		GetRelativePositionOfCamera(focal, pos);
-		UpdateOrientation();
-
-		//se comprueba si han cambiado las dimensiones o el spacing
-		bool mantenerZoom = true;
-		{
-
-			for(int i = 0; i < 3 && mantenerZoom; ++i) {
-				mantenerZoom = mantenerZoom && oldSpacing[i] == curSpacing[i] && oldDimensions[i] == curDimensions[i];
-			}
-		}
-		ResetZoom(mantenerZoom, 0);
-		if (mantenerZoom) {
-			SetRelativePositionOfCamera(focal, pos);
+		for(int i = 0; i < 3 && mantenerZoom; ++i) {
+			mantenerZoom = mantenerZoom && oldSpacing[i] == curSpacing[i] && oldDimensions[i] == curDimensions[i];
 		}
 	}
+	ResetZoom(mantenerZoom, 0);
+	if (mantenerVista || mantenerZoom) {
+		SetRelativePositionOfCamera(focal, pos);
+	}
+	
 }
 
 //====================================================================================================
@@ -1814,11 +1814,25 @@ void vtkGinkgoImageViewer::RotateCamera( bool right)
 void vtkGinkgoImageViewer::Flip(bool vertical)
 {
 	Estado& e = members->Estado;
-	if (vertical) {
-		e.FlipVertical = !e.FlipVertical;
+	//if its rolled between 45 and 135 or between -45 and -135 vertical means horizontal and horizontal vertical
+	if ( (e.RollOffset > 45 && e.RollOffset <= 135)
+		|| (e.RollOffset < -45 && e.RollOffset >= -135) ) 
+	{
+		if (vertical) {
+			e.FlipHorizontal = !e.FlipHorizontal;
+		}
+		else {
+			e.FlipVertical = !e.FlipVertical;
+		}
 	}
-	else {
-		e.FlipHorizontal = !e.FlipHorizontal;
+	else 
+	{
+		if (vertical) {
+		e.FlipVertical = !e.FlipVertical;
+		}
+		else {
+			e.FlipHorizontal = !e.FlipHorizontal;
+		}
 	}
 	UpdateOrientation();
 }
@@ -2170,6 +2184,14 @@ double vtkGinkgoImageViewer::GetZoom()
 	return e.Zoom;
 }
 
+double vtkGinkgoImageViewer::GetZoomFactor()
+{
+	Pipeline& p = members->Pipeline;
+	//Estado& e = members->Estado;
+
+	return p.Renderer->GetActiveCamera()->GetParallelScale() / (double) p.RenderWindow->GetSize()[1];
+}
+
 void vtkGinkgoImageViewer::SyncSetZoom(double factor)
 {
 	SetZoom(factor);
@@ -2238,6 +2260,23 @@ void vtkGinkgoImageViewer::CoordenadasImagenACoordenadasMundo(const double ip[3]
 	}
 }
 
+
+void vtkGinkgoImageViewer::CoordenadasMundoACoordenadasImagen(const double wp[3], double ip[3])
+{
+	vtkSmartPointer<vtkImageData> input = GetInput();
+	if (!input)
+	{
+		return;
+	}
+
+	const double* spacing = input->GetSpacing();
+	const double* origin = input->GetOrigin();
+
+	ip[0] = (wp[0] - origin[0]) / spacing[0];
+	ip[1] = ( wp[1] - origin[1]) / spacing[1]; 
+	ip[2] = (wp[2] - origin[2]) / spacing[2];
+}
+
 void vtkGinkgoImageViewer::CoordenadasImagenACoordenadasPixel(const double ip[3], int pp[2])
 {
 	//Transforma a coordenadas pixel para usar con vtk (un 0.5 del desplazamiento y otro para hacer un round)
