@@ -1,16 +1,16 @@
 /*
- *  
- *  $Id: wanotacionesquina.cpp $
- *  Ginkgo CADx Project
- *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
- *  http://ginkgo-cadx.com
- *
- *  This file is licensed under LGPL v3 license.
- *  See License.txt for details
- *
- *
- */
+*  
+*  $Id: wanotacionesquina.cpp $
+*  Ginkgo CADx Project
+*
+*  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+*  http://ginkgo-cadx.com
+*
+*  This file is licensed under LGPL v3 license.
+*  See License.txt for details
+*
+*
+*/
 
 #include <sstream>
 #include <cmath>
@@ -26,6 +26,7 @@
 #include <api/globals.h>
 #include <api/helpers/helpertexto.h>
 #include <api/iwidgetsmanager.h>
+#include <api/controllers/icontroladorlog.h>
 #include <api/ievento.h>
 #include <api/icontexto.h>
 #include <api/math/geometry3d.h>
@@ -48,6 +49,21 @@
 
 #define ANNOTATOR_TEXT_COLOR 0.9f, 0.9f, 0.9f, 1.0f
 
+namespace GNC {
+	const char* PatientOrientation[9*3*3] = {
+		"", "", "",   "", "", "",   "", "", "", // N/A
+		"R", "", "L",   "A", "", "P",   "I", "", "S", // HFS
+		"L", "", "R",   "P", "", "A",   "I", "", "S", // HFP
+		"A", "", "P",   "L", "", "R",   "I", "", "S", // HFDR
+		"P", "", "A",   "R", "", "L",   "I", "", "S", // HFDL
+		"P", "", "A",   "L", "", "R",   "S", "", "I", // FFDR
+		"A", "", "P",   "R", "", "L",   "S", "", "I", // FFDL
+		"L", "", "R",   "A", "", "P",   "S", "", "I", // FFS
+		"R", "", "L",   "P", "", "A",   "S", "", "I", // FFP
+
+	};
+}
+
 namespace GNC {
 	namespace GCS {
 		namespace Widgets {
@@ -67,10 +83,17 @@ namespace GNC {
 					{
 						m_TexturaModificada[i] = false;
 					}
-					m_Alineacion[0] = GNC::GCS::Widgets::HelperTexto::TA_Izquierda;
-					m_Alineacion[1] = GNC::GCS::Widgets::HelperTexto::TA_Derecha;
-					m_Alineacion[2] = GNC::GCS::Widgets::HelperTexto::TA_Izquierda;
-					m_Alineacion[3] = GNC::GCS::Widgets::HelperTexto::TA_Derecha;
+
+					m_Alineacion[GNC::GCS::Widgets::WAnotador::TP_TopLeft] = GNC::GCS::Widgets::HelperTexto::TA_Izquierda;
+					m_Alineacion[GNC::GCS::Widgets::WAnotador::TP_TopRight] = GNC::GCS::Widgets::HelperTexto::TA_Derecha;
+					m_Alineacion[GNC::GCS::Widgets::WAnotador::TP_BottomLeft] = GNC::GCS::Widgets::HelperTexto::TA_Izquierda;
+					m_Alineacion[GNC::GCS::Widgets::WAnotador::TP_BottomRight] = GNC::GCS::Widgets::HelperTexto::TA_Derecha;
+
+					m_Alineacion[GNC::GCS::Widgets::WAnotador::TP_Top] = GNC::GCS::Widgets::HelperTexto::TA_Centrado;
+					m_Alineacion[GNC::GCS::Widgets::WAnotador::TP_Right] = GNC::GCS::Widgets::HelperTexto::TA_Derecha;
+					m_Alineacion[GNC::GCS::Widgets::WAnotador::TP_Bottom] = GNC::GCS::Widgets::HelperTexto::TA_Izquierda;
+					m_Alineacion[GNC::GCS::Widgets::WAnotador::TP_Left] = GNC::GCS::Widgets::HelperTexto::TA_Centrado;
+
 					m_pFontOptions = cairo_font_options_create();
 					m_TexturaMetrica.Redimensionar(2, 2);
 					cairo_get_font_options(m_TexturaMetrica.cr, m_pFontOptions);
@@ -228,15 +251,15 @@ namespace GNC {
 					GTRACE("Anotaciones::Render(" << c->GetRenderer() << ")");
 					GNC::GCS::Vector pos;
 
-					pos = GNC::GCS::Vector(0.0f, 0.0f).Redondeado();
+					pos = GNC::GCS::Vector(0.0, 0.0).Redondeado();
 					m_Texturas[WAnotador::TP_TopLeft].Actualizar();
 					m_Texturas[WAnotador::TP_TopLeft].Render(c, pos, false, false, 0);
 
-					pos = GNC::GCS::Vector(m_RectViewport[1].x - m_TamTexto[WAnotador::TP_TopRight].x, 0.0f).Redondeado();
+					pos = GNC::GCS::Vector(m_RectViewport[1].x - m_TamTexto[WAnotador::TP_TopRight].x, 0.0).Redondeado();
 					m_Texturas[WAnotador::TP_TopRight].Actualizar();
 					m_Texturas[WAnotador::TP_TopRight].Render(c, pos, false, false, 0);
 
-					pos = GNC::GCS::Vector(0.0f, m_RectViewport[1].y - m_TamTexto[WAnotador::TP_BottomLeft].y).Redondeado();
+					pos = GNC::GCS::Vector(0.0, m_RectViewport[1].y - m_TamTexto[WAnotador::TP_BottomLeft].y).Redondeado();
 					m_Texturas[WAnotador::TP_BottomLeft].Actualizar();
 					m_Texturas[WAnotador::TP_BottomLeft].Render(c, pos, false, false, 0);
 
@@ -244,6 +267,25 @@ namespace GNC {
 					m_Texturas[WAnotador::TP_BottomRight].Actualizar();
 					m_Texturas[WAnotador::TP_BottomRight].Render(c, pos, false, false, 0);
 
+
+					//
+					pos = GNC::GCS::Vector( (0.5 * m_RectViewport[1].x) - m_TamTexto[WAnotador::TP_Top].x, 0.0).Redondeado();
+					m_Texturas[WAnotador::TP_Top].Actualizar();
+					m_Texturas[WAnotador::TP_Top].Render(c, pos, false, false, 0);
+
+					pos = GNC::GCS::Vector(0.0, (0.5 * m_RectViewport[1].y) - m_TamTexto[WAnotador::TP_Left].y).Redondeado();
+					m_Texturas[WAnotador::TP_Left].Actualizar();
+					m_Texturas[WAnotador::TP_Left].Render(c, pos, false, false, 0);
+
+					pos = GNC::GCS::Vector((0.5 * m_RectViewport[1].x) - m_TamTexto[WAnotador::TP_Bottom].x, m_RectViewport[1].y - m_TamTexto[WAnotador::TP_Bottom].y).Redondeado();
+					m_Texturas[WAnotador::TP_Bottom].Actualizar();
+					m_Texturas[WAnotador::TP_Bottom].Render(c, pos, false, false, 0);
+
+					pos = GNC::GCS::Vector( m_RectViewport[1].x - m_TamTexto[WAnotador::TP_Right].x,  (0.5 * m_RectViewport[1].y) - m_TamTexto[WAnotador::TP_Right].y).Redondeado();
+					m_Texturas[WAnotador::TP_Right].Actualizar();
+					m_Texturas[WAnotador::TP_Right].Render(c, pos, false, false, 0);
+					//
+
 					Modificar(false);
 
 				}
@@ -279,7 +321,7 @@ namespace GNC {
 				bool m_Correcta;
 				float m_TamFuente;
 
-				GNC::GCS::Widgets::HelperTexto::TAlineamiento m_Alineacion[4];
+				GNC::GCS::Widgets::HelperTexto::TAlineamiento m_Alineacion[WAnotador::TP_NumPosiciones];
 
 				GNC::GCS::IWidgetsRenderer* m_pRenderer;
 				bool m_Modificada;
@@ -292,8 +334,7 @@ namespace GNC {
 			public:
 				typedef std::map<GNC::GCS::IWidgetsRenderer*,Anotaciones*> MapaAnotaciones;
 
-				MapaAnotaciones m_Anotaciones;
-
+				MapaAnotaciones       m_Anotaciones;
 
 				inline Anotaciones* Get(GNC::GCS::IWidgetsRenderer* key)
 				{
@@ -306,6 +347,7 @@ namespace GNC {
 					else {
 						m_Anotaciones[key] = res = new Anotaciones(key);
 					}
+
 					return res;
 				}
 
@@ -341,6 +383,40 @@ namespace GNC {
 	}
 }
 
+
+int GetOrientation(const std::string& strPos) {
+	if (strcmp(strPos.c_str(), "") == 0) {
+		return 1;
+	}
+	else if (strcmp(strPos.c_str(), "HFS") == 0) {
+		return 1;
+	}
+	else if (strcmp(strPos.c_str(), "HFP") == 0) {
+		return 2;
+	}
+	else if (strcmp(strPos.c_str(), "HFDR") == 0) {
+		return 3;
+	}
+	else if (strcmp(strPos.c_str(), "HFDL") == 0) {
+		return 4;
+	}
+	else if (strcmp(strPos.c_str(), "FFDR") == 0) {
+		return 5;
+	}
+	else if (strcmp(strPos.c_str(), "FFDL") == 0) {
+		return 6;
+	}
+	else if (strcmp(strPos.c_str(), "FFS") == 0) {
+		return 7;
+	}
+	else if(strcmp(strPos.c_str(), "FFP") == 0) {
+		return 8;
+	}
+	else {
+		return 0;
+	}
+}
+
 //region "Constructor y destructor"
 
 GNC::GCS::Widgets::WAnotador::WAnotador(GNC::GCS::IAnotador* annotator, IWidgetsManager* pManager, long vid, const char* nombre, long gid) : GNC::GCS::Widgets::IWidget(pManager, vid, nombre, gid)
@@ -354,6 +430,10 @@ GNC::GCS::Widgets::WAnotador::WAnotador(GNC::GCS::IAnotador* annotator, IWidgets
 
 	GTRACE("AnotadorEsquina creado");
 
+	for (int i = 0; i < TP_NumPosiciones; ++i) {
+		m_volatileProperty[i] = false;
+	}
+
 	GNC::GCS::Events::EventoModificacionImagen evt2(m_pManager->GetVista());
 	GNC::GCS::IEventsController::Instance()->Registrar(this, evt2);
 }
@@ -393,6 +473,8 @@ bool GNC::GCS::Widgets::WAnotador::HitTest(GNC::GCS::Vector* , int )
 	return false;
 }
 
+
+
 void GNC::GCS::Widgets::WAnotador::Render(GNC::GCS::Contexto3D* c)
 {
 	if(m_Oculto){
@@ -421,10 +503,45 @@ void GNC::GCS::Widgets::WAnotador::Render(GNC::GCS::Contexto3D* c)
 
 	pAnotaciones->Redimensionar(viewport);
 
+	bool recalc = false;
+
 	if(!pAnotaciones->m_Correcta) {
+		recalc = true;
 		RecalcularEstaticas(pAnotaciones, c);
 	}
 
+	if (!recalc) {
+		for (int i = 0; i < TP_NumPosiciones; ++i) {
+			if (m_volatileProperty[i]) {
+				switch ((WAnotador::TPosicionAnotacion)i) {
+				case TP_TopLeft:
+					pAnotaciones->SetAnotation(TP_TopLeft, m_pAnnotator->GetTopLeftAnnotation(c));
+					break;
+				case TP_TopRight:
+					pAnotaciones->SetAnotation(TP_TopRight, m_pAnnotator->GetTopRightAnnotation(c));
+					break;
+				case TP_BottomLeft:
+					pAnotaciones->SetAnotation(TP_BottomLeft, m_pAnnotator->GetBottomLeftAnnotation(c));
+					break;
+				case TP_BottomRight:
+					pAnotaciones->SetAnotation(TP_BottomRight, m_pAnnotator->GetBottomRightAnnotation(c));
+					break;
+				case TP_Top:
+					break;
+				case TP_Right:
+					break;
+				case TP_Bottom:
+					break;
+				case TP_Left:
+					break;
+				default:
+					break;
+				}
+				
+			}
+		}
+	}
+
 	pAnotaciones->Actualizar(m_color);
 
 	pAnotaciones->Render(c);
@@ -436,9 +553,9 @@ void GNC::GCS::Widgets::WAnotador::Render(GNC::GCS::Contexto3D* c)
 
 	glMatrixMode(GL_TEXTURE);
 	glPopMatrix();
-	
+
 	glMatrixMode(GL_MODELVIEW);
-	
+
 	glPopAttrib();
 
 }
@@ -478,6 +595,192 @@ void GNC::GCS::Widgets::WAnotador::RecalcularEstaticas(Anotaciones* pAnotaciones
 	pAnotaciones->SetAnotation(TP_TopRight, m_pAnnotator->GetTopRightAnnotation(c));
 	pAnotaciones->SetAnotation(TP_BottomLeft, m_pAnnotator->GetBottomLeftAnnotation(c));
 	pAnotaciones->SetAnotation(TP_BottomRight, m_pAnnotator->GetBottomRightAnnotation(c));
+
+
+	GNC::GCS::Vector3D camPos;
+	GNC::GCS::Vector3D camDir;
+	GNC::GCS::Vector3D camUp;
+
+	c->GetRenderer()->GetCamVectors(camPos.v, camDir.v, camUp.v);
+
+	for (int i = 0; i < 3; ++i) {
+		if (std::abs(camUp.v[i]) < 0.1) {
+			camUp.v[i] = 0.0;
+		}
+		if (std::abs(camDir.v[i]) < 0.1) {
+			camDir.v[i] = 0.0;
+		}
+	}
+
+	GNC::GCS::Vector3D camCross = camDir.ProductoVectorial(camUp);
+
+	for (int i = 0; i < 3; ++i) {
+		if (std::abs(camCross.v[i]) < 0.1) {
+			camCross.v[i] = 0.0;
+		}
+	}
+
+	GNC::GCS::Vector3D camOrient[3][2];
+	camOrient[0][0] = camCross.Sign(); // izq
+	camOrient[0][1] = GNC::GCS::Vector3D() - camOrient[0][0];   // der
+
+	camOrient[1][0] = camUp.Stabilized().Sign();                // up
+	camOrient[1][1] = GNC::GCS::Vector3D() - camOrient[1][0];   // down
+
+	camOrient[2][0] = camDir.Stabilized().Sign();               // back
+	camOrient[2][1] = GNC::GCS::Vector3D() - camOrient[2][0];   // front
+
+	std::string strPos = m_pAnnotator->GetPatientPosition(c);
+	std::stringstream trimmer;
+	trimmer << strPos;
+	int patientPosIndex = GetOrientation(trimmer.str());
+
+	std::ostringstream left;
+	std::ostringstream right;
+	std::ostringstream top;
+	std::ostringstream bottom;
+
+	LOG_DEBUG("View", "Current orientation:");
+	LOG_DEBUG("View", "Left = " << camOrient[0][1] << ", Left = " << camOrient[0][0]);
+	LOG_DEBUG("View", "Up  = " << camOrient[1][0] << ", Down = " << camOrient[1][1]);
+
+	const int offPos = 9 * patientPosIndex;
+	const int offX = 0;
+	const int offY = 3;
+	const int offZ = 6;
+	const int offSignNeg = 0;
+	const int offSignZero = 1;
+	const int offSignPos = 2;
+
+	// Left X:
+	if (camOrient[0][0][0] == 1.0) {
+		left << PatientOrientation[offPos + offX + offSignPos];
+	}
+	else if (camOrient[0][0][0] == -1.0) {
+		left << PatientOrientation[offPos + offX + offSignNeg];
+	}
+	else {
+		left << PatientOrientation[offPos + offX + offSignZero];
+	}
+	// Left Y:
+	if (camOrient[0][0][1] == 1.0) {
+		left << PatientOrientation[offPos + offY + offSignPos];
+	}
+	else if (camOrient[0][0][1] == -1.0) {
+		left << PatientOrientation[offPos + offY + offSignNeg];
+	}
+	else {
+		left << PatientOrientation[offPos + offY + offSignZero];
+	}
+	// Left Z:
+	if (camOrient[0][0][2] == 1.0) {
+		left << PatientOrientation[offPos + offZ + offSignPos];
+	}
+	else if (camOrient[0][0][2] == -1.0) {
+		left << PatientOrientation[offPos + offZ + offSignNeg];
+	}
+	else {
+		left << PatientOrientation[offPos + offZ + offSignZero];
+	}
+
+	// Right X:
+	if (camOrient[0][1][0] == 1.0) {
+		right << PatientOrientation[offPos + offX + offSignPos];
+	}
+	else if (camOrient[0][1][0] == -1.0) {
+		right << PatientOrientation[offPos + offX + offSignNeg];
+	}
+	else {
+		right << PatientOrientation[offPos + offX + offSignZero];
+	}
+	// Right Y:
+	if (camOrient[0][1][1] == 1.0) {
+		right << PatientOrientation[offPos + offY + offSignPos];
+	}
+	else if (camOrient[0][1][1] == -1.0) {
+		right << PatientOrientation[offPos + offY + offSignNeg];
+	}
+	else {
+		right << PatientOrientation[offPos + offY + offSignZero];
+	}
+	// Right Z:
+	if (camOrient[0][1][2] == 1.0) {
+		right << PatientOrientation[offPos + offZ + offSignPos];
+	}
+	else if (camOrient[0][1][2] == -1.0) {
+		right << PatientOrientation[offPos + offZ + offSignNeg];
+	}
+	else {
+		right << PatientOrientation[offPos + offZ + offSignZero];
+	}
+
+	// Top X:
+	if (camOrient[1][0][0] == 1.0) {
+		top << PatientOrientation[offPos + offX + offSignPos];
+	}
+	else if (camOrient[1][0][0] == -1.0) {
+		top << PatientOrientation[offPos + offX + offSignNeg];
+	}
+	else {
+		top << PatientOrientation[offPos + offX + offSignZero];
+	}
+	// Top Y:
+	if (camOrient[1][0][1] == 1.0) {
+		top << PatientOrientation[offPos + offY + offSignPos];
+	}
+	else if (camOrient[1][0][1] == -1.0) {
+		top << PatientOrientation[offPos + offY + offSignNeg];
+	}
+	else {
+		top << PatientOrientation[offPos + offY + offSignZero];
+	}
+	// Top Z:
+	if (camOrient[1][0][2] == 1.0) {
+		top << PatientOrientation[offPos + offZ + offSignPos];
+	}
+	else if (camOrient[1][0][2] == -1.0) {
+		top << PatientOrientation[offPos + offZ + offSignNeg];
+	}
+	else {
+		top << PatientOrientation[offPos + offZ + offSignZero];
+	}
+
+	// Bottom X:
+	if (camOrient[1][1][0] == 1.0) {
+		bottom << PatientOrientation[offPos + offX + offSignPos];
+	}
+	else if (camOrient[1][1][0] == -1.0) {
+		bottom << PatientOrientation[offPos + offX + offSignNeg];
+	}
+	else {
+		bottom << PatientOrientation[offPos + offX + offSignZero];
+	}
+	// Bottom Y:
+	if (camOrient[1][1][1] == 1.0) {
+		bottom << PatientOrientation[offPos + offY + offSignPos];
+	}
+	else if (camOrient[1][1][1] == -1.0) {
+		bottom << PatientOrientation[offPos + offY + offSignNeg];
+	}
+	else {
+		bottom << PatientOrientation[offPos + offY + offSignZero];
+	}
+	// Bottom Z:
+	if (camOrient[1][1][2] == 1.0) {
+		bottom << PatientOrientation[offPos + offZ + offSignPos];
+	}
+	else if (camOrient[1][1][2] == -1.0) {
+		bottom << PatientOrientation[offPos + offZ + offSignNeg];
+	}
+	else {
+		bottom << PatientOrientation[offPos + offZ + offSignZero];
+	}
+
+	pAnotaciones->SetAnotation(TP_Top, top.str());
+	pAnotaciones->SetAnotation(TP_Right, right.str());
+	pAnotaciones->SetAnotation(TP_Bottom, bottom.str());
+	pAnotaciones->SetAnotation(TP_Left, left.str());
+
 	pAnotaciones->m_Correcta = true;
 }
 
@@ -502,6 +805,11 @@ void GNC::GCS::Widgets::WAnotador::SetTextColor(const GNC::GCS::GLHelper::TColor
 
 //region "Estado interno"
 
+void GNC::GCS::Widgets::WAnotador::setVolatileProperty(TPosicionAnotacion pos, bool enabled)
+{
+	m_volatileProperty[pos] = enabled;
+}
+
 void GNC::GCS::Widgets::WAnotador::InvalidarTodas()
 {
 	m_Estado->InvalidarTodas();
@@ -517,7 +825,7 @@ void GNC::GCS::Widgets::WAnotador::ProcesarEvento(GNC::GCS::Events::IEvent *evt)
 	}
 	switch (evt->GetCodigoEvento()) {
 
-		case ginkgoEVT_Core_ModificacionImagen:
+	case ginkgoEVT_Core_ModificacionImagen:
 		{
 			GNC::GCS::Events::EventoModificacionImagen* pEvt = dynamic_cast<GNC::GCS::Events::EventoModificacionImagen*>(evt);
 			if (pEvt != NULL && pEvt->GetTipo() == GNC::GCS::Events::EventoModificacionImagen::AnotacionesEstaticasModificadas) {
@@ -525,7 +833,7 @@ void GNC::GCS::Widgets::WAnotador::ProcesarEvento(GNC::GCS::Events::IEvent *evt)
 				m_Estado->InvalidarTodas();
 			}
 		}
-			break;
+		break;
 
 	}
 }
@@ -563,17 +871,17 @@ void GNC::GCS::Widgets::WAnotador::OffscreenRender(GNC::GCS::Contexto3D* c)
 	}
 	/*
 	if (!TamCajaMaxima.EsNulo()) {
-		TamFuente = ((TamViewPort * TAMFUENTE) / TamCajaMaxima).Redondear().ComponenteMinima(); // Calculo del tamanyo de fuente maxima
-		TamFuente = std::max(TAMFUENTE_MIN, TamFuente);
-		for (int i = 0; i < WAnotador::TP_NumPosiciones; ++i) {
-			TamTexto[i] *=  (TamFuente / TAMFUENTE);
-			TamTexto[i].Redondear();
-		}
+	TamFuente = ((TamViewPort * TAMFUENTE) / TamCajaMaxima).Redondear().ComponenteMinima(); // Calculo del tamanyo de fuente maxima
+	TamFuente = std::max(TAMFUENTE_MIN, TamFuente);
+	for (int i = 0; i < WAnotador::TP_NumPosiciones; ++i) {
+	TamTexto[i] *=  (TamFuente / TAMFUENTE);
+	TamTexto[i].Redondear();
+	}
 	}
 	else{
-		for (int i = 0; i < WAnotador::TP_NumPosiciones; ++i) {
-			TamTexto[i].Redondear();
-		}
+	for (int i = 0; i < WAnotador::TP_NumPosiciones; ++i) {
+	TamTexto[i].Redondear();
+	}
 	}
 	cairo_set_font_size(c->cr, TamFuente);
 	*/
