@@ -399,11 +399,11 @@ GNKVisualizator::ECGStudy::~ECGStudy(){
 
 void GNKVisualizator::ECGStudy::InitializeContext(long pkSeries)
 {
-	GNC::GCS::IHistoryController::FileModelList fileModels;
+	GNC::GCS::IHistoryController::LightFileModelList fileModels;
 	GNC::GCS::HistoryController::Instance()->GetSeriesSortedFileModels(pkSeries, fileModels);
 
 	std::list<std::string> rutas;
-	for (GNC::GCS::IHistoryController::FileModelList::iterator itFile = fileModels.begin(); itFile != fileModels.end(); ++itFile) 
+	for (GNC::GCS::IHistoryController::LightFileModelList::iterator itFile = fileModels.begin(); itFile != fileModels.end(); ++itFile) 
 	{
 		rutas.push_back((*itFile).real_path);
 	}
@@ -426,6 +426,11 @@ GNKVisualizator::ECGStudy::TListChannelInfo& GNKVisualizator::ECGStudy::GetListO
 	LoadChannels();
 	return ECGFiles[ActiveFileIndex]->GetListOfChannels();
 }
+bool GNKVisualizator::ECGStudy::Ok()
+{
+	LoadChannels();
+	return ECGFiles[ActiveFileIndex]->Groups.size() > 0;
+}
 
 std::list<std::string> GNKVisualizator::ECGStudy::GetLabelOfMultiplexGroups()
 {
