@@ -54,7 +54,7 @@
 #include <api/imodelointegracion.h>
 #include <api/controllers/imodulecontroller.h>
 #include <api/controllers/icontroladorpermisos.h>
-#include <api/controllers/icommandscontroller.h>
+#include <main/controllers/commandcontroller.h>
 #include <main/controllers/hangingprotocolcontroller.h>
 
 #include <main/entorno.h>
@@ -313,17 +313,49 @@ public:
 
 	void SetSlice(int slicenum)
 	{
-		return GView->GoToSlice(slicenum, false);
+		int tsize = GView->IVista->VisualizatorStudy->GetTSizeActive();
+
+		if (tsize == 1) {
+			GView->GoToSlice(slicenum, false);
+		}
+		else {
+			bool ok = true;
+			for(GVistaCompleja::TListaGVistasSimples::iterator it = GView->m_VistasSimples.begin(); it != GView-> m_VistasSimples.end(); ++it) {
+				GVistaSimple* vs = *it;
+				vs->GoToTSlice(slicenum, false);
+			}
+		}
 	}
 
 	int GetSlice() const
 	{
-		return GView->GetCurrentSlice();
+		int tsize = GView->IVista->VisualizatorStudy->GetTSizeActive();
+
+		if (tsize == 1) {
+			return GView->IVista->VisualizatorStudy->GetSliceNumber();
+		}
+		else {
+			GVistaCompleja::TListaGVistasSimples::iterator it = GView->m_VistasSimples.begin();
+			if (it != GView-> m_VistasSimples.end()) {
+				GVistaSimple* vs = *it;
+				return vs->ViewImage2D->GetTindex();
+			}
+			else {
+				return 0;
+			}
+		}
 	}
 
 	int GetNumberOfSlices() const
 	{
-		return GView->IVista->VisualizatorStudy->GetSliceNumber();
+		int tsize = GView->IVista->VisualizatorStudy->GetTSizeActive();
+
+		if (tsize == 1) {
+			return GView->IVista->VisualizatorStudy->GetSliceNumber();
+		}
+		else {
+			return tsize;
+		}
 	}
 
 	virtual ListaWindowLevels& GetWindowLevelList()
@@ -447,6 +479,9 @@ GVistaCompleja::GVistaCompleja(GNKVisualizator::Vista2D* pIVista) : VistaComplej
 	pToolBar->AddTool(HCore_Reset, (GNC::GCS::ISliderContract*) Delegate);
 	pToolBar->AddTool(HCore_WindowLayout, WindowLayoutDelegate);
 	pToolBar->AddTool(HCore_RotateAndFlip, (GNC::GCS::ISliderContract*) Delegate);
+
+	pToolBar->AddTool(HCore_SecondaryCapture, (GNC::GCS::ISliderContract*)Delegate);
+	pToolBar->AddTool(HCore_CopyImageToClipboard, (GNC::GCS::ISliderContract*)Delegate);
 	//tools
 	pToolBar->AddTool(HCore_ShowDicomTags, (GNC::GCS::IViewContract*) IVista);
 	pToolBar->AddTool(HCore_ShowHistory, (GNC::GCS::IViewContract*) IVista);
@@ -455,6 +490,9 @@ GVistaCompleja::GVistaCompleja(GNKVisualizator::Vista2D* pIVista) : VistaComplej
 	pToolBar->AddTool(HCore_ImageExport, ExportDelegate);
 	pToolBar->AddTool(HCore_ImagePrint, ExportDelegate);
 	pToolBar->AddTool(HCore_Deshacer, (GNC::GCS::IViewContract*) IVista);
+	pToolBar->AddTool(HCore_PACSUpload, (GNC::GCS::IViewContract*) IVista);
+	pToolBar->AddTool(HCore_DicomizeFromView, (GNC::GCS::IViewContract*) IVista);
+	pToolBar->AddTool(HCore_AddFileToHistory, (GNC::GCS::IViewContract*) IVista);
 
 	m_pSizerTools->Add(pToolBar->CreateNewToolBar(this, GNC::GCS::ITool::TFamiliaVisualizacion), 0, wxEXPAND);
 	m_pSizerTools->Add(pToolBar->CreateNewToolBar(this, GNC::GCS::ITool::TFamiliaMedicion), 0, wxEXPAND);
@@ -529,7 +567,7 @@ GVistaCompleja::GVistaCompleja(GNKVisualizator::Vista2D* pIVista) : VistaComplej
 	//m_pManager->InsertarWidget(new GNC::GCS::Widgets::WProgreso(m_VistasSimples.front()->ViewInteractor2D, m_pManager, -1, "progreso", 666));
 	m_pManager->EnableAnimation();
 
-	Layout();
+	this->Layout();
 }
 
 GVistaCompleja::~GVistaCompleja()
@@ -544,7 +582,7 @@ GVistaCompleja::~GVistaCompleja()
 	IVista->VisualizatorStudy->Viewer = NULL;
 
 	if (IVista != NULL) {
-		GNC::GCS::IEntorno::Instance()->GetControladorComandos()->AbortarComandosDeOwner(IVista);
+		GNC::GCS::IEntorno::Instance()->GetCommandController()->AbortarComandosDeOwner(IVista);
 	}
 
 	//Disconnect(wxEVT_CHILD_FOCUS, wxChildFocusEventHandler(GVistaCompleja::OnFocus),NULL,this);
@@ -628,7 +666,7 @@ void GVistaCompleja::LoadSeries(long seriesPk)
 	IniciarPipeline();
 }
 
-void GVistaCompleja::IniciarPipeline(const GNC::GCS::Ptr<GNC::GCS::HangingProtocol>& hangingProtocol)
+void GVistaCompleja::IniciarPipeline(const GNC::GCS::Ptr<GNC::GCS::Layout>& layout)
 {
 	m_pManager->EliminarTodosLosWidgets(false);
 	m_pPanelManipulacion->Enable(true);
@@ -672,25 +710,22 @@ void GVistaCompleja::IniciarPipeline(const GNC::GCS::Ptr<GNC::GCS::HangingProtoc
 	//contrato window level, hay que preguntarle al viewer de la primera vista porque el estudioatencionprimaria no tiene viewer
 	IVista->GetToolController()->Enable(HCore_WindowLevel, m_VistasSimples[0]->ViewImage2D->GetNumberOfComponents() == 1);
 
-	if (hangingProtocol.IsValid()) {
-		if (hangingProtocol->getLayout().IsValid()) {
-			if (hangingProtocol->getLayout()->getMatcher().IsValid()) {
-				for (std::vector<long>::iterator it = IVista->VisualizatorStudy->OpenedSeries.begin(); it != IVista->VisualizatorStudy->OpenedSeries.end(); ++it)
+	if (layout.IsValid()) {
+		if (layout->getMatcher().IsValid()) {
+			for (std::vector<long>::iterator it = IVista->VisualizatorStudy->OpenedSeries.begin(); it != IVista->VisualizatorStudy->OpenedSeries.end(); ++it)
+			{
+				if (layout->getMatcher()->MatchesSeries((*it))) 
 				{
-					if (hangingProtocol->getLayout()->getMatcher()->MatchesSeries((*it))) 
-					{
-						LoadSeries(*it);
-					}
+					LoadSeries(*it);
 				}
-				WindowLayoutDelegate->SetWindowLayout(hangingProtocol->getLayout()->getRows(), hangingProtocol->getLayout()->getColumns());
 			}
-		} else {
-			LOG_WARN("HangingProtocolDelegate", "trying to build an invalid layout");
+			WindowLayoutDelegate->SetWindowLayout(layout->getRows(), layout->getColumns());
 		}
+		layout->applyWindowProperties(IVista);
 	} else {
 		GoToSlice(0,false,false);
-		GNC::GCS::IEntorno::Instance()->GetControladorEventos()->ProcesarEvento(new GNC::GCS::Events::EventoModificacionImagen(IVista,GNC::GCS::Events::EventoModificacionImagen::ImagenCargada));
 	}
+	
 	m_pManager->CrearWidgetAnotador(this);
 }
 
@@ -706,7 +741,7 @@ void GVistaCompleja::DetenerPipeline()
 
 void GVistaCompleja::OnCargaFinalizada()
 {
-	m_pPanelPreview->LoadModel(this, IVista->VisualizatorStudy);
+	m_pPanelPreview->LoadModel();
 	m_pManager->OcultarTodosLosWidgets(true, 666);
 	m_pManager->DisableAnimation();
 	m_pManager->Render();
@@ -738,7 +773,7 @@ void GVistaCompleja::OnPaint(wxPaintEvent& event)
 							LOG_ERROR("GVistaCompleja", "Textura no cargada en memoria de video")
 							GNC::GCS::IEntorno::Instance()->GetControladorEventos()->ProcesarEvento(new GNC::GCS::Events::EventoMensajes(NULL,_Std("Error: You have exhausted the system's video memory and has not been able to load the image. Close some studies to free memory."),GNC::GCS::Events::EventoMensajes::PopUpMessage,false));
 							GADAPI::ComandoDestruirVistaParams* pParams = new GADAPI::ComandoDestruirVistaParams(IVista);
-							GNC::GCS::IEntorno::Instance()->GetControladorComandos()->ProcessAsync(_Std("Destroy View"),new GADAPI::ComandoDestruirVista(pParams),NULL);
+							GNC::GCS::IEntorno::Instance()->GetCommandController()->ProcessAsync(_Std("Destroy View"),new GADAPI::ComandoDestruirVista(pParams),NULL);
 						}
 					} else {
 						//se comprobara mas tarde porque la textura todavia no tiene id
@@ -749,14 +784,14 @@ void GVistaCompleja::OnPaint(wxPaintEvent& event)
 					LOG_ERROR("GVistaCompleja","bad_alloc, error al reservar memoria física");
 					GNC::GCS::IEntorno::Instance()->GetControladorEventos()->ProcesarEvento(new GNC::GCS::Events::EventoMensajes(NULL,_Std("Error: System out of memory. Close some studies to free memory."),GNC::GCS::Events::EventoMensajes::PopUpMessage,false));
 					GADAPI::ComandoDestruirVistaParams* pParams = new GADAPI::ComandoDestruirVistaParams(IVista);
-					GNC::GCS::IEntorno::Instance()->GetControladorComandos()->ProcessAsync(_Std("Destroy View"),new GADAPI::ComandoDestruirVista(pParams),NULL);
+					GNC::GCS::IEntorno::Instance()->GetCommandController()->ProcessAsync(_Std("Destroy View"),new GADAPI::ComandoDestruirVista(pParams),NULL);
 				}
 				catch(...)
 				{
 					LOG_ERROR("GVistaCompleja","excepción general al comprobar errores de memoria");
 					GNC::GCS::IEntorno::Instance()->GetControladorEventos()->ProcesarEvento(new GNC::GCS::Events::EventoMensajes(NULL,_Std("Error: Internal error."),GNC::GCS::Events::EventoMensajes::PopUpMessage,false));
 					GADAPI::ComandoDestruirVistaParams* pParams = new GADAPI::ComandoDestruirVistaParams(IVista);
-					GNC::GCS::IEntorno::Instance()->GetControladorComandos()->ProcessAsync(_Std("Destroy View"),new GADAPI::ComandoDestruirVista(pParams),NULL);
+					GNC::GCS::IEntorno::Instance()->GetCommandController()->ProcessAsync(_Std("Destroy View"),new GADAPI::ComandoDestruirVista(pParams),NULL);
 				}
 			}
 			m_hasBeenRendered = true;
@@ -902,7 +937,7 @@ void GVistaCompleja::OnFocus(wxChildFocusEvent &)
 
 void GVistaCompleja::OnSize(wxSizeEvent &)
 {
-	Layout();
+	this->Layout();
 }
 
 void GVistaCompleja::OnZSliderScroll (wxScrollEvent& event) {
@@ -1073,6 +1108,21 @@ std::string GVistaCompleja::GetBottomRightAnnotation(GNC::GCS::Contexto3D* c)
 	return "";
 }
 
+
+std::string GVistaCompleja::GetPatientPosition(GNC::GCS::Contexto3D* c) {
+	GNC::GCS::IWidgetsRenderer* r = ( c == NULL? NULL : c->GetRenderer());
+	if (r == NULL) {
+		return m_VistasSimples[0]->GetPatientPosition(c);
+	} else {
+		for (TListaGVistasSimples::iterator it = m_VistasSimples.begin(); it != m_VistasSimples.end(); ++it) {
+			if ( (*it)->ViewInteractor2D == r) {
+				return (*it)->GetPatientPosition(c);
+			}
+		}
+	}
+	return "";
+}
+
 std::string GVistaCompleja::GetAnotacionPosicion(GNC::GCS::Vector* pPosicion)
 {
 	GNC::GCS::IWidgetsRenderer* r = m_pManager->GetRendererActivo();
@@ -1091,6 +1141,11 @@ void GVistaCompleja::ActualizarImagen()
 	GNC::GCS::IEntorno::Instance()->GetControladorEventos()->ProcesarEvento(new GNC::GCS::Events::EventoModificacionImagen(IVista,GNC::GCS::Events::EventoModificacionImagen::ImagenModificada, -1));
 }
 
+GNC::GCS::IVista* GVistaCompleja::GetView()
+{
+	return IVista;
+}
+
 //----------DIALOGO SINCRONIZACION...-------------
 class DialogoSincronizacion: public DialogoSincronizacionBase {
 public:
@@ -1102,7 +1157,7 @@ public:
 		for(TipoListaVistas::iterator it = listaVistas.begin(); it!=listaVistas.end(); ++it){
 			m_pCheckListVistas->AppendString(wxString::FromUTF8((*it)->GetTitulo().c_str()));
 		}
-		Layout();
+		this->Layout();
 	}
 
 	~DialogoSincronizacion(){
@@ -1228,6 +1283,10 @@ void GVistaCompleja::DesSincronizar(){
 
 void GVistaCompleja::GoToSlice(int pos, bool relativa, bool propagar, bool render){
 	if (WindowLayoutDelegate->m_MaxSlice == WindowLayoutDelegate->m_MinSlice) {
+		if (render) {
+			GNC::GCS::Events::EventoModificacionImagen* pEvt = new GNC::GCS::Events::EventoModificacionImagen(IVista,GNC::GCS::Events::EventoModificacionImagen::SliceCambiado, -1, render);
+			GNC::GCS::IEntorno::Instance()->GetControladorEventos()->ProcesarEvento(pEvt);
+		}
 		return;
 	}
 	int posicion;
@@ -1243,6 +1302,10 @@ void GVistaCompleja::GoToSlice(int pos, bool relativa, bool propagar, bool rende
 	//si la posicion + las que se muestran en el layout actual es mayor al número de slices de la serie, no se avanza
 
 	if(posicion + ( (int) m_VistasSimples.size() ) > IVista->GetEstudio()->GetSliceNumber()) {
+		if (render) {
+			GNC::GCS::Events::EventoModificacionImagen* pEvt = new GNC::GCS::Events::EventoModificacionImagen(IVista,GNC::GCS::Events::EventoModificacionImagen::SliceCambiado, -1, render);
+			GNC::GCS::IEntorno::Instance()->GetControladorEventos()->ProcesarEvento(pEvt);
+		}
 		return;
 	}
 
