@@ -149,7 +149,7 @@ GVistaSimple::GVistaSimple(GNKVisualizator::Vista2D* pIVista, wxWindow* parent)
 
 	this->Connect(wxEVT_CHILD_FOCUS, wxChildFocusEventHandler(GVistaSimple::OnFocus),NULL,this);
 	ViewInteractor2D->Connect(wxEVT_KEY_DOWN,wxKeyEventHandler(GVistaSimple::OnKeyDown),NULL,this);
-	Layout();
+	this->Layout();
 }
 
 GVistaSimple::~GVistaSimple() {
@@ -164,7 +164,7 @@ GVistaSimple::~GVistaSimple() {
 	this->Disconnect( wxEVT_SIZE, wxSizeEventHandler( GVistaSimple::OnSize ) );
 
 	//abortamos comandos antes de cargarnos nada!
-	//m_pEntorno->GetControladorComandos()->AbortarComandosDeOwner(IVista);
+	//m_pEntorno->GetCommandController()->AbortarComandosDeOwner(IVista);
 
 	ViewImage2D->Detach();
 	//necesario para que no haga un doble delete
@@ -175,7 +175,7 @@ GVistaSimple::~GVistaSimple() {
 
 void GVistaSimple::OnSize( wxSizeEvent& /*event*/ )
 {
-	Layout();
+	this->Layout();
 }
 
 void GVistaSimple::OnPaint( wxPaintEvent& /*event*/ )
@@ -347,7 +347,7 @@ void GVistaSimple::ActualizarTSlider()
 		m_pSliderTimeInstant->SetRange(1, 2);
 		if (m_pSliderTimeInstant->IsShown()) {
 			m_pSliderTimeInstant->Show(false);
-			Layout();
+			this->Layout();
 			ViewInteractor2D->Refresh(true);
 		}
 	}
@@ -355,7 +355,7 @@ void GVistaSimple::ActualizarTSlider()
 		m_pSliderTimeInstant->SetRange(0, m_tDimensions - 1);
 		if (!m_pSliderTimeInstant->IsShown()) {
 			m_pSliderTimeInstant->Show(true);
-			Layout();
+			this->Layout();
 			ViewInteractor2D->Refresh(true);
 		}
 	}
@@ -550,6 +550,11 @@ std::string GVistaSimple::GetBottomRightAnnotation(GNC::GCS::Contexto3D* c) {
 	return os.str();
 }
 
+std::string GVistaSimple::GetPatientPosition(GNC::GCS::Contexto3D* c)
+{
+	return IVista->GetDICOMTagOriginal("0018|5100");
+}
+
 std::string GVistaSimple::GetAnotacionPosicion(GNC::GCS::Vector* pPosicion)
 {
 	if (!this->ViewImage2D->IsInstalledAndInitialized() || IVista == NULL)
