@@ -23,7 +23,7 @@
 
 #include <visualizator/vistas/waveformview.h>
 #include <visualizator/estudios/visualizatorstudy.h>
-#include <api/controllers/icommandscontroller.h>
+#include <main/controllers/commandcontroller.h>
 #include <api/controllers/ieventscontroller.h>
 #include <api/controllers/icontroladorvistas.h>
 #include <api/iwidgetsrenderer.h>
@@ -142,9 +142,12 @@ namespace GNKVisualizator
 			pToolBar->AddTool(HCore_DetachWindow, (GNC::GCS::IViewContract*) View);
 			pToolBar->AddTool(HCore_MetricGrid, (GNC::GCS::IWidgetsContract*) Delegate);
 			pToolBar->AddTool(HCore_Reset, (GNC::GCS::IWidgetsContract*) Delegate);
+
+			pToolBar->AddTool(HCore_SecondaryCapture, (GNC::GCS::IWidgetsContract*) Delegate);
 			//tools
 			pToolBar->AddTool(HCore_ShowDicomTags, (GNC::GCS::IViewContract*) View);
 			pToolBar->AddTool(HCore_ShowHistory, (GNC::GCS::IViewContract*) View);
+			pToolBar->AddTool(HCore_PACSUpload, (GNC::GCS::IViewContract*) View);
 			pToolBar->AddTool(HCore_Deshacer, (GNC::GCS::IViewContract*) View);
 			m_pSizerTools->Add(pToolBar->CreateNewToolBar(this, GNC::GCS::ITool::TFamiliaVisualizacion), 0, wxEXPAND);
 			m_pSizerTools->Add(pToolBar->CreateNewToolBar(this, GNC::GCS::ITool::TFamiliaMedicion), 0, wxEXPAND);
@@ -196,7 +199,7 @@ namespace GNKVisualizator
 		{
 			this->Disconnect(wxEVT_CHILD_FOCUS, wxChildFocusEventHandler(GWaveformView::OnFocus),NULL,this);
 			if (View != NULL) {
-				GNC::GCS::IEntorno::Instance()->GetControladorComandos()->AbortarComandosDeOwner(View);
+				GNC::GCS::IEntorno::Instance()->GetCommandController()->AbortarComandosDeOwner(View);
 			}			
 			View->GetToolController()->FinalizeToolController();
 			m_pManager->EliminarTodosLosWidgets(false);
@@ -235,25 +238,29 @@ namespace GNKVisualizator
 
 				
 				WECG = new GNKVisualizator::Widgets::WECG(GetManager(), 0);
-				GetManager()->InsertarWidget(WECG, false);
+					GetManager()->InsertarWidget(WECG, false);
 				
-				WECG->Reload(View->GetECGStudy()->GetListOfChannels());
-				WECG->AutoCallibrate();
+				if (!View->GetECGStudy()->Ok()) {
+					wxMessageBox(_("Error loading study with ecg view"), _("Error"), wxOK, NULL);
+				} else {
+					WECG->Reload(View->GetECGStudy()->GetListOfChannels());
+					WECG->AutoCallibrate();
 
-				m_pTextDiagnosis->SetValue(wxString::FromUTF8(View->GetECGStudy()->GetDiagnosis().c_str()));
-				m_pTextMeasurements->SetValue(wxString::FromUTF8(View->GetECGStudy()->GetGlobalMeasurement().c_str()));
+					m_pTextDiagnosis->SetValue(wxString::FromUTF8(View->GetECGStudy()->GetDiagnosis().c_str()));
+					m_pTextMeasurements->SetValue(wxString::FromUTF8(View->GetECGStudy()->GetGlobalMeasurement().c_str()));
 
-				//change color to widget anotacionesesquina
-				for( GNC::GCS::ListaWidgets::iterator it = m_pManager->GetListaWidgets().begin(); it != m_pManager->GetListaWidgets().end(); ++it) {
-					GNC::GCS::Widgets::IWidget* w = *it;
-					if (w->GetVID() == -1) {
-						GNC::GCS::Widgets::WAnotador* wac = dynamic_cast<GNC::GCS::Widgets::WAnotador*> (w);
-						if (wac != NULL) {
-							wac->SetTextColor(GNC::GCS::GLHelper::TColor(ANNOTATOR_TEXT_COLOR));
+					//change color to widget anotacionesesquina
+					for( GNC::GCS::ListaWidgets::iterator it = m_pManager->GetListaWidgets().begin(); it != m_pManager->GetListaWidgets().end(); ++it) {
+						GNC::GCS::Widgets::IWidget* w = *it;
+						if (w->GetVID() == -1) {
+							GNC::GCS::Widgets::WAnotador* wac = dynamic_cast<GNC::GCS::Widgets::WAnotador*> (w);
+							if (wac != NULL) {
+								wac->SetTextColor(GNC::GCS::GLHelper::TColor(ANNOTATOR_TEXT_COLOR));
+							}
 						}
 					}
-				}
-			}		
+				}		
+			}
 		}
 
 		
@@ -468,10 +475,17 @@ namespace GNKVisualizator
 			os << "25 mm/s, 10 mm/mV";
 			return os.str();
 		}
+
+		std::string GWaveformView::GetPatientPosition(GNC::GCS::Contexto3D* c)
+		{
+			return "";
+		}
+
 		std::string GWaveformView::GetAnotacionPosicion(GNC::GCS::Vector* pPosicionRaton)
 		{
 			return "";
 		}
+
 		//end ianotador
 
 		void GWaveformView::OnFocus(wxChildFocusEvent &event)
@@ -531,7 +545,9 @@ namespace GNKVisualizator
 								{
 									ViewImage2D->Modified();
 									GNC::GCS::IEntorno::Instance()->GetControladorEventos()->ProcesarEvento(new GNC::GCS::Events::EventoModificacionImagen(View,GNC::GCS::Events::EventoModificacionImagen::AnotacionesEstaticasModificadas));
-									WECG->Reload(View->GetECGStudy()->GetListOfChannels());
+									if (View->GetECGStudy()->Ok()) {
+										WECG->Reload(View->GetECGStudy()->GetListOfChannels());
+									}
 								}
 								break;
 						case GNC::GCS::Events::EventoModificacionImagen::ImagenRecalibrada:
